@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Cookie Based Access Handler
 #
-# $Id: lonacc.pm,v 1.135 2010/10/29 20:41:49 raeburn Exp $
+# $Id: lonacc.pm,v 1.136 2011/06/13 02:44:36 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -290,12 +290,15 @@ sub sso_login {
         }
     }
 
-    my $domain = $r->dir_config('lonDefDomain');
+    my $domain = $r->dir_config('lonSSOUserDomain');
+    if ($domain eq '') {
+        $domain = $r->dir_config('lonDefDomain');
+    }
     my $home=&Apache::lonnet::homeserver($user,$domain);
     if ($home !~ /(con_lost|no_host|no_such_host)/) {
 	&Apache::lonnet::logthis(" SSO authorized user $user ");
 	if ($r->dir_config("lonBalancer") eq 'yes') {
-	    # login but immeaditly go to switch server to find us a new 
+	    # login but immediately go to switch server to find us a new 
 	    # machine
 	    &Apache::lonauth::success($r,$user,$domain,$home,'noredirect');
             $env{'request.sso.login'} = 1;
