@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # User Authentication Module
 #
-# $Id: lonauth.pm,v 1.101.4.2 2010/05/23 21:20:11 raeburn Exp $
+# $Id: lonauth.pm,v 1.101.8.9 2011/10/10 21:02:55 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -40,6 +40,7 @@ use Apache::lonmenu();
 use Apache::createaccount;
 use Fcntl qw(:flock);
 use Apache::lonlocal;
+use Apache::File();
 use HTML::Entities;
  
 # ------------------------------------------------------------ Successful login
@@ -116,14 +117,16 @@ sub success {
     my $remoteinfo=&Apache::lonmenu::load_remote_msg($lowerurl);
     my $setflags=&Apache::lonmenu::setflags();
     my $maincall=&Apache::lonmenu::maincall();
+    my $brcrum = [{'href' => '',
+                   'text' => 'Successful Login'},];
     my $start_page=&Apache::loncommon::start_page('Successful Login',
                                                   $startupremote,
-                                                  {'no_inline_link' => 1,});
+                                                  {'no_inline_link' => 1,
+                                                   'bread_crumbs' => $brcrum,});
     my $end_page  =&Apache::loncommon::end_page();
 
     my $continuelink;
-    if (($env{'browser.interface'} eq 'textual') ||
-        ($env{'environment.remote'} eq 'off')) {
+    if ($env{'environment.remote'} eq 'off') {
 	$continuelink='<a href="'.$destination.'">'.&mt('Continue').'</a>';
     }
 # ------------------------------------------------- Output for successful login
@@ -134,16 +137,16 @@ sub success {
 
     my %lt=&Apache::lonlocal::texthash(
 				       'wel' => 'Welcome',
-				       'mes' => 'Welcome to the Learning<i>Online</i> Network with CAPA. Please wait while your session is being set up.',
 				       'pro' => 'Login problems?',
 				       'log' => 'loginproblems.html',
 				       );
+    my $welcome = &mt('Welcome to the Learning[_1]Online[_2] Network with CAPA. Please wait while your session is being set up.','<i>','</i>');
     $r->print(<<ENDSUCCESS);
 $start_page
 $setflags
 $windowinfo
 <h1>$lt{'wel'}</h1>
-$lt{'mes'}<p>
+$welcome<p>
 <a href="/adm/$lt{'log'}">$lt{'pro'}</a></p>
 $remoteinfo
 $maincall
@@ -214,21 +217,21 @@ sub handler {
         } else {
 # Indeed, a valid token is found
             &Apache::lonnet::transfer_profile_to_env($lonidsdir,$handle);
-	    &Apache::loncommon::content_type($r,'text/html');
-	    $r->send_http_header;
-	    my $start_page = 
-	        &Apache::loncommon::start_page('Already logged in');
-	    my $end_page = 
-	        &Apache::loncommon::end_page();
+            &Apache::loncommon::content_type($r,'text/html');
+            $r->send_http_header;
+            my $start_page =
+                &Apache::loncommon::start_page('Already logged in');
+            my $end_page =
+                &Apache::loncommon::end_page();
             my $dest = '/adm/roles';
             if ($env{'form.firsturl'} ne '') {
                 $dest = $env{'form.firsturl'};
             }
             $r->print(
-                $start_page
-               .'<h1>'.&mt('You are already logged in!').'</h1>'
-               .'<p>'.&mt('Please either [_1]continue the current session[_2] or [_3]log out[_4].'
-                        ,'<a href="'.$dest.'">','</a>','<a href="/adm/logout">','</a>')
+               $start_page
+              .'<h1>'.&mt('You are already logged in!').'</h1>'
+              .'<p>'.&mt('Please either [_1]continue the current session[_2] or [_3]log out[_4].'
+                    ,'<a href="'.$dest.'">','</a>','<a href="/adm/logout">','</a>')
               .'</p>'
               .$end_page
             );
@@ -274,7 +277,8 @@ sub handler {
     my $tmpinfo=Apache::lonnet::reply('tmpget:'.$form{'logtoken'},
                                       $form{'serverid'});
 
-    if (($tmpinfo=~/^error/) || ($tmpinfo eq 'con_lost')) {
+    if (($tmpinfo=~/^error/) || ($tmpinfo eq 'con_lost') ||
+       ($tmpinfo eq 'no_such_host')) {
 	&failed($r,'Information needed to verify your login information is missing, inaccessible or expired.',\%form);
         return OK;
     } else {
@@ -328,24 +332,20 @@ sub handler {
     }
 
 # ---------------------------------------------------------------- Authenticate
-    my @cancreate;
+
     my %domconfig = &Apache::lonnet::get_dom('configuration',['usercreation'],$form{'udom'});
-    if (ref($domconfig{'usercreation'}) eq 'HASH') {
-        if (ref($domconfig{'usercreation'}{'cancreate'}) eq 'HASH') {
-            if (ref($domconfig{'usercreation'}{'cancreate'}{'selfcreate'}) eq 'ARRAY') {
-                @cancreate = @{$domconfig{'usercreation'}{'cancreate'}{'selfcreate'}};
-            } elsif (($domconfig{'usercreation'}{'cancreate'}{'selfcreate'} ne 'none') && 
-                     ($domconfig{'usercreation'}{'cancreate'}{'selfcreate'} ne '')) {
-                @cancreate = ($domconfig{'usercreation'}{'cancreate'}{'selfcreate'});
-            }
+    my ($cancreate,$statustocreate) =
+        &Apache::createaccount::get_creation_controls($form{'udom'},$domconfig{'usercreation'});
+    my $defaultauth;
+    if (ref($cancreate) eq 'ARRAY') {
+        if (grep(/^login$/,@{$cancreate})) {
+            $defaultauth = 1;
         }
     }
-    my $defaultauth;
-    if (grep(/^login$/,@cancreate)) {
-        $defaultauth = 1;
-    }
+    my $clientcancheckhost = 1;
     my $authhost=Apache::lonnet::authenticate($form{'uname'},$upass,
-                                              $form{'udom'},$defaultauth);
+                                              $form{'udom'},$defaultauth,
+                                              $clientcancheckhost);
     
 # --------------------------------------------------------------------- Failed?
 
@@ -354,22 +354,25 @@ sub handler {
 		\%form);
         return OK;
     } elsif ($authhost eq 'no_account_on_host') {
-        my %domconfig = 
-            &Apache::lonnet::get_dom('configuration',['usercreation'],$form{'udom'});
-        if (grep(/^login$/,@cancreate)) {
+        if ($defaultauth) {
+            my $domdesc = &Apache::lonnet::domain($form{'udom'},'description');
+            unless (&check_can_host($r,\%form,'no_account_on_host',$domdesc)) {
+                return OK;
+            }
             my $start_page = 
                 &Apache::loncommon::start_page('Create a user account in LON-CAPA',
                                                '',{'no_inline_link'   => 1,});
-            my $domdesc = &Apache::lonnet::domain($form{'udom'},'description');
             my $lonhost = $r->dir_config('lonHostID');
             my $origmail = $Apache::lonnet::perlvar{'lonSupportEMail'};
             my $contacts = 
                 &Apache::loncommon::build_recipient_list(undef,'helpdeskmail',
                                                         $form{'udom'},$origmail);
             my ($contact_email) = split(',',$contacts); 
-            my $output = &Apache::createaccount::username_check($form{'uname'}, 
-                                                                $form{'udom'},$domdesc,'',
-                                                                $lonhost,$contact_email,$contact_name);
+            my $output =
+                &Apache::createaccount::username_check($form{'uname'},$form{'udom'},
+                                                       $domdesc,'',$lonhost,
+                                                       $contact_email,$contact_name,
+                                                       undef,$statustocreate);
             &Apache::loncommon::content_type($r,'text/html');
             $r->send_http_header;
             &Apache::createaccount::print_header($r,$start_page);
@@ -411,14 +414,133 @@ sub handler {
     }
 
     if ($r->dir_config("lonBalancer") eq 'yes') {
-	&success($r,$form{'uname'},$form{'udom'},$authhost,'noredirect',undef,
-		 \%form);
-	$r->internal_redirect('/adm/switchserver');
+        my $otherserver = &Apache::lonnet::spareserver(30000,undef,1,$form{'udom'});
+        if (!$otherserver) {
+            ($otherserver) = &Apache::lonnet::choose_server($form{'udom'});
+        }
+        if ($otherserver) {
+            &success($r,$form{'uname'},$form{'udom'},$authhost,'noredirect',undef,
+                     \%form);
+            $r->internal_redirect('/adm/switchserver?otherserver='.$otherserver.'&origurl='.$firsturl);
+        } else {
+            $r->print(&noswitch());
+        }
+        return OK;
     } else {
-	&success($r,$form{'uname'},$form{'udom'},$authhost,$firsturl,undef,
-		 \%form);
+        if (!&check_can_host($r,\%form,$authhost)) {
+            my ($otherserver) = &Apache::lonnet::choose_server($form{'udom'});
+            if ($otherserver) {
+                &success($r,$form{'uname'},$form{'udom'},$authhost,'noredirect',undef,
+                         \%form);
+                $r->internal_redirect('/adm/switchserver?otherserver='.$otherserver.'&origurl='.$firsturl);
+            } else {
+                $r->print(&noswitch());
+            }
+            return OK;
+        }
+# ------------------------------------------------------- Do the load balancing
+
+# ---------------------------------------------------------- Determine own load
+        my $loadlim = $r->dir_config('lonLoadLim');
+        my $loadavg;
+        {
+            my $loadfile=Apache::File->new('/proc/loadavg');
+            $loadavg=<$loadfile>;
+        }
+        $loadavg =~ s/\s.*//g;
+        my $loadpercent=sprintf("%.1f",100*$loadavg/$loadlim);
+        my $userloadpercent=&Apache::lonnet::userload();
+
+# ---------------------------------------------------------- Are we overloaded?
+        if ((($userloadpercent>100.0)||($loadpercent>100.0))) {
+            my $unloaded=Apache::lonnet::spareserver($loadpercent,$userloadpercent,1,$form{'udom'});
+            if (!$unloaded) {
+                ($unloaded) = &Apache::lonnet::choose_server($form{'udom'});
+            }
+            if ($unloaded) {
+                &success($r,$form{'uname'},$form{'udom'},$authhost,'noredirect',
+                         undef,\%form);
+                $r->internal_redirect('/adm/switchserver?otherserver='.$unloaded.'&origurl='.$firsturl);
+                return OK;
+            }
+        }
+        &success($r,$form{'uname'},$form{'udom'},$authhost,$firsturl,undef,
+                 \%form);
+        return OK;
     }
-    return OK;
+}
+
+sub check_can_host {
+    my ($r,$form,$authhost,$domdesc) = @_;
+    return unless (ref($form) eq 'HASH');
+    my $canhost = 1;
+    my $lonhost = $r->dir_config('lonHostID');
+    my $udom = $form->{'udom'};
+    my @intdoms;
+    my $internet_names = &Apache::lonnet::get_internet_names($lonhost);
+    if (ref($internet_names) eq 'ARRAY') {
+        @intdoms = @{$internet_names};
+    }
+    my $uprimary_id = &Apache::lonnet::domain($udom,'primary');
+    my $uint_dom = &Apache::lonnet::internet_dom($uprimary_id);
+    unless ($uint_dom ne '' && grep(/^\Q$uint_dom\E$/,@intdoms)) {
+        my $machine_dom = &Apache::lonnet::host_domain($lonhost);
+        my $hostname = &Apache::lonnet::hostname($lonhost);
+        my $serverhomeID = &Apache::lonnet::get_server_homeID($hostname);
+        my $serverhomedom = &Apache::lonnet::host_domain($serverhomeID);
+        my %defdomdefaults = &Apache::lonnet::get_domain_defaults($serverhomedom);
+        my %udomdefaults = &Apache::lonnet::get_domain_defaults($udom);
+        my $loncaparev;
+        if ($authhost eq 'no_account_on_host') {
+            $loncaparev = &Apache::lonnet::get_server_loncaparev($machine_dom);
+        } else {
+            $loncaparev = &Apache::lonnet::get_server_loncaparev($machine_dom,$lonhost);
+        }
+        $canhost = &Apache::lonnet::can_host_session($udom,$lonhost,$loncaparev,
+                                                     $udomdefaults{'remotesessions'},
+                                                     $defdomdefaults{'hostedsessions'});
+    }
+    unless ($canhost) {
+        if ($authhost eq 'no_account_on_host') {
+            my $checkloginvia = 1;
+            my ($login_host,$hostname) =
+                &Apache::lonnet::choose_server($udom,$checkloginvia);
+            &Apache::loncommon::content_type($r,'text/html');
+            $r->send_http_header;
+            if ($login_host ne '') {
+                my $protocol = $Apache::lonnet::protocol{$login_host};
+                $protocol = 'http' if ($protocol ne 'https');
+                my $newurl = $protocol.'://'.$hostname.'/adm/createaccount';
+                $r->print(&Apache::loncommon::start_page('Create a user account in LON-CAPA').
+                          '<h3>'.&mt('Account creation').'</h3>'.
+                          &mt('You do not currently have a LON-CAPA account at this institution.').'<br />'.
+                          '<p>'.&mt('You will be able to create one by logging into a LON-CAPA server within the [_1] domain.',$domdesc).'</p>'.
+                          '<p>'.&mt('[_1]Log in[_2]','<a href="'.$newurl.'">','</a>').
+                          &Apache::loncommon::end_page());
+            } else {
+                $r->print(&Apache::loncommon::start_page('Access to LON-CAPA unavailable').
+                          '<h3>'.&mt('Account creation unavailable').'</h3>'.
+                          &mt('You do not currently have a LON-CAPA account at this institution.').'<br />'.
+                          '<p>'.&mt('Currently a LON-CAPA server is not available within the [_1] domain for you to log-in to, to create an account.',$domdesc).'</p>'.
+                          &Apache::loncommon::end_page());
+            }
+        } else {
+            &success($r,$form->{'uname'},$udom,$authhost,'noredirect',undef,
+                     $form);
+            my ($otherserver) = &Apache::lonnet::choose_server($udom);
+            $r->internal_redirect('/adm/switchserver?otherserver='.$otherserver);
+        }
+    }
+    return $canhost;
+}
+
+sub noswitch {
+    my $result = &Apache::loncommon::start_page('Access to LON-CAPA unavailable').
+                 '<h3>'.&mt('Session unavailable').'</h3>'.
+                 &mt('This LON-CAPA server is unable to host your session.').'<br />'.
+                 '<p>'.&mt('Currently no other LON-CAPA server is available to host your session either.').'</p>'.
+                 &Apache::loncommon::end_page();
+    return $result;
 }
 
 1;
