@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Logout Handler
 #
-# $Id: lonlogout.pm,v 1.38 2009/05/16 13:50:04 droeschl Exp $
+# $Id: lonlogout.pm,v 1.42.2.2 2011/11/19 19:10:34 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -109,14 +109,32 @@ sub handler {
         $relogmessage.='<h1>'.&mt('Goodbye').'</h1>'
                       .'<p>'.&mt('Thank you for using LON-CAPA.').'</p>';
 
+        my $domain = $env{'user.domain'};
 	if (!$env{'request.sso.norelogin'}) {
-	    my $relogin_server;
+	    my ($relogin_server,$login_url);
 	    if ($env{'request.sso.reloginserver'}) {
 		$relogin_server = $env{'request.sso.reloginserver'};
-	    }
-	    my $login_url = $relogin_server.'/adm/'.
-		($env{'request.sso.login'} ? 'roles': 'login');
-
+	    } else {
+                 my %domdefaults = &Apache::lonnet::get_domain_defaults($domain);
+                 if ($domdefaults{'portal_def'}) {
+                     $login_url = $domdefaults{'portal_def'};
+                 } else {
+                     my $checkloginvia = 1;
+                     my ($lonhost,$server,$path) = 
+                         &Apache::lonnet::choose_server($domain,$checkloginvia);
+                     if ($server && $lonhost) {
+                         $login_url = $Apache::lonnet::protocol{$lonhost}.
+                                      '://'.$server.$path;
+                         if ($path eq '/adm/login' && $domain ne '') {
+                             $login_url .= '?domain='.$domain;
+                         }
+                     }
+                 }
+            }
+            if ($login_url eq '') {
+	        $login_url = $relogin_server.'/adm/'.
+		    ($env{'request.sso.login'} ? 'roles': 'login?domain='.$domain);
+            }
             $relogmessage.='<p>'.&mt('You have been successfully logged out.').' '
                           .&mt('You can [_1]close this window[_2] now.'
                               ,'','') # ,'<a href="javascript:self.close();">','</a>')
@@ -131,10 +149,9 @@ Due to security reasons in new web browsers a window could only be closed with j
 
 =cut
             $relogmessage.='<p>'.&mt('[_1]Log in again[_2]'
-                              ,'<a href="'.$login_url.'?domain='.$env{'user.domain'}.'">','</a>')
+                              ,'<a href="'.$login_url.'">','</a>')
                           .'</p>';
         }
-	my $domain = $env{'user.domain'};
         if ($env{'request.sso.login'}
 	    && defined($r->dir_config("lonSSOUserLogoutMessageFile_$domain"))) {
 	    open(my $fh,$r->dir_config("lonSSOUserLogoutMessageFile_$domain"));
