@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # User Roles Screen
 #
-# $Id: lonroles.pm,v 1.231.4.15 2010/08/20 03:40:01 raeburn Exp $
+# $Id: lonroles.pm,v 1.256.2.6 2011/09/27 20:33:34 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -138,10 +138,11 @@ use Apache::lonannounce;
 use Apache::lonlocal;
 use Apache::lonpageflip();
 use Apache::lonnavdisplay();
+use Apache::loncoursequeueadmin;
 use GDBM_File;
 use LONCAPA qw(:DEFAULT :match);
 use HTML::Entities;
- 
+
 
 sub redirect_user {
     my ($r,$title,$url,$msg,$launch_nav) = @_;
@@ -152,14 +153,18 @@ sub redirect_user {
     my $swinfo=&Apache::lonmenu::rawconfig();
     my $navwindow;
     if ($launch_nav eq 'on') {
-	$navwindow.=&Apache::lonnavdisplay::launch_win('now',undef,undef,
-						       ($url =~ m-^/adm/whatsnew-));
+        $navwindow.=&Apache::lonnavdisplay::launch_win('now',undef,undef,
+                                                       ($url =~ m-^/adm/whatsnew-));
     } else {
-	$navwindow.=&Apache::lonnavmaps::close();
+        $navwindow.=&Apache::lonnavmaps::close();
     }
 
+    # Breadcrumbs
+    my $brcrum = [{'href' => $url,
+                   'text' => 'Switching Role'},];
     my $start_page = &Apache::loncommon::start_page('Switching Role',undef,
-                                                    {'redirect' => [1,$url]});
+                                                    {'redirect' => [1,$url],
+                                                     'bread_crumbs' => $brcrum,});
     my $end_page   = &Apache::loncommon::end_page();
 
 # Note to style police: 
@@ -185,17 +190,25 @@ sub error_page {
     &Apache::loncommon::no_cache($r);
     $r->send_http_header;
     return OK if $r->header_only;
-    $r->print(&Apache::loncommon::start_page('Problems during Course Initialization').
+    # Breadcrumbs
+    my $brcrum = [{'href' => $dest,
+                   'text' => 'Problems during Course Initialization'},];
+    $r->print(&Apache::loncommon::start_page('Problems during Course Initialization',
+                                             undef,
+                                             {'bread_crumbs' => $brcrum,})
+    );
+    $r->print(
         '<script type="text/javascript">'.
         '// <![CDATA['.
         &Apache::lonmenu::rawconfig().
         '// ]]>'.
         '</script>'.
 	      '<p class="LC_error">'.&mt('The following problems occurred:').
-              '<br />'.
+          '<br />'.
 	      $error.
-	      '</p><br /><a href="'.$dest.'">'.&mt('Continue').'</a>'.
-              &Apache::loncommon::end_page());
+	      '</p><br /><a href="'.$dest.'">'.&mt('Continue').'</a>'
+    );
+    $r->print(&Apache::loncommon::end_page());
 }
 
 sub handler {
@@ -212,6 +225,7 @@ sub handler {
     my %dcroles = ();
     my $numdc = &check_fordc(\%dcroles,$then);
     &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'});
+    my $loncaparev = $Apache::lonnet::perlvar{'lonVersion'};
 
 # ================================================================== Roles Init
     if ($env{'form.selectrole'}) {
@@ -325,6 +339,42 @@ sub handler {
 		if ($tstatus eq 'is') {
 		    $where=~s/^\///;
 		    my ($cdom,$cnum,$csec)=split(/\//,$where);
+                    if (($cnum) && ($role ne 'ca') && ($role ne 'aa')) {
+                        my $home = $env{'course.'.$cdom.'_'.$cnum.'.home'};
+                        my @ids = &Apache::lonnet::current_machine_ids();
+                        unless ($loncaparev eq '' && $home && grep(/^\Q$home\E$/,@ids)) {
+                            my %curr_reqd_hash = &Apache::lonnet::userenvironment($cdom,$cnum,'internal.releaserequired');
+                            if ($curr_reqd_hash{'internal.releaserequired'} ne '') {
+                                my ($switchserver,$switchwarning) =
+                                    &check_release_required($loncaparev,$cdom.'_'.$cnum,$trolecode,$curr_reqd_hash{'internal.releaserequired'});
+                                if ($switchwarning ne '' || $switchserver ne '') {
+                                    &Apache::loncommon::content_type($r,'text/html');
+                                    &Apache::loncommon::no_cache($r);
+                                    $r->send_http_header;
+                                    my $end_page=&Apache::loncommon::end_page();
+                                    $r->print(&Apache::loncommon::start_page('Selected course unavailable on this server').
+                                              '<p class="LC_warning">');
+                                    if ($switchwarning) {
+                                        $r->print($switchwarning.'<br /><a href="/adm/roles">');
+                                        if (&Apache::loncommon::show_course()) {
+                                            $r->print(&mt('Display courses'));
+                                        } else {
+                                            $r->print(&mt('Display roles'));
+                                        }
+                                        $r->print('</a>');
+                                    } elsif ($switchserver) {
+				        $r->print(&mt('This course requires a newer version of LON-CAPA than is installed on this server.').
+                                                  '<br />'.
+                                                  '<a href="/adm/switchserver?'.$switchserver.'">'.
+                                                  &mt('Switch Server').
+                                                  '</a>');
+                                    }
+                                    $r->print('</p>'.&Apache::loncommon::end_page());
+                                    return OK;
+                                }
+                            }
+                        }
+                    }
 # check for course groups
                     my %coursegroups = &Apache::lonnet::get_active_groups(
                           $env{'user.domain'},$env{'user.name'},$cdom, $cnum);
@@ -460,6 +510,12 @@ ENDENTERKEY
                             if (($ferr) && ($tadv)) {
 				&error_page($r,$ferr,$dest);
 			    } else {
+                                if ($dest =~ m{^/adm/coursedocs\?folderpath}) {
+                                    if ($env{'request.course.id'} eq $cdom.'_'.$cnum) { 
+                                        my $chome = &Apache::lonnet::homeserver($cnum,$cdom);
+                                        &update_content_constraints($cdom,$cnum,$chome,$cdom.'_'.$cnum);
+                                    }
+                                }
 				$r->internal_redirect($dest);
 			    }
 			    return OK;
@@ -489,7 +545,7 @@ ENDENTERKEY
 				}
 				$courseid =~ s/\//_/;
 				if ((($role eq 'cc') || ($role eq 'co')) 
-                                      && ($env{'course.' . $courseid .'.course.helper.not.run'})) { 
+                                    && ($env{'course.' . $courseid .'.course.helper.not.run'})) { 
 				    $furl = "/adm/helper/course.initialization.helper";
 				    # Send the user to the course they selected
 				} elsif ($env{'request.course.id'}) {
@@ -499,10 +555,10 @@ ENDENTERKEY
                                             my $esc_symb = &HTML::Entities::encode($env{'form.destsymb'},'"<>&');
                                             $dest .= '?symb='.$esc_symb;
                                         }
-                                        &redirect_user($r,&mt('Entering [_1]',
-                                                      $env{'course.'.$courseid.'.description'}),
-                                               $dest,$msg,
-                                               $env{'environment.remotenavmap'});
+                                        &redirect_user($r, &mt('Entering [_1]',
+                                                       $env{'course.'.$courseid.'.description'}),
+                                                       $dest, $msg,
+                                                       $env{'environment.remotenavmap'});
                                         return OK;
                                     }
 				    if (&Apache::lonnet::allowed('whn',
@@ -515,24 +571,26 @@ ENDENTERKEY
 					unless ($startpage eq 'firstres') {         
 					    $msg = &mt('Entering [_1] ...',
 						       $env{'course.'.$courseid.'.description'});
-					    &redirect_user($r,&mt('New in course'),
-							   '/adm/whatsnew?refpage=start',$msg,
-							   $env{'environment.remotenavmap'});
+                                            &redirect_user($r,&mt('New in course'),
+                                                           '/adm/whatsnew?refpage=start',$msg,
+                                                           $env{'environment.remotenavmap'});
 					    return OK;
 					}
 				    }
 				}
 # Are we allowed to look at the first resource?
-				if ($furl !~ m|^/adm/|) {
+				if (($furl !~ m|^/adm/|) || 
+                                    (($env{'environment.remotenavmap'} eq 'on') && 
+                                     ($furl =~ m{^/adm/navmaps}))) {
 # Guess not ...
 				    $furl=&Apache::lonpageflip::first_accessible_resource();
 				}
                                 $msg = &mt('Entering [_1] ...',
 					   $env{'course.'.$courseid.'.description'});
-				&redirect_user($r,&mt('Entering [_1]',
-						      $env{'course.'.$courseid.'.description'}),
-					       $furl,$msg,
-					       $env{'environment.remotenavmap'});
+                                &redirect_user($r,&mt('Entering [_1]',
+                                                      $env{'course.'.$courseid.'.description'}),
+                                               $furl,$msg,
+                                               $env{'environment.remotenavmap'});
 			    }
 			    return OK;
 			}
@@ -692,11 +750,12 @@ ENDHEADER
         $r->print('<input type="hidden" name="selectrole" value="1" />');
         $r->print('<input type="hidden" name="newrole" value="" />');
     }
+    $r->rflush();
 
     my (%roletext,%sortrole,%roleclass,%futureroles,%timezones);
     my ($countactive,$countfuture,$inrole,$possiblerole) = 
         &gather_roles($then,$refresh,$now,$reinit,$nochoose,\%roletext,\%sortrole,\%roleclass,
-                      \%futureroles,\%timezones);
+                      \%futureroles,\%timezones,$loncaparev);
 
     $refresh = $now;
     &Apache::lonnet::appenv({'user.refresh.time'  => $refresh});
@@ -711,7 +770,6 @@ ENDHEADER
             $r->print(&Apache::loncoursequeueadmin::queued_selfenrollment());
             my $domdesc = &Apache::lonnet::domain($env{'user.domain'},'description');
             my $esc_dom = &HTML::Entities::encode($env{'user.domain'},'"<>&'); 
-
             $r->print(
                 '<p>'
                .&mt('[_1]Visit the [_2]Course/Community Catalog[_3]'
@@ -736,7 +794,7 @@ ENDHEADER
 	    $r->print('<h2>'.&mt('Currently no active roles, courses or communities').'</h2>');
 	}
         &findcourse_advice($r);
-        &requestcourse_advice($r);
+        &requestcourse_advice($r); 
 	$r->print('</form>');
         if ($countfuture) {
             $r->print(&mt('The following [quant,_1,role,roles] will become active in the future:',$countfuture));
@@ -767,6 +825,7 @@ ENDHEADER
 	return OK;
     }
 # ----------------------------------------------------------------------- Table
+
     if ($numdc > 0) {
         $r->print(&coursepick_jscript());
         $r->print(&Apache::loncommon::coursebrowser_javascript().
@@ -784,6 +843,7 @@ ENDHEADER
                       $env{'form.destsymb'}.'" />');
         }
     }
+
     my $doheaders = &roletable_headers($r,\%roleclass,\%sortrole,$nochoose);
     if ($env{'environment.recentroles'}) {
         my %recent_roles =
@@ -806,12 +866,16 @@ ENDHEADER
 	    } elsif ($numdc > 0) {
                 unless ($role =~/^error\:/) {
                     my ($roletext,$role_text_end) = &display_cc_role('user.role.'.$role);
-                    $output.= &Apache::loncommon::start_data_table_row().
-                              $roletext.
-                              &Apache::loncommon::end_data_table_row().
-                              &Apache::loncommon::continue_data_table_row().
-                              $role_text_end.
-                              &Apache::loncommon::end_data_table_row();
+                    if ($roletext) {
+                        $output.= &Apache::loncommon::start_data_table_row().
+                                  $roletext.
+                                  &Apache::loncommon::end_data_table_row();
+                        if ($role_text_end) {
+                            $output .= &Apache::loncommon::continue_data_table_row().
+                                       $role_text_end.
+                                       &Apache::loncommon::end_data_table_row();
+                        }
+                    }
                 }
             }
 	}
@@ -877,29 +941,24 @@ ENDHEADER
 }
 
 sub gather_roles {
-    my ($then,$refresh,$now,$reinit,$nochoose,$roletext,$sortrole,$roleclass,$futureroles,$timezones) = @_;
+    my ($then,$refresh,$now,$reinit,$nochoose,$roletext,$sortrole,$roleclass,$futureroles,$timezones,$loncaparev) = @_;
     my ($countactive,$countfuture,$inrole,$possiblerole) = (0,0,0,'');
     my $advanced = $env{'user.adv'};
     my $tryagain = $env{'form.tryagain'};
+    my @ids = &Apache::lonnet::current_machine_ids();
     foreach my $envkey (sort(keys(%env))) {
         my $button = 1;
         my $switchserver='';
+        my $switchwarning;
         my ($role_text,$role_text_end,$sortkey);
         if ($envkey=~/^user\.role\./) {
             my ($role,$where,$trolecode,$tstart,$tend,$tremark,$tstatus,$tpstart,$tpend);
             &Apache::lonnet::role_status($envkey,$then,$refresh,$now,\$role,\$where,
                                          \$trolecode,\$tstatus,\$tstart,\$tend);
             next if (!defined($role) || $role eq '' || $role =~ /^gr/);
-            my $timezone = &role_timezone($where,$timezones);
             $tremark='';
             $tpstart='&nbsp;';
             $tpend='&nbsp;';
-            if ($tstart) {
-                $tpstart=&Apache::lonlocal::locallocaltime($tstart,$timezone);
-            }
-            if ($tend) {
-                $tpend=&Apache::lonlocal::locallocaltime($tend,$timezone);
-            }
             if ($env{'request.role'} eq $trolecode) {
                 $tstatus='selected';
             }
@@ -908,6 +967,13 @@ sub gather_roles {
                 || ($tstatus eq 'selected')
                 || ($tstatus eq 'future')
                 || ($env{'form.showall'})) {
+                my $timezone = &role_timezone($where,$timezones);
+                if ($tstart) {
+                    $tpstart=&Apache::lonlocal::locallocaltime($tstart,$timezone);
+                }
+                if ($tend) {
+                    $tpend=&Apache::lonlocal::locallocaltime($tend,$timezone);
+                }
                 if ($tstatus eq 'is') {
                     $tbg='LC_roles_is';
                     $possiblerole=$trolecode;
@@ -944,7 +1010,6 @@ sub gather_roles {
                 if (($role eq 'ca') || ($role eq 'aa')) {
                     my $home = &Apache::lonnet::homeserver($trest,$tdom);
                     my $allowed=0;
-                    my @ids=&Apache::lonnet::current_machine_ids();
                     foreach my $id (@ids) { if ($id eq $home) { $allowed=1; } }
                     if (!$allowed) {
                         $button=0;
@@ -964,7 +1029,6 @@ sub gather_roles {
                     my $home = &Apache::lonnet::homeserver
                         ($env{'user.name'},$env{'user.domain'});
                     my $allowed=0;
-                    my @ids=&Apache::lonnet::current_machine_ids();
                     foreach my $id (@ids) { if ($id eq $home) { $allowed=1; } }
                     if (!$allowed) {
                         $button=0;
@@ -983,6 +1047,7 @@ sub gather_roles {
                     $ttype = &Apache::loncommon::course_type($tcourseid);
                     $trole = &Apache::lonnet::plaintext($role,$ttype,$tcourseid);
                     if ($env{'course.'.$tcourseid.'.description'}) {
+                        my $home=$env{'course.'.$tcourseid.'.home'};
                         $twhere=$env{'course.'.$tcourseid.'.description'};
                         $sortkey=$role."\0".$tdom."\0".$twhere."\0".$envkey;
                         $twhere = &HTML::Entities::encode($twhere,'"<>&');
@@ -990,6 +1055,16 @@ sub gather_roles {
                             $twhere.=' <span class="LC_fontsize_small">'.
         &Apache::loncommon::syllabuswrapper(&mt('Syllabus'),$trest,$tdom).
                                     '</span>';
+                            unless ($home && grep(/^\Q$home\E$/,@ids) && $loncaparev eq '') {
+                                my $required = $env{'course.'.$tcourseid.'.internal.releaserequired'};
+                                if ($required ne '') {
+                                    ($switchserver,$switchwarning) = 
+                                        &check_release_required($loncaparev,$tcourseid,$trolecode,$required);
+                                    if ($switchserver || $switchwarning) {
+                                        $button = 0;
+                                    }
+                                }
+                            }
                         }
                     } else {
                         my %newhash=&Apache::lonnet::coursedescription($tcourseid);
@@ -997,11 +1072,22 @@ sub gather_roles {
                             $sortkey=$role."\0".$tdom."\0".$newhash{'description'}.
                                 "\0".$envkey;
                             $twhere=&HTML::Entities::encode($newhash{'description'},'"<>&').
-                              ' <span class="LC_fontsize_small">'.
-        &Apache::loncommon::syllabuswrapper(&mt('Syllabus'),$trest,$tdom).
-                              '</span>';
+                                    ' <span class="LC_fontsize_small">'.
+                                     &Apache::loncommon::syllabuswrapper(&mt('Syllabus'),$trest,$tdom).
+                                    '</span>';
                             $ttype = $newhash{'type'};
                             $trole = &Apache::lonnet::plaintext($role,$ttype,$tcourseid);
+                            my $home = $newhash{'home'};
+                            unless ($home && grep(/^\Q$home\E$/,@ids) && $loncaparev eq '') {
+                                my $required = $newhash{'internal.releaserequired'};
+                                if ($required ne '') {
+                                    ($switchserver,$switchwarning) =
+                                        &check_release_required($loncaparev,$tcourseid,$trolecode,$required);
+                                    if ($switchserver || $switchwarning) {
+                                        $button = 0;
+                                    }
+                                }
+                            }
                         } else {
                             $twhere=&mt('Currently not available');
                             $env{'course.'.$tcourseid.'.description'}=$twhere;
@@ -1025,7 +1111,7 @@ sub gather_roles {
                 ($role_text,$role_text_end) =
                     &build_roletext($trolecode,$tdom,$trest,$tstatus,$tryagain,
                                     $advanced,$tremark,$tbg,$trole,$twhere,$tpstart,
-                                    $tpend,$nochoose,$button,$switchserver,$reinit);
+                                    $tpend,$nochoose,$button,$switchserver,$reinit,$switchwarning);
                 $roletext->{$envkey}=[$role_text,$role_text_end];
                 if (!$sortkey) {$sortkey=$twhere."\0".$envkey;}
                 $sortrole->{$sortkey}=$envkey;
@@ -1045,9 +1131,15 @@ sub role_timezone {
             my $cnum = $2;
             if ($cdom && $cnum) {
                 if (!exists($timezones->{$cdom.'_'.$cnum})) {
-                    my %timehash =
-                        &Apache::lonnet::get('environment',['timezone'],$cdom,$cnum);
-                    if ($timehash{'timezone'} eq '') {
+                    my $tz;
+                    if ($env{'course.'.$cdom.'_'.$cnum.'.description'}) {
+                        $tz = $env{'course.'.$cdom.'_'.$cnum.'.timezone'};
+                    } else {
+                        my %timehash =
+                            &Apache::lonnet::get('environment',['timezone'],$cdom,$cnum);
+                        $tz = $timehash{'timezone'};
+                    }
+                    if ($tz eq '') {
                         if (!exists($timezones->{$cdom})) {
                             my %domdefaults = 
                                 &Apache::lonnet::get_domain_defaults($cdom);
@@ -1060,7 +1152,7 @@ sub role_timezone {
                         $timezones->{$cdom.'_'.$cnum} = $timezones->{$cdom};
                     } else {
                         $timezones->{$cdom.'_'.$cnum} = 
-                            &Apache::lonlocal::gettimezone($timehash{'timezone'});
+                            &Apache::lonlocal::gettimezone($tz);
                     }
                 }
                 $timezone = $timezones->{$cdom.'_'.$cnum};
@@ -1196,12 +1288,12 @@ sub requestcourse_advice {
     &Apache::lonnet::check_can_request($env{'user.domain'},\%can_request,\%request_doms);
     if (keys(%request_doms) > 0) {
         my ($types,$typename) = &Apache::loncommon::course_types();
-        if ((ref($types) eq 'ARRAY') && (ref($typename) eq 'HASH')) {
+        if ((ref($types) eq 'ARRAY') && (ref($typename) eq 'HASH')) { 
             $r->print('<h3>'.&mt('Request creation of a course or community').'</h3>'.
                       '<p>'.&mt('You have rights to request the creation of courses and/or communities in the following domain(s):').'<ul>');
             my (@reqdoms,@reqtypes);
             foreach my $type (sort(keys(%request_doms))) {
-                push(@reqtypes,$type);
+                push(@reqtypes,$type); 
                 if (ref($request_doms{$type}) eq 'ARRAY') {
                     my $domstr = join(', ',map { &Apache::lonnet::domain($_) } sort(@{$request_doms{$type}}));
                     $r->print(
@@ -1234,7 +1326,7 @@ sub requestcourse_advice {
             }
             if (@reqdoms == 1 || @showtypes > 0) {
                 $requrl .= '&state=crstype&action=new';
-            }
+            } 
             $r->print('</ul>'.&mt('Use the [_1]request form[_2] to submit a request for creation of a new course or community.','<a href="'.$requrl.'">','</a>').'</p>');
         }
     }
@@ -1297,7 +1389,7 @@ sub privileges_info {
 }
 
 sub build_roletext {
-    my ($trolecode,$tdom,$trest,$tstatus,$tryagain,$advanced,$tremark,$tbg,$trole,$twhere,$tpstart,$tpend,$nochoose,$button,$switchserver,$reinit) = @_;
+    my ($trolecode,$tdom,$trest,$tstatus,$tryagain,$advanced,$tremark,$tbg,$trole,$twhere,$tpstart,$tpend,$nochoose,$button,$switchserver,$reinit,$switchwarning) = @_;
     my ($roletext,$roletext_end);
     my $is_dc=($trolecode =~ m/^dc\./);
     my $rowspan=($is_dc) ? ''
@@ -1315,6 +1407,13 @@ sub build_roletext {
             } else {
                 $roletext.=('<td'.$rowspan.' class="'.$tbg.'">&nbsp;</td>');
             }
+            if ($switchwarning) {
+                if ($tremark eq '') {
+                    $tremark = $switchwarning;
+                } else {
+                    $tremark .= '<br />'.$switchwarning;
+                }
+            }
         } elsif ($tstatus eq 'is') {
             $roletext.='<td'.$rowspan.' class="'.$tbg.'">'.
                         '<input name="'.$buttonname.'" type="button" value="'.
@@ -1495,6 +1594,95 @@ sub check_forcc {
     return $is_cc;
 }
 
+sub check_release_required {
+    my ($loncaparev,$tcourseid,$trolecode,$required) = @_;
+    my ($switchserver,$warning);
+    if ($required ne '') {
+        my ($reqdmajor,$reqdminor) = ($required =~ /^(\d+)\.(\d+)$/);
+        my ($major,$minor) = ($loncaparev =~ /^\'?(\d+)\.(\d+)\.[\w.\-]+\'?$/);
+        if ($reqdmajor ne '' && $reqdminor ne '') {
+            my $otherserver;
+            if (($major eq '' && $minor eq '') || 
+                (($reqdmajor > $major) || (($reqdmajor == $major) && ($reqdminor > $minor)))) {
+                my ($userdomserver) = &Apache::lonnet::choose_server($env{'user.domain'});
+                my $switchlcrev = 
+                    &Apache::lonnet::get_server_loncaparev($env{'user.domain'},
+                                                           $userdomserver);
+                my ($swmajor,$swminor) = ($switchlcrev =~ /^\'?(\d+)\.(\d+)\.[\w.\-]+\'?$/);
+                if (($swmajor eq '' && $swminor eq '') || ($reqdmajor > $swmajor) || 
+                    (($reqdmajor == $swmajor) && ($reqdminor > $swminor))) {
+                    my $cdom = $env{'course.'.$tcourseid.'.domain'};
+                    if ($cdom ne $env{'user.domain'}) {
+                        my ($coursedomserver,$coursehostname) = &Apache::lonnet::choose_server($cdom); 
+                        my $serverhomeID = &Apache::lonnet::get_server_homeID($coursehostname);
+                        my $serverhomedom = &Apache::lonnet::host_domain($serverhomeID);
+                        my %defdomdefaults = &Apache::lonnet::get_domain_defaults($serverhomedom);
+                        my %udomdefaults = &Apache::lonnet::get_domain_defaults($env{'user.domain'});
+                        my $remoterev = &Apache::lonnet::get_server_loncaparev($serverhomedom,$coursedomserver);
+                        my $canhost =
+                            &Apache::lonnet::can_host_session($env{'user.domain'},
+                                                              $coursedomserver,
+                                                              $remoterev,
+                                                              $udomdefaults{'remotesessions'},
+                                                              $defdomdefaults{'hostedsessions'});
+
+                        if ($canhost) {
+                            $otherserver = $coursedomserver;
+                        } else {
+                            $warning = &mt('Requires LON-CAPA version [_1].',$env{'course.'.$tcourseid.'.internal.releaserequired'}).'<br />'. &mt("No suitable server could be found amongst servers in either your own domain or in the course's domain.");
+                        }
+                    } else {
+                        $warning = &mt('Requires LON-CAPA version [_1].',$env{'course.'.$tcourseid.'.internal.releaserequired'}).'<br />'.&mt("No suitable server could be found amongst servers in your own domain (which is also the course's domain).");
+                    }
+                } else {
+                    $otherserver = $userdomserver;
+                }
+            }
+            if ($otherserver ne '') {
+                $switchserver = 'otherserver='.$otherserver.'&amp;role='.$trolecode;
+            }
+        }
+    }
+    return ($switchserver,$warning);
+}
+
+sub update_content_constraints {
+    my ($cdom,$cnum,$chome,$cid) = @_;
+    my %curr_reqd_hash = &Apache::lonnet::userenvironment($cdom,$cnum,'internal.releaserequired');
+    my ($reqdmajor,$reqdminor) = split(/\./,$curr_reqd_hash{'internal.releaserequired'}); 
+    my %checkresponsetypes;
+    foreach my $key (keys(%Apache::lonnet::needsrelease)) {
+        my ($item,$name,$value) = split(/:/,$key);
+        if ($item eq 'resourcetag') {
+            if ($name eq 'responsetype') {
+                $checkresponsetypes{$value} = $Apache::lonnet::needsrelease{$key}
+            }
+        }
+    }
+    my $navmap = Apache::lonnavmaps::navmap->new();
+    if (defined($navmap)) {
+        my %allresponses;
+        foreach my $res ($navmap->retrieveResources(undef,sub { $_[0]->is_problem() },1,0)) {
+            my %responses = $res->responseTypes();
+            foreach my $key (keys(%responses)) {
+                next unless(exists($checkresponsetypes{$key}));
+                $allresponses{$key} += $responses{$key};
+            }
+        }
+        foreach my $key (keys(%allresponses)) {
+            my ($major,$minor) = split(/\./,$checkresponsetypes{$key});
+            if (($major > $reqdmajor) || ($major == $reqdmajor && $minor > $reqdminor)) { 
+                ($reqdmajor,$reqdminor) = ($major,$minor);
+            } 
+        }
+        undef($navmap);
+    }
+    unless (($reqdmajor eq '') && ($reqdminor eq '')) {
+        &Apache::lonnet::update_released_required($reqdmajor.'.'.$reqdminor,$cdom,$cnum,$chome,$cid);
+    }
+    return;
+}
+
 sub courselink {
     my ($dcdom,$rowtype) = @_;
     my $courseform=&Apache::loncommon::selectcourse_link
@@ -1575,7 +1763,7 @@ sub display_cc_role {
             my %newhash=&Apache::lonnet::coursedescription($tcourseid);
             if (%newhash) {
                 $twhere=$newhash{'description'}.
-                        ' <span style="LC_fontsize_small">'.
+                        ' <span class="LC_fontsize_small">'.
                         &Apache::loncommon::syllabuswrapper(&mt('Syllabus'),$trest,$tdom).
                         '</span>';
                 $ttype = $newhash{'type'};
@@ -1662,7 +1850,7 @@ handler determines via C<lonnet>'s C<&allowed> function that a certain
 action is not allowed, C<lonroles> is used as error handler. This
 allows the user to select another role which may have permission to do
 what they were trying to do. C<lonroles> can also be accessed via the
-B<CRS> button in the Remote Control. 
+B<CRS> button in the Remote Control.
 
 =begin latex
 
