@@ -2,7 +2,7 @@
 #
 # The LearningOnline Network
 #
-# $Id: modify_config_files.pl,v 1.11 2009/07/21 20:02:47 raeburn Exp $
+# $Id: modify_config_files.pl,v 1.12 2011/05/31 02:55:15 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -200,7 +200,7 @@ if ($dist =~ /^fedora(\d+)$/) {
 my $mysql_global_status =
     &update_file('/etc/my.cnf',
              [{section =>'mysqld',
-               key     =>'set-variable=wait_timeout=',
+               key     =>'wait_timeout=',
                value   =>'31536000', }]);
 
 my $local_my_cnf = '/home/www/.my.cnf';
