@@ -1,5 +1,5 @@
 # Automated Enrollment manager
-# $Id: Enrollment.pm,v 1.42 2009/10/31 17:55:01 raeburn Exp $
+# $Id: Enrollment.pm,v 1.43 2010/08/20 21:44:59 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -775,14 +775,13 @@ sub parse_classlist {
                  push @state, $tagname;
                  if ("@state" eq "students student") {
                      $uname = $attr->{username};
+                     $$studentsref{$uname}[ $$placeref{'groupID'} ] = $groupID;
                  }
             }, "tagname, attr"],
          text_h =>
              [sub {
                  my ($text) = @_;
-                 if ("@state" eq "students student groupID") {
-                     $$studentsref{$uname}[ $$placeref{'groupID'} ] = $groupID;
-                 } elsif ("@state" eq "students student startdate") {
+                 if ("@state" eq "students student startdate") {
                      my $start = $text;
                      unless ($text eq '') {
                          $start = &process_date($text);
