@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # edit mode helpers
 #
-# $Id: edit.pm,v 1.123.4.1 2010/01/31 00:47:41 raeburn Exp $
+# $Id: edit.pm,v 1.135 2011/08/09 16:12:21 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -204,7 +204,7 @@ sub start_table {
     $Apache::edit::colordepth++;
     push(@Apache::edit::inserttag,$token->[1]);
     my $result='<div align="right">';
-    $result.='<table bgcolor="'.$color.'" width="97%" border="0" cellspacing="5" cellpadding="3">';
+    $result.='<table bgcolor="'.$color.'" width="97%" border="0" cellspacing="3" cellpadding="2">';
     return $result;
 }
 
@@ -232,7 +232,7 @@ sub end_table {
     return $result;
 }
 
-sub start_spanning_row { return '<tr><td colspan="5" bgcolor="#DDDDDD">';}
+sub start_spanning_row { return '<tr><td colspan="5" bgcolor="#F0F0F0">';}
 sub start_row          { return '<tr><td bgcolor="#DDDDDD">';            }
 sub end_row            { return '</td></tr>';          }
 
@@ -357,7 +357,7 @@ sub do_insert {
 	my $depth = scalar(@Apache::lonxml::depthcounter);
 	$depth -- if ($after);
 	my $inset = "\t"x$depth;
-	$result.="\n$inset<$newtag>\n$inset</$newtag>";
+	$result.="\n$inset<$newtag></$newtag>";
     } else {
 	if (defined(&$func)) {
 	    {
@@ -397,6 +397,47 @@ sub insert_formularesponse {
 </formularesponse>';
 }
 
+sub insert_functionplotresponse {
+    return '
+<functionplotresponse>
+<functionplotelements>
+<spline />
+</functionplotelements>
+<functionplotruleset>
+<functionplotrule />
+</functionplotruleset>
+</functionplotresponse>';
+}
+
+sub insert_spline {
+    return '
+<spline />';
+}
+
+sub insert_backgroundplot {
+    return '
+<backgroundplot />';
+}
+
+sub insert_functionplotrule {
+    return '
+<functionplotrule />';
+}
+
+sub insert_functionplotruleset {
+    return '
+<functionplotruleset>
+<functionplotrule />
+</functionplotruleset>';
+}
+
+sub insert_functionplotelements {
+    return '
+<functionplotelements>
+<spline />
+</functionplotelements>';
+}
+
 sub insert_numericalresponse {
     return '
 <numericalresponse answer="">
@@ -592,6 +633,9 @@ sub insert_matchresponse {
 </matchresponse>';
 }
 
+sub insert_startpartmarker { return '<startpartmarker />'; }
+sub insert_endpartmarker { return '<endpartmarker />'; }
+
 sub insert_displayduedate { return '<displayduedate />'; }
 sub insert_displaytitle   { return '<displaytitle />'; }
 sub insert_hintpart {
@@ -697,6 +741,12 @@ sub submit_ask_anyway {
     return ' onclick="still_ask=true;'.$extra_action.'" ';
 }
 
+sub submit_dont_ask {
+    my ($extra_action) = @_;
+    return ' onclick="is_submit=true;'.$extra_action.'" ';
+}
+
+
 sub textarea_sizes {
     my ($data)=@_;
     my $count=0;
@@ -728,27 +778,27 @@ sub editfield {
     my ($tag,$data,$description,$minwidth,$minheight,$usehtmlarea)=@_;
 
     my ($rows,$cols)=&textarea_sizes(\$data);
-    if (&Apache::lonhtmlcommon::htmlareabrowser() &&
-	!&Apache::lonhtmlcommon::htmlareablocked()) {
+    my $textareaclass;
+ 
+    if (&Apache::lonhtmlcommon::htmlareabrowser() && $usehtmlarea) { 
 	$rows+=7;      # make room for HTMLarea
 	$minheight+=7; # make room for HTMLarea
+        $textareaclass = ' class="LC_richDefaultOff"';
     }
     if ($cols > 80) { $cols = 80; }
     if ($cols < $minwidth ) { $cols = $minwidth; }
     if ($rows < $minheight) { $rows = $minheight; }
     if ($description) { $description=$description."<br />"; }
-    if ($usehtmlarea) {
-	&Apache::lonhtmlcommon::add_htmlareafields('homework_edit_'.
-						   $Apache::lonxml::curdepth);
-    }
+
     # remove typesetting whitespace from between data and the end tag
     # to make the edit look prettier
     $data =~ s/\n?[ \t]*$//;
 
-    return $description."\n".'<textarea style="width:100%" rows="'.$rows.
+    return $description."\n".'<textarea style="width:99%" rows="'.$rows.
 	'" cols="'.$cols.'" name="homework_edit_'.
 	$Apache::lonxml::curdepth.'" id="homework_edit_'.
-	$Apache::lonxml::curdepth.'" '.&element_change_detection().'>'.
+	$Apache::lonxml::curdepth.'" '.&element_change_detection().
+        $textareaclass.'>'.
 	&HTML::Entities::encode($data,'<>&"').'</textarea>'.
 	($usehtmlarea?&Apache::lonhtmlcommon::spelllink('lonhomework',
 			 'homework_edit_'.$Apache::lonxml::curdepth):'')."\n";
