@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # The LON-CAPA Homework handler
 #
-# $Id: lonhomework.pm,v 1.310.4.1 2010/08/20 03:48:29 raeburn Exp $
+# $Id: lonhomework.pm,v 1.317.4.4 2011/10/06 12:32:52 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -47,6 +47,7 @@ use Apache::externalresponse();
 use Apache::rankresponse();
 use Apache::matchresponse();
 use Apache::chemresponse();
+use Apache::functionplotresponse();
 use Apache::drawimage();
 use Apache::Constants qw(:common);
 use Apache::loncommon();
@@ -128,43 +129,46 @@ sub get_target {
 	    return ('web');
 	}
     } elsif ($env{'request.state'} eq "construct") {
+#
+# We are in construction space, editing and testing problems
+#
 	if ( defined($env{'form.grade_target'}) ) {
 	    return ($env{'form.grade_target'});
 	}
 	if ( defined($env{'form.preview'})) {
 	    if ( defined($env{'form.submitted'})) {
+#
+# We are doing a problem preview
+#
 		return ('grade', 'web');
 	    } else {
 		return ('web');
 	    }
 	} else {
 	    if ($env{'form.problemstate'} eq 'WEB_GRADE') {
-		#$env{'form.webgrade'} = 'yes';
-		return ('grade','webgrade','answer');
-	    } elsif (($env{'form.problemmode'} eq 'view') ||
-		     ($env{'form.problemmode'} eq 'discard')) {
-		if ( defined($env{'form.submitted'}) &&
-		     (!defined($env{'form.resetdata'})) &&
-		     (!defined($env{'form.newrandomization'}))) {
-		    return ('grade', 'web','answer');
-		} else {
-		    return ('web','answer');
-		}
-	    } elsif ($env{'form.problemmode'} eq 'edit') {
-		if ( $env{'form.submitted'} eq 'edit' ) {
-		    if ( $env{'form.submitbutton'} eq &mt('Save and View') ) {
-			return ('modified','web','answer');
-		    } else {
-			return ('modified','no_output_web','edit');
-		    }
-		} else {
-		    return ('no_output_web','edit');
-		}
-	    } else {
-		return ('web');
-	    }
+                return ('grade','webgrade','answer');
+            } elsif ($env{'form.problemmode'} eq 'view') {
+                return ('grade','web','answer');
+            } elsif ($env{'form.problemmode'} eq 'saveview') {
+                return ('modified','web','answer');
+            } elsif ($env{'form.problemmode'} eq 'discard') {
+                return ('web','answer');
+            } elsif (($env{'form.problemmode'} eq 'saveedit') ||
+                     ($env{'form.problemmode'} eq 'undo')) {
+                return ('modified','no_output_web','edit');
+            } elsif ($env{'form.problemmode'} eq 'edit') {
+                return ('no_output_web','edit');
+            } else {
+                return ('web');
+            }
 	}
+#
+# End of Construction Space
+#
     }
+#
+# Huh? We are nowhere, so do nothing.
+#
     return ();
 }
 
@@ -269,8 +273,8 @@ sub check_slot_access {
     }
     if ($slotstatus eq 'NEEDS_CHECKIN' &&
 	&proctor_checked_in($slot_name,$returned_slot,$type)) {
-	&Apache::lonxml::debug("protoctor checked in");
-	$slotstatus='CAN_ANSWER';
+	&Apache::lonxml::debug("proctor checked in");
+	$slotstatus=$status;
     }
 
     my ($is_correct,$got_grade,$checkedin);
@@ -382,7 +386,7 @@ sub check_access {
 	    $date=&mt("can not be accessed from your location.");
 	    return($status,$date);
 	}
-	
+
 	foreach my $temp ("opendate","duedate","answerdate") {
 	    $lastdate = $date;
 	    if ($temp eq 'duedate') {
@@ -637,11 +641,12 @@ sub setupheader {
 
 sub handle_save_or_undo {
     my ($request,$problem,$result) = @_;
+
     my $file    = &Apache::lonnet::filelocation("",$request->uri);
     my $filebak =$file.".bak";
     my $filetmp =$file.".tmp";
     my $error=0;
-    if ($env{'form.Undo'} eq &mt('undo')) {
+    if (($env{'form.problemmode'} eq 'undo') || ($env{'form.problemmode'} eq 'undoxml')) {
 	my $error=0;
 	if (!&File::Copy::copy($file,$filetmp)) { $error=1; }
 	if ((!$error) && (!&File::Copy::copy($filebak,$file))) { $error=1; }
@@ -664,6 +669,7 @@ sub handle_save_or_undo {
 	}
     } else {
         &Apache::lonnet::correct_line_ends($result);
+
 	my $fs=Apache::File->new(">$filebak");
 	if (defined($fs)) {
 	    print $fs $$problem;
@@ -692,9 +698,21 @@ sub handle_save_or_undo {
 sub analyze_header {
     my ($request) = @_;
     my $js = &Apache::structuretags::setmode_javascript();
-    my $result =
-	&Apache::loncommon::start_page('Analyzing a problem',$js);
 
+    # Breadcrumbs
+    my $brcrum = [{'href' => &Apache::loncommon::authorspace(),
+                   'text' => 'Construction Space'},
+                  {'href' => '',
+                   'text' => 'Problem Testing'},
+                  {'href' => '',
+                   'text' => 'Analyzing a problem'}];
+
+    my $result =
+        &Apache::loncommon::start_page('Analyzing a problem',
+                                       $js,
+                                       {'bread_crumbs' => $brcrum,})
+       .&Apache::loncommon::head_subbox(
+                &Apache::loncommon::CSTR_pageheader());
     $result .= 
 	&Apache::lonxml::message_location().'
             <form name="lonhomework" method="post" action="'.
@@ -707,10 +725,10 @@ sub analyze_header {
             'onclick="javascript:setmode(this.form,'."'editxml'".')" />
             <input type="button" name="submitmode" value="'.&mt('Edit').'" '.
             'onclick="javascript:setmode(this.form,'."'edit'".')" />
-            <hr class="LC_edit_problem_divide" />
+            <hr />
             <input type="button" name="submitmode" value="'.&mt("View").'" '.
             'onclick="javascript:setmode(this.form,'."'view'".')" />
-            <hr class="LC_edit_problem_divide" />
+            <hr />
             </div>
             </form>';
     &Apache::lonxml::add_messages(\$result);
@@ -784,7 +802,7 @@ sub analyze {
     }
     &Apache::lonhtmlcommon::Update_PrgWin($request,\%prog_state,
 					  &mt('Analyzing Results'));
-    $request->print('<hr class="LC_edit_problem_divide" />'
+    $request->print('<hr />'
                    .'<h3>'
                    .&mt('List of possible answers')
                    .'</h3>'
@@ -888,20 +906,22 @@ sub editxmlmode {
     my $problem=&Apache::lonnet::getfile($file);
     if ($problem eq -1) {
 	&Apache::lonxml::error(
-            '<b> '
+            '<p class="LC_error">'
            .&mt('Unable to find [_1]',
                 '<span class="LC_filename">'.$file.'</span>')
-           .'</b>');
+           .'</p>');
 
 	$problem='';
     }
-    if (defined($env{'form.editxmltext'}) || defined($env{'form.Undo'})) {
+    if (($env{'form.problemmode'} eq 'saveeditxml') ||
+        ($env{'form.problemmode'} eq 'saveviewxml') ||
+        ($env{'form.problemmode'} eq 'undoxml')) {
 	my $error=&handle_save_or_undo($request,\$problem,
 				       \$env{'form.editxmltext'});
 	if (!$error) { $problem=&Apache::lonnet::getfile($file); }
     }
     &Apache::lonhomework::showhashsubset(\%env,'^form');
-    if ( $env{'form.submitbutton'} eq &mt('Save and View') ) {
+    if ($env{'form.problemmode'} eq 'saveviewxml') {
 	&Apache::lonhomework::showhashsubset(\%env,'^form');
 	$env{'form.problemmode'}='view';
 	&renderpage($request,$file);
@@ -916,8 +936,13 @@ sub editxmlmode {
             &Apache::structuretags::setmode_javascript().
             &Apache::lonhtmlcommon::dragmath_js("EditMathPopup");
 	my $only_body =  ($env{'environment.remote'} eq 'off')? 0 : 1;
-	my $dragmath_button = 
-            &Apache::lonhtmlcommon::dragmath_button("LC_editxmltext",1);
+
+    # Breadcrumbs
+    my $brcrum = [{'href' => &Apache::loncommon::authorspace(),
+                   'text' => 'Construction Space'},
+                  {'href' => '',
+                   'text' => 'Problem Editing'}];
+
 	my $start_page = 
 	    &Apache::loncommon::start_page(&mt("EditXML [_1]",$file),$js,
 					   {'no_auto_mt_title' => 1,
@@ -925,37 +950,30 @@ sub editxmlmode {
 					    'add_entries'      => {
 						'onresize' => q[resize_textarea('LC_editxmltext','LC_aftertextarea')],
 						'onload'   => q[resize_textarea('LC_editxmltext','LC_aftertextarea')],
-				    }});
-	$result.=$start_page.
-	    &renderpage($request,$file,['no_output_web'],1).
+                                    },
+                                                'bread_crumbs' => $brcrum,
+                                           });
+
+    $result=$start_page
+           .&Apache::loncommon::head_subbox(
+                &Apache::loncommon::CSTR_pageheader());
+	$result.=&renderpage($request,$file,['no_output_web'],1).
             '<form '.&Apache::edit::form_change_detection().' name="lonhomework" method="post" action="'.
 	    &HTML::Entities::encode($env{'request.uri'},'<>&"').'">'.
 	    &Apache::structuretags::remember_problem_state().'
             <div class="LC_edit_problem_editxml_header">
               <table class="LC_edit_problem_header_title"><tr><td>
-               '.&mt('Problem Editing').&Apache::loncommon::help_open_topic('Problem_Editor_XML_Index').'
+               <h2>'.&mt('Problem Editing').' '.&Apache::loncommon::help_open_topic('Problem_Editor_XML_Index').'</h2>
                 </td><td align="right">
                   '.&Apache::loncommon::helpLatexCheatsheet('Problem_LON-CAPA_Functions','Script Functions').'
                 </td></tr>
-              </table>
-              <div class="LC_edit_problem_discards">
-                <input type="hidden" name="problemmode" value="editxml" />
+              </table>';
 
-                <input type="button" name="submitmode" accesskey="d" value="'.&mt('Discard Edits and View').'" '.
-                'onclick="javascript:setmode(this.form,'."'discard'".')" />
-                <input type="button" '.&Apache::edit::submit_ask_anyway('setmode(this.form,'."'edit'".')').'name="submitmode" accesskey="e" value="'.&mt('Edit').'" />
-                <input type="submit" name="Undo" accesskey="u" value="'.&mt('undo').'" />
-                '.$dragmath_button.'
-              </div>
-              <div class="LC_edit_problem_saves">
-                <input type="submit" name="submitbutton" accesskey="s" value="'.&mt('Save').'"  />
-                <input type="submit" name="submitbutton" accesskey="v" value="'.&mt('Save and View').'" />
-              </div>
-              <hr class="LC_edit_problem_divide" />
-	      '.&Apache::lonxml::message_location().'
-            </div>
-            '  . '
-            <textarea '.&Apache::edit::element_change_detection().
+         $result.='<input type="hidden" name="problemmode" value="saveedit" />'.
+                  &Apache::structuretags::problem_edit_buttons('editxml');
+
+         $result.='<hr style="clear:both;" />'.&Apache::lonxml::message_location().'</div>'.
+                  '<textarea '.&Apache::edit::element_change_detection().
 	              ' rows="'.$rows.'" cols="'.$cols.'" style="width:100%" '.
 		      ' name="editxmltext" id="LC_editxmltext">'.
 		      &HTML::Entities::encode($problem,'<>&"').'</textarea>
@@ -998,9 +1016,10 @@ sub renderpage {
 	    $problem='';
 	    my $filename=(split('/',$file))[-1];
 	    my $error =
-		"<b> ".&mt('Unable to find [_1]',
+                '<p class="LC_error">'
+                .&mt('Unable to find [_1]',
 			   '<span class="LC_filename">'.$filename.'</span>')
-		."</b>";
+		."</p>";
 	    $result.=
 		&Apache::loncommon::simple_error_page($request,'Not available',
 						      $error);
@@ -1081,15 +1100,21 @@ sub get_template_list {
     }
     my $count = 0;
     my $currentcategory='';
+    my $first = 1;
     foreach my $file (@files) {
 	next if ($file->[1] !~ /\S/);
         if ($file->[2] ne $currentcategory) {
            $currentcategory=$file->[2];
            if ((!$seconddiv) && ($count >= $midpoint)) {
-               $result .= '</div>'."\n".'<div class="LC_left_float">'."\n";
+               $result .= '</div></div>'."\n".'<div class="LC_left_float">'."\n";
                $seconddiv = 1;
+           } elsif (!$first) {
+               $result.='</div>'."\n";
+           } else {
+               $first = 0;
            }
-           $result.='<h3>'.$currentcategory.'</h3>';
+           $result.= '<div class="LC_Box">'."\n"
+                    .'<h3 class="LC_hcell">'.$currentcategory.'</h3>'."\n";
            $count++;
         }
 	$result .=
@@ -1100,11 +1125,13 @@ sub get_template_list {
         }
         my $filename=$file->[0];
         $filename=~s/^\/home\/httpd\/html//;
-        $result.=' <font size="-2"><a href="'.$filename.'" target="sample">'.&mt('Example').'</font></a><br />'."\n";
+        $result.=' <span class="LC_fontsize_small">'
+                .'<a href="'.$filename.'?inhibitmenu=yes" target="sample">'.&mt('Example').'</a>'
+                .'</span><br />'."\n";
         $count ++;
     }
     if ($numfiles > 0) {
-        $result .= '</div>'."\n".'<div class="LC_clear_float_footer"></div>'."\n";
+        $result .= '</div></div>'."\n".'<div class="LC_clear_float_footer"></div>'."\n";
     }
     return $result;
 }
@@ -1138,26 +1165,33 @@ sub newproblem {
 	my $dest = &Apache::lonnet::filelocation("",$request->uri);
 	my $errormsg;
 	my $instructions;
+        my $brcrum = [{'href' => &Apache::loncommon::authorspace(),
+                       'text' => 'Construction Space'},
+                      {'href' => '',
+                       'text' => "Create New $extension"}];
 	my $start_page = 
-	    &Apache::loncommon::start_page("Create New $extension");
-	$request->print("
-$start_page
-<h1>".&mt("Creating a new $extension resource.")."</h1>
+            &Apache::loncommon::start_page("Create New $extension",
+                                           undef,
+                                           {'bread_crumbs' => $brcrum,});
+	$request->print(
+        $start_page
+       .&Apache::loncommon::head_subbox(
+                &Apache::loncommon::CSTR_pageheader())
+       .'<h1>'.&mt("Creating a new $extension resource.")."</h1>
 $errormsg
 ".&mt("The requested file [_1] currently does not exist.",
-      '<span class="LC_filename">'.$shownurl.'</span>')."
-<p>
-<b>
-".&mt("To create a new $extension, select a template from the".
-      " list below. Then click on the \"Create $extension\" button.").'</b>
-</p><form action="'.$url.'" method="post">');
+      '<span class="LC_filename">'.$shownurl.'</span>').'
+<p class="LC_info">
+'.&mt("To create a new $extension, select a template from the".
+      " list below. Then click on the \"Create $extension\" button.").'
+</p><div><form action="'.$url.'" method="post">');
 
 	if (defined($templatelist)) {
 	    $request->print($templatelist);
 	}
 	$request->print('<br /><input type="submit" name="newfile" value="'.
 			&mt("Create $extension").'" />');
-	$request->print("</form></p>".&Apache::loncommon::end_page());
+	$request->print('</form></div>'.&Apache::loncommon::end_page());
     }
     return;
 }
@@ -1217,8 +1251,11 @@ sub handler {
 		#first visit to problem in construction space
 		$env{'form.problemmode'}= 'view';
 		&renderpage($request,$file);
-	    } elsif ($env{'form.problemmode'} eq 'editxml') {
-		&editxmlmode($request,$file);
+            } elsif (($env{'form.problemmode'} eq 'editxml') ||
+                     ($env{'form.problemmode'} eq 'saveeditxml') ||
+                     ($env{'form.problemmode'} eq 'saveviewxml') ||
+                     ($env{'form.problemmode'} eq 'undoxml')) {
+                &editxmlmode($request,$file);
 	    } elsif ($env{'form.problemmode'} eq 'calcanswers') {
 		&analyze($request,$file);
 	    } else {
