@@ -1,7 +1,7 @@
 # LearningOnline Network with CAPA
 # option list style responses
 #
-# $Id: optionresponse.pm,v 1.173 2010/12/19 00:52:00 raeburn Exp $
+# $Id: optionresponse.pm,v 1.173.2.2 2011/11/08 19:38:05 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -155,13 +155,9 @@ ENDTABLE
       splice(@options,$delopt-1,1);
       $optchanged=1;
     }
-    if ($env{"form.$Apache::lonxml::curdepth.options"}) {
+    if ($env{"form.$Apache::lonxml::curdepth.options"} ne '') {
       my $newopt = $env{"form.$Apache::lonxml::curdepth.options"};
-      if ($options[0]) {
-	push(@options,$newopt);
-      } else {
-	$options[0]=$newopt;
-      }
+      push(@options,$newopt);
       $optchanged=1;
     }
     my $rebuildtag = &Apache::edit::get_new_args($token,$parstack,$safeeval,
@@ -213,7 +209,7 @@ sub end_foilgroup {
     my $randomize = &Apache::lonxml::get_param('randomize',$parstack,
 					       $safeeval,'-2');
     if ($target eq 'web' || $target eq 'tex') {
-      $result.=&displayfoils($target,$max,$randomize,$TeXlayout,$checkboxvalue,$checkboxchoices,@opt);
+      $result.=&displayfoils($target,$max,$randomize,$TeXlayout,$checkboxvalue,$checkboxchoices,$tex_option_switch,@opt);
       $Apache::lonxml::post_evaluate=0;
     } elsif ( $target eq 'answer') {
       $result.=&displayanswers($max,$randomize,@opt);
@@ -421,7 +417,8 @@ sub check_for_invalid {
 }
 
 sub displayfoils {
-  my ($target,$max,$randomize,$TeXlayout,$checkboxvalue,$checkboxchoices,@opt)=@_;
+  my ($target,$max,$randomize,$TeXlayout,$checkboxvalue,$checkboxchoices,
+      $tex_option_switch,@opt)=@_;
   if (!defined(@{ $Apache::response::foilgroup{'names'} })) {return;}
   my @names = @{ $Apache::response::foilgroup{'names'} };
   my @truelist;
@@ -431,7 +428,9 @@ sub displayfoils {
   my $displayoptionintex=1;
   my @alphabet = ('A'..'Z');
   my @whichopt = &whichfoils($max,$randomize);
-  &check_for_invalid(\@whichopt,\@opt);
+  unless (($target eq 'tex') && ($tex_option_switch eq 'nochoice')) {
+      &check_for_invalid(\@whichopt,\@opt);
+  }
   my $part=$Apache::inputtags::part;
   my $id=$Apache::inputtags::response[-1];
   my $break;
