@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # randomlabel.png: composite together text and images into 1 image
 #
-# $Id: randomlylabel.pm,v 1.30 2007/09/25 23:16:13 albertel Exp $
+# $Id: randomlylabel.pm,v 1.31 2008/12/19 14:28:14 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -213,8 +213,8 @@ sub get_image {
     my ($imgsrc,$set_trans)=@_;
     my $image;
     if ($imgsrc !~ m|^(/home/)|) {
-	if ($imgsrc !~ /^http:/) {
-	    $imgsrc="http://".$ENV{'HTTP_HOST'}.$imgsrc;
+	if ($imgsrc !~ /^https?\:/) {
+	    $imgsrc=&Apache::lonnet::absolute_url($ENV{'HTTP_HOST'}).$imgsrc;
 	}
 	my $ua=new LWP::UserAgent;
 	my $request=new HTTP::Request('GET',"$imgsrc");
