@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # various response type definitons response definition
 #
-# $Id: response.pm,v 1.216 2009/05/24 13:08:18 www Exp $
+# $Id: response.pm,v 1.221.2.2 2011/11/29 18:44:31 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -30,7 +30,7 @@
 
 =head1 NAME
 
-Apache::resonse.pm
+Apache::response.pm
 
 =head1 SYNOPSIS
 
@@ -136,9 +136,10 @@ sub poprandomnumber {
 }
 
 sub setrandomnumber {
-    my ($ignore_id2) = @_;
-    my $rndseed;
-    $rndseed=&Apache::structuretags::setup_rndseed();
+    my ($ignore_id2,$target,$rndseed) = @_;
+    if (!defined($rndseed)) {
+        $rndseed=&Apache::structuretags::setup_rndseed(undef,$target);
+    } 
     if (!defined($rndseed)) { $rndseed=&Apache::lonnet::rndseed(); }
     &Apache::lonxml::debug("randseed $rndseed");
     #  $rndseed=unpack("%32i",$rndseed);
@@ -280,9 +281,11 @@ sub meta_response_order {
 }
 
 sub check_for_previous {
-    my ($curresponse,$partid,$id,$last) = @_;
+    my ($curresponse,$partid,$id,$last,$type) = @_;
     my %previous;
     $previous{'used'} = 0;
+    my $questiontype = $Apache::lonhomework::type;
+    my $curr_rndseed = $env{'form.'.$partid.'.rndseed'};
     foreach my $key (sort(keys(%Apache::lonhomework::history))) {
 	if ($key =~ /resource\.\Q$partid\E\.\Q$id\E\.submission$/) {
 	    if ( $last && $key =~ /^(\d+):/ ) {
@@ -291,21 +294,38 @@ sub check_for_previous {
 	    &Apache::lonxml::debug("Trying $key");
 	    my $pastresponse=$Apache::lonhomework::history{$key};
 	    if ($pastresponse eq $curresponse) {
-		$previous{'used'} = 1;
 		my $history;
 		if ( $key =~ /^(\d+):/ ) {
-		    $history=$1;
+                    $history=$1;
+                    next if ((($questiontype eq 'randomizetry') ||
+                             ($Apache::lonhomework::history{"$history:resource.$partid.type"} eq 'randomizetry')) &&
+                             ($curr_rndseed ne $Apache::lonhomework::history{"$history:resource.$partid.rndseed"}));
 		    $previous{'award'} = $Apache::lonhomework::history{"$history:resource.$partid.$id.awarddetail"};
 		    $previous{'last'}='0';
 		    push(@{ $previous{'version'} },$history);
 		} else {
+                    next if ((($questiontype eq 'randomizetry') ||
+                             ($Apache::lonhomework::history{"resource.$partid.type"} eq 'randomizetry')) &&
+                             ($curr_rndseed ne $Apache::lonhomework::history{"resource.$partid.rndseed"}));
 		    $previous{'award'} = $Apache::lonhomework::history{"resource.$partid.$id.awarddetail"};
 		    $previous{'last'}='1';
 		}
+                $previous{'used'} = 1;
 		if (! $previous{'award'} ) { $previous{'award'} = 'UNKNOWN';	}
                 if ($previous{'award'} eq 'INTERNAL_ERROR') { $previous{'used'}=0; }
 		&Apache::lonxml::debug("got a match :$previous{'award'}:$previous{'used'}:");
-	    }
+            } elsif ($type eq 'ci') {
+                if (lc($pastresponse) eq lc($curresponse)) {
+                    if ($key =~ /^(\d+):/) {
+                        my $history = $1;
+                        next if (($questiontype eq 'randomizetry') &&
+                             ($curr_rndseed ne $Apache::lonhomework::history{"$history:resource.$partid.rndseed"}));
+                        push (@{$previous{'versionci'}},$history);
+                        $previous{'awardci'} = $Apache::lonhomework::history{"$history:resource.$partid.$id.awarddetail"};
+                        $previous{'usedci'} = 1;
+                    }
+                }
+            }
 	}
     }
     &Apache::lonhomework::showhash(%previous);
@@ -318,7 +338,10 @@ sub handle_previous {
 	if ($$previous{'last'}) {
 	    push(@Apache::inputtags::previous,'PREVIOUSLY_LAST');
 	    push(@Apache::inputtags::previous_version,$$previous{'version'});
-	} elsif ($Apache::lonhomework::type ne 'survey') {
+	} elsif (($Apache::lonhomework::type ne 'survey') &&
+                 ($Apache::lonhomework::type ne 'surveycred') &&
+                 ($Apache::lonhomework::type ne 'anonsurvey') &&
+                 ($Apache::lonhomework::type ne 'anonsurveycred')) {
 	    push(@Apache::inputtags::previous,'PREVIOUSLY_USED');
 	    push(@Apache::inputtags::previous_version,$$previous{'version'});
 	}
@@ -399,7 +422,7 @@ sub start_customresponse {
     } elsif ($target eq 'edit') {
 	$result.=&Apache::edit::tag_start($target,$token);
 	$result.=&Apache::edit::text_arg('String to display for answer:',
-					 'answerdisplay',$token);
+					 'answerdisplay',$token,'50');
 	$result.=&Apache::edit::end_row().&Apache::edit::start_spanning_row();
     } elsif ($target eq 'modified') {
 	my $constructtag;
@@ -466,7 +489,7 @@ sub end_customresponse {
 	$result .= &Apache::response::answer_footer('customresponse');
     }
     if ($target eq 'web') {
-	&setup_prior_tries_hash(\&format_prior_response_math);
+	&setup_prior_tries_hash(\&format_prior_response_custom);
     }
     if ($target eq 'grade' || $target eq 'web' || $target eq 'answer' || 
 	$target eq 'tex' || $target eq 'analyze') {
@@ -487,6 +510,9 @@ sub end_customresponse {
 
 sub format_prior_response_custom {
     my ($mode,$answer) =@_;
+    if (ref($answer) eq 'ARRAY') {
+        $answer = '('.join(', ', @{ $answer }).')';
+    }
     return '<span class="LC_prior_custom">'.
 	    &HTML::Entities::encode($answer,'"<>&').'</span>';
 }
@@ -509,7 +535,7 @@ sub start_mathresponse {
     } elsif ($target eq 'edit') {
 	$result.=&Apache::edit::tag_start($target,$token);
 	$result.=&Apache::edit::text_arg('String to display for answer:',
-					 'answerdisplay',$token);
+					 'answerdisplay',$token,'50');
 	$result.=&Apache::edit::select_arg('Algebra System:',
 					   'cas',
 					   ['maxima','R'],
@@ -907,6 +933,10 @@ sub showallfoils {
 	}
     }
     if ($Apache::lonhomework::type eq 'survey') { return 1; }
+    if ($Apache::lonhomework::type eq 'surveycred') { return 1; }
+    if ($Apache::lonhomework::type eq 'anonsurvey') { return 1; }
+    if ($Apache::lonhomework::type eq 'anonsurveycred') { return 1; }
+
     return 0;
 }
 
@@ -1061,7 +1091,7 @@ sub scored_response {
 }
 
 sub whichorder {
-    my ($max,$randomize,$showall,$hash)=@_;
+    my ($max,$randomize,$showall,$hash,$rndseed)=@_;
     #&Apache::lonxml::debug("man $max randomize $randomize");
     if (!defined(@{ $$hash{'names'} })) { return; }
     my @names = @{ $$hash{'names'} };
@@ -1301,25 +1331,40 @@ sub check_status {
     - scalars that are other elements of the history hash to pass to $func
     - ref to data to be passed untouched to $func
 
+  $questiontype is the questiontype (currently only passed in if
+      randomizebytry.
+
 =cut
 
 sub setup_prior_tries_hash {
-    my ($func,$data) = @_;
+    my ($func,$data,$questiontype) = @_;
     my $part = $Apache::inputtags::part;
-    my $id   = $Apache::inputtags::response[-1];	
+    my $id   = $Apache::inputtags::response[-1];
     foreach my $i (1..$Apache::lonhomework::history{'version'}) {
-	my $sub_key   = "$i:resource.$part.$id.submission";
+        my $partprefix = "$i:resource.$part";
+	my $sub_key   = "$partprefix.$id.submission";
 	next if (!exists($Apache::lonhomework::history{$sub_key}));
+        my $type_key = "$partprefix.type";
+        my $type = $Apache::lonhomework::history{$type_key};
 	my @other_data;
-	foreach my $datum (@{ $data }) {
-	    if (ref($datum)) {
-		push(@other_data,$datum);
-	    } else {
-		my $info_key = "$i:resource.$part.$id.$datum";
-		push(@other_data,$Apache::lonhomework::history{$info_key});
+        if (ref($data) eq 'ARRAY') {
+	    foreach my $datum (@{ $data }) {
+	        if (ref($datum)) {
+		    push(@other_data,$datum);
+	        } else {
+		    my $info_key = "$i:resource.$part.$id.$datum";
+		    push(@other_data,$Apache::lonhomework::history{$info_key});
+	        }
 	    }
-	}
-
+        }
+        if ($questiontype eq 'randomizetry') { 
+            my $order_key = "$partprefix.$id.foilorder";
+            my @whichopts = &Apache::lonnet::str2array($Apache::lonhomework::history{$order_key});
+            if (@whichopts > 0) {
+                shift(@other_data);
+                unshift(@other_data,\@whichopts);
+            }
+        }
 	my $output =
 	    &$func('grade',
 		   $Apache::lonhomework::history{$sub_key},
