@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # definition of tags that give a structure to a document
 #
-# $Id: structuretags.pm,v 1.444.4.6 2010/02/10 21:06:07 raeburn Exp $
+# $Id: structuretags.pm,v 1.465.2.14 2011/10/06 03:23:44 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -66,7 +66,7 @@ use lib '/home/httpd/lib/perl/';
 use LONCAPA;
  
 BEGIN {
-    &Apache::lonxml::register('Apache::structuretags',('block','languageblock','translated','instructorcomment','while','randomlist','problem','library','web','tex','part','preduedate','postanswerdate','solved','notsolved','problemtype','startouttext','endouttext','simpleeditbutton','definetag'));
+    &Apache::lonxml::register('Apache::structuretags',('block','languageblock','translated','instructorcomment','while','randomlist','problem','library','web','tex','part','preduedate','postanswerdate','solved','notsolved','problemtype','startpartmarker','startouttext','endpartmarker','endouttext','simpleeditbutton','definetag'));
 }
 
 sub start_web {
@@ -128,8 +128,17 @@ sub homework_js {
            &setmode_javascript().
 	<<'JS';
 <script type="text/javascript">
-function setSubmittedPart (part) {
-   this.document.lonhomework.submitted.value="part_"+part;
+// <![CDATA[
+function setSubmittedPart (part,prefix) {
+    if (typeof(prefix) == 'undefined') {
+        this.document.lonhomework.submitted.value="part_"+part;
+    } else {
+        for (var i=0;i<this.document.lonhomework.elements.length;i++) {
+            if (this.document.lonhomework.elements[i].name == prefix+'submitted') {
+                this.document.lonhomework.elements[i].value="part_"+part;
+            }
+        }
+    }
 }
 
 function image_response_click (which, e) {
@@ -145,7 +154,7 @@ function image_response_click (which, e) {
     input_element.value = click;
     img_element.src = '/adm/randomlabel.png?token='+token+'&clickdata='+click;
 }
-
+// ]]>
 </script>
 JS
 }
@@ -153,10 +162,55 @@ JS
 sub setmode_javascript {
     return <<"ENDSCRIPT";
 <script type="text/javascript">
+// <![CDATA[
 function setmode(form,probmode) {
     form.problemmode.value = probmode;
     form.submit();
 }
+// ]]>
+</script>
+ENDSCRIPT
+}
+
+sub file_delchk_js {
+    my $delfilewarn = &mt('You have indicated you wish to remove some files previously included in your submission.').'\\n'.
+                      &mt('Continue submission with these files removed?');
+    return <<"ENDSCRIPT";
+<script type="text/javascript">
+// <![CDATA[
+function file_deletion_check(formname) {
+    var elemnum = formname.elements.length;
+    if (elemnum == 0) {
+        return true;
+    }
+    var str = new RegExp("^HWFILE.+_delete\$");
+    var delboxes = new Array();
+    for (i=0; i<formname.elements.length; i++) {
+        var id = formname.elements[i].id;
+        if (id != '') {
+            if (str.test(id)) {
+                if (formname.elements[i].type == 'checkbox') {
+                    if (formname.elements[i].checked) {
+                        delboxes.push(id);
+                    }
+                }
+            }
+        }
+    }
+    if (delboxes.length > 0) {
+        if (confirm("$delfilewarn")) {
+            return true;
+        } else {
+            for (var j=0; j<delboxes.length; j++) {
+                formname.elements[delboxes[j]].checked = false;
+            }
+            return false;
+        }
+    } else {
+        return true;
+    }
+}
+// ]]>
 </script>
 ENDSCRIPT
 }
@@ -177,12 +231,17 @@ sub page_start {
 					   $parstack,$parser,$safeeval);
     }
 
-    $extra_head .= &homework_js();
-
-    if ($env{'environment.wysiwygeditor'} eq 'on') {
-	$extra_head .= &Apache::lonhtmlcommon::dragmath_js("FCKEditMathPopup");
-    } else {
-        $extra_head .= &Apache::lonhtmlcommon::dragmath_js("EditMathPopup");
+    $extra_head .= &homework_js().
+                   &Apache::lonhtmlcommon::dragmath_js("EditMathPopup");
+    if (&Apache::lonhtmlcommon::htmlareabrowser()) {
+        my %textarea_args = (
+                                dragmath => 'math',
+                              );
+        $extra_head .= &Apache::lonhtmlcommon::htmlareaselectactive(\%textarea_args);
+    }
+    my $is_task = ($env{'request.uri'} =~ /\.task$/);
+    if ($is_task) {
+        $extra_head .= &file_delchk_js();
     }
 
     my %body_args;
@@ -203,6 +262,7 @@ sub page_start {
 	}
     }
 
+    my $pageheader = '';
     if (defined($found{'body'})) {
 	$body_args{'skip_phases'}{'body'}=1;
     } elsif (!defined($found{'body'}) 
@@ -211,6 +271,22 @@ sub page_start {
 	    if ($env{'environment.remote'} ne 'off') {
 		$body_args{'only_body'}  = 1;
 	    }
+        # Breadcrumbs for Construction Space
+        &Apache::lonhtmlcommon::clear_breadcrumbs();
+        &Apache::lonhtmlcommon::add_breadcrumb({
+            'text'  => 'Construction Space',
+            'href'  => &Apache::loncommon::authorspace(),
+        });
+        # breadcrumbs (and tools) will be created 
+        # in start_page->bodytag->innerregister
+
+# FIXME Where are we?
+#        &Apache::lonhtmlcommon::add_breadcrumb({
+#            'text'  => 'Problem Editing', # 'Problem Testing'
+#            'href'  => '',
+#        });
+        $pageheader =&Apache::loncommon::head_subbox(
+                &Apache::loncommon::CSTR_pageheader());
 	}
     } elsif (!defined($found{'body'})) {
 	my %add_entries;
@@ -222,27 +298,27 @@ sub page_start {
 
 	my $bgcolor=&Apache::lonxml::get_param('bgcolor',$parstack,
 					       $safeeval);
-       	if ($bgcolor eq '' ) { $bgcolor = '#FFFFFF'; }
+        if ($bgcolor eq '' ) { $bgcolor = '#FFFFFF'; }
 
-	$body_args{'bgcolor'}        = $bgcolor;
-	$body_args{'no_title'}       = 1;
-	$body_args{'force_register'} = 1;
-	$body_args{'add_entries'}    = \%add_entries;	
-	if ($env{'environment.remote'} eq 'off'
-	    && $env{'request.state'} eq   'construct') {
-	    $body_args{'only_body'}  = 1;
-	}
+        $body_args{'bgcolor'}        = $bgcolor;
+        # $body_args{'no_title'}       = 1;
+        $body_args{'force_register'} = 1;
+        $body_args{'add_entries'}    = \%add_entries;
+        if ($env{'environment.remote'} eq 'off'
+            && $env{'request.state'} eq   'construct') {
+            $body_args{'only_body'}  = 1;
+        }
     }
     $body_args{'no_auto_mt_title'} = 1;
     my $page_start = &Apache::loncommon::start_page($name,$extra_head,
 						    \%body_args);
-
+    $page_start .= $pageheader;
     if (!defined($found{'body'}) 
 	&& $env{'request.state'} ne 'construct'
 	&& ($target eq 'web' || $target eq 'webgrade')) {
 
 	my ($symb,undef,undef,undef,$publicuser)= &Apache::lonnet::whichuser();
-	if ($symb eq '' && !$publicuser) {
+        if ($symb eq '' && !$publicuser) {
             $page_start .= '<p class="LC_info">'
                           .&mt('Browsing resource, all submissions are temporary.')
                           .'</p>';
@@ -256,13 +332,16 @@ sub page_start {
     my $form_tag_start;
     if (!defined($found{'form'})) {
 	$form_tag_start='<form name="lonhomework" enctype="multipart/form-data" method="post" action="';
-        my $uri = Apache::loncommon::inhibit_menu_check(
+	my $uri = &Apache::loncommon::inhibit_menu_check(
                 &Apache::lonenc::check_encrypt($env{'request.uri'}));
         $uri = &HTML::Entities::encode($uri,'<>&"');
 	$form_tag_start.=$uri.'" ';
 	if ($target eq 'edit') {
 	    $form_tag_start.=&Apache::edit::form_change_detection();
 	}
+        if ($is_task) {
+            $form_tag_start .= ' onsubmit="return file_deletion_check(this);"';
+        }
 	$form_tag_start.='>'."\n";
 
 	my $symb=&Apache::lonnet::symbread();
@@ -304,9 +383,15 @@ sub get_resource_name {
 }
 
 sub setup_rndseed {
-    my ($safeeval)=@_;
-    my $rndseed;
+    my ($safeeval,$target)=@_;
     my ($symb)=&Apache::lonnet::whichuser();
+    my ($questiontype,$set_safespace,$rndseed);
+    if ($target eq 'analyze') {
+        $questiontype = $env{'form.grade_questiontype'};
+    }
+    unless (defined($questiontype)) {
+        $questiontype = $Apache::lonhomework::type;
+    }
     if ($env{'request.state'} eq "construct" 
 	|| $symb eq '' 
 	|| $Apache::lonhomework::type eq 'practice'
@@ -321,6 +406,14 @@ sub setup_rndseed {
 	    }
 	    $env{'form.rndseed'}=$rndseed;
 	}
+        if (($env{'request.state'} eq "construct") &&
+            ($Apache::lonhomework::type eq 'randomizetry')) {
+            my $tries = $Apache::lonhomework::history{"resource.$Apache::inputtags::part.tries"};
+            if ($tries) {
+                $rndseed += $tries;
+            }
+            $env{'form.'.$Apache::inputtags::part.'.rndseed'}=$rndseed;
+        }
 	if ( ($env{'form.resetdata'} eq &mt('New Problem Variation')
 	      && $env{'form.submitted'} eq 'yes')  ||
 	    $env{'form.newrandomization'} eq &mt('New Randomization')) {
@@ -336,10 +429,42 @@ sub setup_rndseed {
         if ($Apache::lonhomework::history{'resource.CODE'}) {
 	   $rndseed=&Apache::lonnet::rndseed();
 	}
-	if ($safeeval) {
-	    &Apache::lonxml::debug("Setting rndseed to $rndseed");
-	    &Apache::run::run('$external::randomseed="'.$rndseed.'";',$safeeval);
-	}
+        $set_safespace = 1;
+    } elsif ($questiontype eq 'randomizetry') {
+        if ($target eq 'analyze') {
+            if (defined($env{'form.grade_rndseed'})) {
+                $rndseed = $env{'form.grade_rndseed'};
+            }
+        }
+        unless (($target eq 'analyze') && (defined($rndseed))) {
+            $rndseed=&Apache::lonnet::rndseed();
+            my $curr_try = $Apache::lonhomework::history{"resource.$Apache::inputtags::part.tries"};
+            if ($Apache::inputtags::status[-1] eq 'CAN_ANSWER') {
+                $curr_try ++;
+            }
+            if ($rndseed =~/^(\d+)[,:](\d+)$/) {
+                $rndseed = $1;
+            }
+            if ($curr_try) {
+                my $reqtries = &Apache::lonnet::EXT("resource.$Apache::inputtags::part.randomizeontries");
+                if (($reqtries =~ /^\d+$/) && ($reqtries > 1)) {
+                    my $inc = int(($curr_try-1)/$reqtries);
+                    $rndseed += $inc;
+                } else {
+                    $rndseed += $curr_try;
+                }
+            }
+        }
+        $set_safespace = 1;
+    }
+    if ($set_safespace) {
+        if ($safeeval) {
+            &Apache::lonxml::debug("Setting rndseed to $rndseed");
+            &Apache::run::run('$external::randomseed="'.$rndseed.'";',$safeeval);
+        }
+    }
+    unless (($env{'request.state'} eq "construct") || ($symb eq '')) {
+        $env{'form.'.$Apache::inputtags::part.'.rndseed'}=$rndseed;
     }
     return $rndseed;
 }
@@ -351,45 +476,64 @@ sub remember_problem_state {
        <input type="hidden" name="problemstatus" value="'.$env{'form.problemstatus'}.'" />';
 }
 
+sub problem_edit_action_button {
+    my ($name,$action,$accesskey,$text,$flag)=@_;
+    my $actionscript="setmode(this.form,'$action')";
+    return "\n<input type='button' name='$name' accesskey='$accesskey' value='".&mt($text)."'".
+           ($flag?&Apache::edit::submit_ask_anyway($actionscript):&Apache::edit::submit_dont_ask($actionscript))." />";
+}
+
 sub problem_edit_buttons {
-   return  '
-<div class="LC_edit_problem_discards">
-       <input type="button" name="submitmode" accesskey="d" value="'.&mt('Discard Edits and View').'" '.
-       ' onclick="javscript:setmode(this.form,'."'discard'".')"  />
-       <input '.&Apache::edit::submit_ask_anyway('setmode(this.form,'."'editxml'".')').' type="button" name="submitmode" accesskey="x" value="'.&mt('EditXML').'" />
-       <input type="submit" name="Undo" accesskey="u" value="'.&mt('undo').'" />
-</div>
-<div class="LC_edit_problem_saves">
-       <input type="submit" name="submitbutton" accesskey="s" value="'.&mt('Save and Edit').'" />
-       <input type="submit" name="submitbutton" accesskey="v" value="'.&mt('Save and View').'" />
-</div>';
+    my ($mode)=@_;
+# Buttons that do not save
+    my $result='<div class="LC_edit_problem_discards">'.
+              &problem_edit_action_button('subdiscview','discard','d','Discard Edits and View',1);
+    if ($mode eq 'editxml') {
+        $result.=&problem_edit_action_button('subedit','edit','e','Edit',1);
+        $result.=&problem_edit_action_button('subundo','undoxml','u','Undo',1);
+        $result.=&Apache::lonhtmlcommon::dragmath_button("LC_editxmltext",1);
+    } else {
+        $result.=&problem_edit_action_button('subeditxml','editxml','x','EditXML',1);
+        $result.=&problem_edit_action_button('subundo','undo','u','Undo',1);
+    }
+    $result.="\n</div>";
+# Buttons that save
+    $result.='<div class="LC_edit_problem_saves">';
+    if ($mode eq 'editxml') {
+        $result.=&problem_edit_action_button('subsaveedit','saveeditxml','s','Save and EditXML');
+        $result.=&problem_edit_action_button('subsaveview','saveviewxml','v','Save and View');
+    } else {
+        $result.=&problem_edit_action_button('subsaveedit','saveedit','s','Save and Edit');
+        $result.=&problem_edit_action_button('subsaveview','saveview','v','Save and View');
+    }
+    $result.="\n</div>\n";
+    return $result;
 }
 
 sub problem_edit_header {
-    return '<input type="hidden" name="submitted" value="edit" /><input type="hidden" name="problemmode" value="edit" />'.
-	&Apache::structuretags::remember_problem_state().'
+    return '<input type="hidden" name="submitted" value="edit" />'.
+	&remember_problem_state('edit').'
 <div class="LC_edit_problem_header">
 <div class="LC_edit_problem_header_title">
 '.&mt('Problem Editing').&Apache::loncommon::help_open_menu('Problem Editing','Problem_Editor_XML_Index',5,'Authoring').'
 </div>'.
+'<input type="hidden" name="problemmode" value="saveedit" />'.
 &problem_edit_buttons().'
-<hr class="LC_edit_problem_divide" />
+<hr style="clear:both;" />
 '.&Apache::lonxml::message_location().'
 </div>
 '.
-       '<table border="0" width="100%"><tr><td bgcolor="#DDDDDD">';
+       '<table border="0" width="100%"><tr><td bgcolor="#F8F8F8">';
 }
 
 sub problem_edit_footer {
     return '</td></tr></table><br />
 <div class="LC_edit_problem_footer">
-  <hr class="LC_edit_problem_divide" />'.
+  <hr />'.
 &problem_edit_buttons().'
-  <hr class="LC_edit_problem_divide" />
+  <hr style="clear:both;" />
 </div>
 '.
-
-    &Apache::lonhtmlcommon::htmlareaselectactive(&Apache::lonhtmlcommon::get_htmlareafields()).
     "\n</form>\n".&Apache::loncommon::end_page();
 }
 
@@ -420,10 +564,10 @@ sub problem_web_to_edit_header {
 	    '</div>';
     }
     
-    my $show_all_foils_text =
-        ($Apache::lonhomework::parsing_a_task) ?
-        &mt('Show All Instances')
-        : &mt('Show All Foils');
+    my $show_all_foils_text = 
+	($Apache::lonhomework::parsing_a_task) ?
+	&mt('Show All Instances')
+	: &mt('Show All Foils');
 
     my $show_all= '<span class="LC_nobreak"><label for="showallfoils">'
                  .'<input type="checkbox" name="showallfoils"';
@@ -455,7 +599,11 @@ sub problem_web_to_edit_header {
   ".&option('exam'   ,'problemtype').&mt("Exam Problem")."</option>
   ".&option('problem','problemtype').&mt("Homework Problem")."</option>
   ".&option('survey' ,'problemtype').&mt("Survey Question")."</option>
+  ".&option('surveycred' ,'problemtype').&mt("Survey Question (with credit)")."</option>
+  ".&option('anonsurvey' ,'problemtype').&mt("Anonymous Survey Question")."</option>
+  ".&option('anonsurveycred' ,'problemtype').&mt("Anonymous Survey Question (with credit)")."</option>
   ".&option('practice' ,'problemtype').&mt("Practice Problem")."</option>
+  ".&option('randomizetry' ,'problemtype').&mt("New Randomization Each Try")."</option>
 </select>
 </span>
 $show_all
@@ -502,7 +650,7 @@ $show_all
      <input type="submit" name="clear_style_file" accesskey="d" value="'.&mt('Show Default View').'" />
      <input type="submit" name="resetdata" accesskey="r" value="'.&mt('Reset Submissions').'" />
    </div>
-   <hr class="LC_edit_problem_divide" />
+   <hr />
    <div class="LC_edit_problem_header_randomize_row">
      <input type="submit" name="newrandomization" accesskey="a" value="'.&mt('New Randomization').'" />
      <input type="submit" name="changerandseed" value="'.&mt('Change Random Seed To:').'" />
@@ -526,7 +674,8 @@ $show_all
 
     $result.='
    </div>
-   <div class="LC_edit_problem_header_edit_row">';
+   <hr />
+   <div>';
     $result.='<input type="hidden" name="problemmode" value="view" />';
     $result .= '<input type="button" name="submitmode" accesskey="e" value="'.&mt('Edit').'" '.
                'onclick="javascript:setmode(this.form,'."'edit'".')" />';
@@ -534,6 +683,7 @@ $show_all
                'onclick="javascript:setmode(this.form,'."'editxml'".')" />';
     $result.='
    </div>
+   <hr />
    '.&Apache::lonxml::message_location().'
 </div>';
     return $result;
@@ -611,9 +761,7 @@ sub finalize_storage {
 	    $result=&Apache::lonnet::cstore(\%Apache::lonhomework::results,
 					    $symb,$courseid,$domain,$name);
 	    &Apache::lonxml::debug('Store return message:'.$result);
-            if ($env{'request.role'} =~/^st/) {
-                &store_aggregates($symb,$courseid);
-            }
+            &store_aggregates($symb,$courseid);
 	}
     } else {
 	&Apache::lonxml::debug('Nothing to store');
@@ -633,7 +781,7 @@ item store_aggregates()
 
 sub store_aggregates {
     my ($symb,$courseid) = @_;
-    my %aggregate;
+    my (%aggregate,%anoncounter,%randtrycounter);
     my @parts;
     my $cdomain = $env{'course.'.$env{'request.course.id'}.'.domain'};
     my $cname = $env{'course.'.$env{'request.course.id'}.'.num'};
@@ -643,28 +791,60 @@ sub store_aggregates {
         }
     }
     foreach my $part (@parts) {
-        if ($Apache::lonhomework::results{'resource.'.$part.'.award'}
-	    eq 'APPROX_ANS' ||
-	    $Apache::lonhomework::results{'resource.'.$part.'.award'}
-	    eq 'EXACT_ANS') {
-            $aggregate{$symb."\0".$part."\0correct"} = 1;
+        if ($env{'request.role'} =~/^st/) {
+            if ($Apache::lonhomework::results{'resource.'.$part.'.award'}
+                eq 'APPROX_ANS' ||
+                $Apache::lonhomework::results{'resource.'.$part.'.award'}
+                eq 'EXACT_ANS') {
+                $aggregate{$symb."\0".$part."\0correct"} = 1;
+            }
+            if ($Apache::lonhomework::results{'resource.'.$part.'.tries'} == 1) {
+                $aggregate{$symb."\0".$part."\0users"} = 1;
+            } else {
+                my (undef,$last_reset) = &Apache::grades::get_last_resets($symb,$env{'request.course.id'},[$part]);
+                if ($last_reset) {
+                    if (&Apache::grades::get_num_tries(\%Apache::lonhomework::history,$last_reset,$part) == 0) {
+                        $aggregate{$symb."\0".$part."\0users"} = 1;
+                    }
+                }
+            }
+            $aggregate{$symb."\0".$part."\0attempts"} = 1;
         }
-        if ($Apache::lonhomework::results{'resource.'.$part.'.tries'} == 1) {
-            $aggregate{$symb."\0".$part."\0users"} = 1;
-        } else {
-            my (undef,$last_reset) = &Apache::grades::get_last_resets($symb,$env{'request.course.id'},[$part]); 
-            if ($last_reset) {
-                if (&Apache::grades::get_num_tries(\%Apache::lonhomework::history,$last_reset,$part) == 0) {
-                    $aggregate{$symb."\0".$part."\0users"} = 1;
+        if (($Apache::lonhomework::results{'resource.'.$part.'.type'} eq 'anonsurvey') ||
+            ($Apache::lonhomework::results{'resource.'.$part.'.type'} eq 'anonsurveycred') ||
+            ($Apache::lonhomework::results{'resource.'.$part.'.type'} eq 'randomizetry')) {
+            if ($Apache::lonhomework::results{'resource.'.$part.'.type'} eq 'randomizetry') {
+                $randtrycounter{$symb."\0".$part} = 1;
+            } else {
+                $anoncounter{$symb."\0".$part} = 1;
+            }
+            my $needsrelease = $Apache::lonnet::needsrelease{'parameter:type:'.$Apache::lonhomework::results{'resource.'.$part.'.type'}};
+            if ($needsrelease) {
+                my $curr_required = $env{'course.'.$env{'request.course.id'}.'.internal.releaserequired'};
+                if ($curr_required eq '') {
+                    &Apache::lonnet::update_released_required($needsrelease);
+                } else {
+                    my ($currmajor,$currminor) = split(/\./,$curr_required);
+                    my ($needsmajor,$needsminor) = split(/\./,$needsrelease);
+                    if (($currmajor < $needsmajor) || ($currmajor == $needsmajor && $currminor < $needsminor)) {
+                        &Apache::lonnet::update_released_required($needsrelease);
+                    }
                 }
             }
         }
-        $aggregate{$symb."\0".$part."\0attempts"} = 1;
     }
     if (keys (%aggregate) > 0) {
 	&Apache::lonnet::cinc('nohist_resourcetracker',\%aggregate,
                             $cdomain,$cname);
     }
+    if (keys(%anoncounter) > 0) {
+        &Apache::lonnet::cput('nohist_anonsurveys',\%anoncounter,
+                              $cdomain,$cname);
+    }
+    if (keys(%randtrycounter) > 0) {
+        &Apache::lonnet::cput('nohist_randomizetry',\%randtrycounter,
+                              $cdomain,$cname);
+    }
 }
 
 sub checkout_msg {
@@ -745,6 +925,7 @@ sub init_problem_globals {
 	&Apache::lonhomework::reset_show_problem_status();
 	$Apache::lonhomework::ignore_response_errors=1;
     }
+    @Apache::functionplotresponse::callscripts=();
     @Apache::inputtags::responselist = ();
     @Apache::inputtags::importlist = ();
     @Apache::inputtags::previous=();
@@ -772,6 +953,7 @@ sub reset_problem_globals {
     undef($Apache::lonhomework::type);
     undef($Apache::lonhomework::scantronmode);
     undef($Apache::lonhomework::ignore_response_errors);
+    undef(@Apache::functionplotresponse::callscripts);
     &Apache::lonhomework::reset_show_problem_status();
 }
 
@@ -872,7 +1054,7 @@ sub start_problem {
 
     if ($target eq 'tex' and $env{'request.symb'} =~ m/\.page_/) {$result='';}
 
-    if ($target eq 'analyze') { my $rndseed=&setup_rndseed($safeeval); }
+    if ($target eq 'analyze') { my $rndseed=&setup_rndseed($safeeval,$target); }
     if ($target eq 'web' || $target eq 'grade' || $target eq 'answer' ||
 	$target eq 'tex') {
 	#handle exam checkout
@@ -890,9 +1072,15 @@ sub start_problem {
 	    my @interval=&Apache::lonnet::EXT("resource.0.interval");
 	    &Apache::lonnet::set_first_access($interval[1]);
 	}
+
+        ($status,$accessmsg,my $slot_name,my $slot) =
+            &Apache::lonhomework::check_slot_access('0','problem');
+        push (@Apache::inputtags::status,$status);
+
 	#handle rand seed in construction space
-	my $rndseed=&setup_rndseed($safeeval);
+	my $rndseed=&setup_rndseed($safeeval,$target);
 	my ($symb)=&Apache::lonnet::whichuser();
+
 	if ($env{'request.state'} ne "construct" && 
 	    ($symb eq '' || $Apache::lonhomework::type eq 'practice')) {
 	    $form_tag_start.='<input type="hidden" name="rndseed" value="'.
@@ -904,26 +1092,27 @@ sub start_problem {
 		    '<input type="hidden" name="username"
                              value="'.$env{'form.username'}.'" />';
 	    }
-            if ($env{'request.role.adv'}) {
-                $form_tag_start.= ' <label class="LC_nobreak">'
+	    if ($env{'request.role.adv'}) {
+		$form_tag_start.= ' <label class="LC_nobreak">'
                          .'<input type="checkbox" name="showallfoils"';
-                if (defined($env{'form.showallfoils'})) {
-                    $form_tag_start.=' checked="checked"';
-                }
+		if (defined($env{'form.showallfoils'})) {
+		    $form_tag_start.=' checked="checked"';
+		}
                 $form_tag_start.= ' /> '
                                  .&mt('Show All Foils')
                                  .'</label>';
-
 	    }
             if ($Apache::lonhomework::type eq 'practice') {
                 $form_tag_start.=&practice_problem_header();
             }
 	    $form_tag_start.='<hr />';
-	}
-
-	($status,$accessmsg,my $slot_name,my $slot) = 
-	    &Apache::lonhomework::check_slot_access('0','problem');
-	push (@Apache::inputtags::status,$status);
+        } elsif (($env{'request.state'} ne "construct") &&
+                 ($Apache::lonhomework::type eq 'randomizetry') &&
+                 ($status eq 'CAN_ANSWER')) {
+            my $reqtries = &Apache::lonnet::EXT("resource.$Apache::inputtags::part.randomizeontries");
+            my $problemstatus = &get_problem_status($Apache::inputtags::part);
+            $form_tag_start.=&randomizetry_problem_header($problemstatus,$reqtries);
+        }
 
 	my $expression='$external::datestatus="'.$status.'";';
 	$expression.='$external::gradestatus="'.$Apache::lonhomework::history{"resource.0.solved"}.'";';
@@ -1004,6 +1193,13 @@ sub start_problem {
 		    $result .= '<input type="hidden" name="grade_'.$field.
 			'" value="'.$env{"form.grade_$field"}.'" />'."\n";
 		}
+                foreach my $field ('questiontype','rndseed') {
+                    if ($env{"form.grade_$field"} ne '') {
+                        $result .= '<input type="hidden" name="grade_'.$field.
+                            '" value="'.$env{"form.grade_$field"}.'" />'."\n";
+                    }
+                }
+
 	    }
 	} elsif ($target eq 'tex') {
 	    $result .= 'INSERTTEXFRONTMATTERHERE';
@@ -1070,7 +1266,7 @@ sub end_problem {
 	#  it in the problem header.  We have been logging the
 	#  last due date written to file. 
 	
-	my $duetime = &Apache::lonnet::EXT("resource.$id.duedate");
+	my $duetime = &Apache::lonnet::EXT("resource.$id.duedate"); 
 	my $duedate = POSIX::strftime("%c",localtime($duetime));
         my $duedate_text = &mt('Due date: [_1]'
                               ,&Apache::lonlocal::locallocaltime($duetime));
@@ -1108,9 +1304,9 @@ sub end_problem {
 			'\textit{'.$duedate_text.'} '.$toc_line;
 		} else {
 		    $frontmatter.= $begin_doc.$toc_line;
-                    if ($Apache::lonhomework::type eq 'exam' and $allow_print_points==1) {
-                        $frontmatter .= '\fbox{\textit{'.$weight.' pt}}';
-                    }
+		    if ($Apache::lonhomework::type eq 'exam' and $allow_print_points==1) { 
+			$frontmatter .= '\fbox{\textit{'.&mt('[quant,_1,pt,pt]',$weight ).'}}';
+		    }
 		}
 	    } else {
 		$frontmatter .= '\vskip 1mm\textit{'.$duedate_text.'} \\\\\\\\'.$startminipage;
@@ -1118,9 +1314,9 @@ sub end_problem {
 	} else {
 	    if (not $env{'request.symb'} =~ m/\.page_/) {
 		$frontmatter .= $begin_doc.$toc_line;
-                if (($Apache::lonhomework::type eq 'exam') and ($allow_print_points==1)) {
-                    $frontmatter .= '\fbox{\textit{'.$weight.' pt}}';
-                }
+		if (($Apache::lonhomework::type eq 'exam') and ($allow_print_points==1)) { 
+		    $frontmatter .= '\fbox{\textit{'.&mt('[quant,_1,pt,pt]',$weight ).'}}';
+		}
 	    } else {
 		$frontmatter .= '\vskip 1mm \\\\\\\\'.$startminipage;
 	    }
@@ -1143,7 +1339,7 @@ sub end_problem {
 	    }
 	} elsif ( ($target eq 'web' || $target eq 'tex') &&
 		  $Apache::inputtags::part eq '0' &&
-		  $status ne 'UNCHECKEDOUT' && $status ne 'NOT_YET_VIEWED') {
+		  $status ne 'UNCHECKEDOUT' && $status ne 'NOT_YET_VIEWED') { 
 	    # if part is zero, no <part>s existed, so we need show the current
 	    # grading status
 	    my $gradestatus = &Apache::inputtags::gradestatus($Apache::inputtags::part,$target);
@@ -1153,10 +1349,9 @@ sub end_problem {
 	    (($target eq 'web') && ($env{'request.state'} ne 'construct')) ||
 	    ($target eq 'answer') || ($target eq 'tex')
 	   ) {
-	    if ($target ne 'tex' &&
-		$env{'form.answer_output_mode'} ne 'tex') {
+	    if (($target ne 'tex') &&
+		($env{'form.answer_output_mode'} ne 'tex')) {
 		$result.="</form>";
-		$result.= &Apache::lonhtmlcommon::htmlareaselectactive(&Apache::lonhtmlcommon::get_htmlareafields());
 	    }
 	    if ($target eq 'web') {
 		$result.= &Apache::loncommon::end_page({'discussion' => 1});
@@ -1177,6 +1372,9 @@ sub end_problem {
 		}
 	    }
 	}
+        if ($target eq 'web') {
+           $result.=&Apache::functionplotresponse::init_script();
+        }
 	if ($target eq 'grade') {
 	    &Apache::lonhomework::showhash(%Apache::lonhomework::results);
 	    &finalize_storage();
@@ -1234,7 +1432,7 @@ sub start_library {
 	($result,$form_tag_start)=
 	    &page_start($target,$token,$tagstack,$parstack,$parser,$safeeval,
 			$name);
-	my $rndseed=&setup_rndseed($safeeval);
+	my $rndseed=&setup_rndseed($safeeval,$target);
 	$result.=" \n $form_tag_start".	
 		  '<input type="hidden" name="submitted" value="yes" />';
 	$result.=&problem_web_to_edit_header($rndseed);
@@ -1473,7 +1671,7 @@ sub start_instructorcomment {
 
     if ($target eq 'web' || $target eq 'grade'   || $target eq 'answer' ||
 	$target eq 'tex' || $target eq 'analyze' || $target eq 'webgrade') {
-        $result=($env{'request.role'}=~/^(in|cc|au|ca|li)/);
+        $result=($env{'request.role'}=~/^(in|cc|co|au|ca|li)/);
 	if ( (! $result) or ($env{'form.instructor_comments'} eq 'hide')) {
 	    my $skip=&Apache::lonxml::get_all_text("/instructorcomment",
 						   $parser,$style);
@@ -1678,6 +1876,44 @@ sub ordered_show_check {
     return $in_order_show;
 }
 
+sub start_startpartmarker {
+    my ($target,$token,$tagstack,$parstack,$parser,$safeeval)=@_;
+    my $result='';
+    if ($target eq 'edit') {
+        $result=&Apache::edit::tag_start($target,$token);
+        $result.=&mt('Marker for the start of a part. Place end marker below to wrap in-between tags into a new part.').'</td></tr>';
+        $result.=&Apache::edit::end_table();
+
+    }
+    return $result;
+}
+
+sub end_startpartmarker {
+    my ($target,$token,$tagstack,$parstack,$parser,$safeeval)=@_;
+    my @result;
+    if ($target eq 'edit') { $result[1]='no'; }
+    return @result;
+}
+
+sub start_endpartmarker {
+    my ($target,$token,$tagstack,$parstack,$parser,$safeeval)=@_;
+    my $result='';
+    if ($target eq 'edit') {
+        $result=&Apache::edit::tag_start($target,$token);
+        $result.=&mt('Marker for the end of a part. Place start marker above to wrap in-between tags into a new part.').'</td></tr>';
+        $result.=&Apache::edit::end_table();
+
+    }
+    return $result;
+}
+
+sub end_endpartmarker {
+    my ($target,$token,$tagstack,$parstack,$parser,$safeeval)=@_;
+    my @result;
+    if ($target eq 'edit') { $result[1]='no'; }
+    return @result;
+}
+
 sub start_part {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
     if (!$Apache::lonxml::metamode) {
@@ -1762,11 +1998,31 @@ sub start_part {
 				    '.disableexampointprint'}) eq 'yes') {
 			$allow_print_points=0;
 		    }
-                    if (($Apache::lonhomework::type eq 'exam') && ($allow_print_points)) { 
-                        $result .= '\vskip 10mm\fbox{\textit{'.$weight.' pt}}';
-                    }
+		    if (($Apache::lonhomework::type eq 'exam') && ($allow_print_points)) { 
+			$result .= '\vskip 10mm\fbox{\textit{'.&mt('[quant,_1,pt,pt]',$weight ).'}}';
+
+		    }
 		} elsif ($target eq 'web') {
-		    $result.='<a name="'.&escape($Apache::inputtags::part).'" />';
+                    if ($status eq 'CAN_ANSWER') {
+                        my $problemstatus = &get_problem_status($Apache::inputtags::part);
+                        my $probrandomize = &Apache::lonnet::EXT("resource.$Apache::inputtags::partlist[0].type");
+                        my $probrandtries = &Apache::lonnet::EXT("resource.$Apache::inputtags::partlist[0].randomizeontries");
+                        my $num = scalar(@Apache::inputtags::partlist)-1;
+                        if ($probrandomize eq 'randomizetry') {
+                            if (&Apache::lonnet::EXT("resource.$Apache::inputtags::part.type") ne 'randomizetry') {
+                                $result .= &randomizetry_part_header($problemstatus,'none',$num);
+                            } else {
+                                my $reqtries = &Apache::lonnet::EXT("resource.$Apache::inputtags::part.randomizeontries");
+                                if ($probrandtries ne $reqtries) {
+                                    $result .= &randomizetry_part_header($problemstatus,$reqtries,$num);
+                                }
+                            }
+                        } elsif (&Apache::lonnet::EXT("resource.$Apache::inputtags::part.type") eq 'randomizetry') {
+                            my $reqtries = &Apache::lonnet::EXT("resource.$Apache::inputtags::part.randomizeontries");
+                            $result .= &randomizetry_part_header($problemstatus,$reqtries,$num);
+                        }
+                    }
+		    $result.='<a name="'.&escape($Apache::inputtags::part).'"></a>';
 		}
 	    }
 	}
@@ -1933,8 +2189,12 @@ sub start_problemtype {
 	$result .=&Apache::edit::checked_arg('When used as type(s):','for',
 					     [ ['exam','Exam/Quiz Problem'],
 					       ['survey','Survey'],
+                                               ['surveycred','Survey (with credit)'],
+                                               ['anonsurvey','Anonymous Survey'],
+                                               ['anonsurveycred','Anonymous Survey (with credit)'],
 					       ['problem','Homework Problem'],
-                                               ['practice','Practice Problem'] ]
+                                               ['practice','Practice Problem'],
+                                               ['randomizetry','New Randomization Each Try'] ]
 					     ,$token);
 	$result .=&Apache::edit::end_row().&Apache::edit::start_spanning_row();
     } elsif ($target eq 'modified') {
@@ -1973,17 +2233,15 @@ sub end_startouttext {
 	$result.=&Apache::edit::start_table($token)."<tr><td>".&mt('Text Block')."</td>"
                  .'<td><span class="LC_nobreak">'.&mt('Delete?').' '
                  .&Apache::edit::deletelist($target,$token)
-                 .'</span></td>';
-        unless ($env{'environment.wysiwygeditor'} eq 'on') {
-	    $result .= '<td align="left">'
-		.&Apache::lonhtmlcommon::dragmath_button($areaid,1)
-		.'</td>'
-		.'<td>'
-		.&Apache::edit::insertlist($target,$token)
-		.'</td>';
-	}
-	$result.='<td align="right" valign="top">' .
-	    &Apache::loncommon::helpLatexCheatsheet().
+                 .'</span></td>'
+	         .'<td align="left"><span id="math_'.$areaid.'" />'
+		 .&Apache::lonhtmlcommon::dragmath_button($areaid,1)
+		 .'</td>'
+		 .'<td>'
+		 .&Apache::edit::insertlist($target,$token)
+		 .'</td>'
+	         .'<td align="right" valign="top">' .
+	         &Apache::loncommon::helpLatexCheatsheet().
 		 &Apache::edit::end_row().
                  &Apache::edit::start_spanning_row()."\n".
 		 &Apache::edit::editfield($token->[1],$text,"",80,8,1);
@@ -2046,14 +2304,17 @@ sub start_simpleeditbutton {
         my $url=$env{'request.noversionuri'};
         $url=~s/\?.*$//;
 	my ($symb) = &Apache::lonnet::whichuser();
-#       Warning make more sense and is more important on edit screen
+#       Warning makes more sense and is more important on edit screen
 #       $result='<p class="LC_warning">'
 #              .&mt('Note: it can take up to 10 minutes for changes to take effect for all users.')
 #              .&Apache::loncommon::help_open_topic('Caching')
 #              .'</p>';
-        $result .= '<table width="100%" bgcolor="#FFFFAA" border="2"><tr><td>'.
-                   '<a href="'.$url.'/smpedit?symb='.&escape($symb).'">'.
-                   &mt('Edit').'</a></td></tr></table><br />';
+        $result.=&Apache::loncommon::head_subbox(
+                 &Apache::lonhtmlcommon::start_funclist()
+                .&Apache::lonhtmlcommon::add_item_funclist(
+                     '<a href="'.$url.'/smpedit?symb='.&escape($symb).'">'
+                    .&mt('Edit').'</a>')
+                .&Apache::lonhtmlcommon::end_funclist());
 
     }
     return $result;
@@ -2069,6 +2330,63 @@ sub practice_problem_header {
            '</span>';
 }
 
+sub randomizetry_problem_header {
+    my ($problemstatus,$reqtries) = @_;
+    my ($header,$text);
+    if ($reqtries > 1) {
+        $header = &mt('New Problem Variation After Every [quant,_1,Try,Tries]',$reqtries);
+        if (($problemstatus eq 'no') ||
+            ($problemstatus eq 'no_feedback_ever')) {
+            $text = &mt('A new variation will be generated after every [quant,_1,try,tries], until the tries limit is reached.',$reqtries);
+        } else {
+            $text = &mt('A new variation will be generated after every [quant,_1,try,tries], until correct or tries limit is reached.',$reqtries);
+        }
+    } else {
+        $header = &mt('New Problem Variation Each Try');
+        if (($problemstatus eq 'no') ||
+            ($problemstatus eq 'no_feedback_ever')) {
+            $text = &mt('A new variation will be generated after each try until the tries limit is reached.');
+
+        } else {
+            $text = &mt('A new variation will be generated after each try until correct or tries limit is reached.');
+        }
+    }
+    return '<span class="LC_info"><h3>'.$header.'</h3></span>'.
+           '<span class="LC_info">'.$text.'</span><hr />';
+}
+
+sub randomizetry_part_header {
+    my ($problemstatus,$reqtries,$num) = @_;
+    my ($header,$text);
+    if ($reqtries eq 'none') {
+        $header = &mt('No Question Variation');
+        $text = &mt('For this question there will no new variation after a try.');
+    } elsif ($reqtries > 1) {
+        $header = &mt('New Question Variation After Every [quant,_1,Try,Tries]',$reqtries);
+        if (($problemstatus eq 'no') ||
+            ($problemstatus eq 'no_feedback_ever')) {
+            $text = &mt('For this question a new variation will be generated after every [quant,_1,try,tries], until the tries limit is reached.',$reqtries);
+        } else {
+            $text = &mt('For this question a new variation will be generated after every [quant,_1,try,tries], until correct or tries limit is reached.',$reqtries);
+        }
+    } else {
+        $header = &mt('New Question Variation For Each Try');
+        if (($problemstatus eq 'no') ||
+            ($problemstatus eq 'no_feedback_ever')) {
+            $text =  &mt('For this question a new variation will be generated after each try until the tries limit is reached.');
+        } else {
+            $text = &mt('For this question a new variation will be generated after each try until correct or tries limit is reached.');
+        }
+    }
+    my $output;
+    if ($num > 1) {
+        $output .= '<hr />';
+    }
+    $output .=  '<span class="LC_info"><h4>'.$header.'</h4></span>'.
+                  '<span class="LC_info">'.$text.'</span><br /><br />';
+    return $output;
+}
+
 1;
 __END__
 
