@@ -3,7 +3,7 @@
 # institutional log-in ID (institutional authentication required - localauth
 #  or kerberos) or an e-mail address.
 #
-# $Id: createaccount.pm,v 1.40.2.3 2010/12/24 20:36:11 raeburn Exp $
+# $Id: createaccount.pm,v 1.40.2.5 2011/09/29 14:16:14 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -411,7 +411,7 @@ sub print_username_form {
                 } else {
                     $output .= '<br />';
                 }
-                $output .=  '<form name="createaccount" method="post" onSubmit="return validate_email()" action="/adm/createaccount">'.
+                $output .=  '<form name="createaccount" method="post" onsubmit="return validate_email()" action="/adm/createaccount">'.
                             &Apache::lonhtmlcommon::start_pick_box()."\n".
                             &Apache::lonhtmlcommon::row_title(&mt('E-mail address'),
                                                              'LC_pick_box_title')."\n".
@@ -465,7 +465,7 @@ sub login_box {
     $output = &serverform($logtoken,$lonhost,undef,$courseid,$context);
     my $unameform = '<input type="text" name="uname" size="20" value="" />';
     my $upassform = '<input type="password" name="upass'.$now.'" size="20" />';
-    $output .= '<form name="client" method="post" onsubmit="return(send());">'."\n".
+    $output .= '<form name="client" method="post" action="" onsubmit="return(send());">'."\n".
                &Apache::lonhtmlcommon::start_pick_box()."\n".
                &Apache::lonhtmlcommon::row_title($titles{$context},
                                                  'LC_pick_box_title')."\n".
@@ -751,7 +751,7 @@ ENDSERVERFORM
         my $upasstwo = '<input type="password" name="upasscheck'.$now.'" size="10" />';
         my $submit_text = &mt('Create LON-CAPA account');
         $output .= '<h3>'.&mt('Login Data').'</h3>'."\n".
-                   '<form name="client" method="post" '.
+                   '<form name="client" method="post" action="" '.
                    'onsubmit="return checkpass();">'."\n".
                    &Apache::lonhtmlcommon::start_pick_box()."\n".
                    &Apache::lonhtmlcommon::row_title(&mt('Username'),
@@ -796,6 +796,17 @@ sub get_creation_controls {
         if (ref($usercreation->{'cancreate'}) eq 'HASH') {
             if (ref($usercreation->{'cancreate'}{'statustocreate'}) eq 'ARRAY') {
                 @statustocreate = @{$usercreation->{'cancreate'}{'statustocreate'}};
+                if (@statustocreate == 0) {
+                    my ($othertitle,$usertypes,$types) =
+                        &Apache::loncommon::sorted_inst_types($domain);
+                    if (ref($types) eq 'ARRAY') {
+                        if (@{$types} == 0) {
+                            @statustocreate = ('default');
+                        }
+                    } else {
+                        @statustocreate = ('default');
+                    }
+                }
             } else {
                 @statustocreate = ('default');
                 my ($othertitle,$usertypes,$types) =
@@ -974,7 +985,7 @@ sub username_check {
         }
     }
     if ($checkfail) { 
-        $msg = '<h4>'.&mt('Account creation unavailable').'</h4>';
+        $msg = '<br /><h4>'.&mt('Account creation unavailable').'</h4>';
         if ($checkfail eq 'username') {
             $msg .= '<span class="LC_warning">'.
                      &mt('A LON-CAPA account may not be created with the username you use.').
@@ -1000,7 +1011,7 @@ sub username_check {
         if ($rowcount) {
             if ($editable) {
                 if ($courseid ne '') { 
-                    $msg = '<h4>'.&mt('User information').'</h4>';
+                    $msg = '<br /><h4>'.&mt('User information').'</h4>';
                 }
                 $msg .= &mt('To create one, use the table below to provide information about yourself, then click the [_1]Create LON-CAPA account[_2] button.','<span class="LC_cusr_emph">','</span>').'<br />';
             } else {
