@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # displays the main menu
 #
-# $Id: lonmainmenu.pm,v 1.5 2007/04/11 02:42:00 www Exp $
+# $Id: lonmainmenu.pm,v 1.8 2009/07/13 08:24:21 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -52,8 +52,7 @@ sub handler {
     return OK if $r->header_only;
 
     my $form;
-    if ($env{'environment.remote'} ne 'off' &&
-	$env{'browser.interface'} ne 'textual') {
+    if ($env{'environment.remote'} ne 'off') {
 	$form=&Apache::lonmenu::serverform();
     }
 
@@ -67,11 +66,14 @@ $utility
 ENDSCRIPT
     }
 # ---- Print the screen, pretend to be in text mode to generate text-based menu
-    unless ($env{'browser.interface'} eq 'textual') {
-	$env{'browser.interface'}='faketextual';
-	$env{'environment.remote'}='off';
-    }
-    $r->print(&Apache::loncommon::start_page('Main Menu',$script_tag));
+# temporarily set interface to "faketextual" and remote to "off", which renders
+# the main menu
+    $env{'browser.interface'}='faketextual';
+    $env{'environment.remote'}='off';
+
+    $r->print(&Apache::loncommon::start_page( 'Main Menu',
+                                              $script_tag,
+                                              {'bread_crumbs' => 1}));
     $r->print(&Apache::lonmenu::inlinemenu().$form);
     $r->print(&Apache::loncommon::end_page());
     return OK;
