@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Metadata display handler
 #
-# $Id: lonmeta.pm,v 1.233 2009/05/27 13:29:47 bisitz Exp $
+# $Id: lonmeta.pm,v 1.240 2010/06/06 02:40:30 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -425,7 +425,7 @@ sub select_course {
 # Pretty printing of metadata field
 
 sub prettyprint {
-    my ($type,$value,$target,$prefix,$form,$noformat)=@_;
+    my ($type,$value,$target,$prefix,$form)=@_;
 # $target,$prefix,$form are optional and for filecrumbs only
     if (! defined($value)) { 
         return '&nbsp;'; 
@@ -500,8 +500,8 @@ sub prettyprint {
                 } 
             }
             $_ = '<li>'.$title.' '.
-		&Apache::lonhtmlcommon::crumbs($url,$target,$prefix,$form,'0',$noformat).
-                '</li>'
+                 &Apache::lonhtmlcommon::crumbs($url,$target,$prefix,$form).
+                 '</li>'
 	    } split(/\s*\,\s*/,$value)).'</ul>';
     }
     # Evaluations
@@ -638,7 +638,7 @@ sub prettyinput {
             
             if ($values) {
                 if ($only_one) {
-                    $output .= (&Apache::loncommon::select_form($cur_values_inst[0],'new_'.$type,%meta_options));
+                    $output .= (&Apache::loncommon::select_form($cur_values_inst[0],'new_'.$type,\%meta_options));
                 } else {
                     $output .= (&Apache::loncommon::multiple_select_form('new_'.$type,\@cur_values_inst,undef,\%meta_options));
                 }
@@ -742,6 +742,23 @@ sub prettyinput {
                       $relatedvalue); 
 }
 
+# Create pageheader
+sub pageheader {
+    my $output = '';
+    # No CSTR? Include breadcrumbs
+    if ($env{'request.state'} ne 'construct') {
+        # loncommon::bodytag already includes breadcrumbs for CSTR
+        # by calling lonmenu::innerregister
+        $output = &Apache::lonhtmlcommon::breadcrumbs();
+    }
+    # CSTR? Include CSTR header
+    if ($env{'request.state'} eq 'construct') {
+          $output .= &Apache::loncommon::head_subbox(
+                         &Apache::loncommon::CSTR_pageheader());
+    }
+    return $output;
+}
+
 # Main Handler
 sub handler {
     my $r=shift;
@@ -755,16 +772,37 @@ sub handler {
     return OK if $r->header_only;
     my ($resdomain,$resuser)=
         (&Apache::lonnet::declutter($uri)=~/^($match_domain)\/($match_username)\//);
+
+    # Breadcrumbs
+    &Apache::lonhtmlcommon::clear_breadcrumbs();
+
+    if ($env{'request.state'} eq 'construct') {
+        &Apache::lonhtmlcommon::add_breadcrumb({
+            'text'  => 'Construction Space',
+            'href'  => &Apache::loncommon::authorspace(),
+        });
+    }
+
     if ($uri=~m:/adm/bombs/(.*)$:) {
+        &Apache::lonhtmlcommon::add_breadcrumb({
+            'text'  => 'Error Messages',
+            'href'  => '',
+        });
         $r->print(&Apache::loncommon::start_page('Error Messages'));
+        $r->print(&pageheader());
         # Looking for all bombs?
         &report_bombs($r,$uri);
     } elsif ($uri=~m|^/editupload/[^/]+/[^/]+/portfolio/|) {
+        &Apache::lonhtmlcommon::add_breadcrumb({
+            'text'  => 'Edit Portfolio File Metadata',
+            'href'  => '',
+        });
 	    ($resdomain,$resuser)=
 		(&Apache::lonnet::declutter($uri)=~m|^($match_domain)/($match_name)/portfolio|);
         $r->print(&Apache::loncommon::start_page('Edit Portfolio File Metadata',
 						 undef,
 						 {'domain' => $resdomain,}));
+        $r->print(&pageheader());
         if ($env{'form.store'}) {
             &present_editable_metadata($r,$uri,'portfolio');
         } else {
@@ -781,22 +819,41 @@ sub handler {
             }
         }
     } elsif ($uri=~m|^/editupload/[^/]+/[^/]+/groups/|) {
+        &Apache::lonhtmlcommon::add_breadcrumb({
+            'text'  => 'Edit Group Portfolio File Metadata',
+            'href'  => '',
+        });
         $r->print(&Apache::loncommon::start_page('Edit Group Portfolio File Metadata',
 						 undef,
 						 {'domain' => $resdomain,}));
+        $r->print(&pageheader());
         &present_editable_metadata($r,$uri,'groups');    
     } elsif ($uri=~m|^/~|) { 
         # Construction space
+        &Apache::lonhtmlcommon::add_breadcrumb({
+            'text'  => 'Edit Metadata',
+            'href'  => '',
+        });
         $r->print(&Apache::loncommon::start_page('Edit Metadata',
 						"\n".'<script type="text/javascript">'."\n".
                                                 &Apache::loncommon::browser_and_searcher_javascript().
                                                 "\n".'</script>',
 						 {'domain' => $resdomain,}));
+        $r->print(&pageheader());
         &present_editable_metadata($r,$uri);
     } else {
-        $r->print(&Apache::loncommon::start_page('Metadata',
-						 undef,
-						 {'domain' => $resdomain,}));
+        &Apache::lonhtmlcommon::add_breadcrumb({
+            'text'  => 'Metadata',
+            'href'  => '',
+        });
+        $r->print(
+            &Apache::loncommon::start_page(
+                'Metadata',
+                undef,
+                {'domain' => $resdomain,
+                'only_body' => 1,})
+           .'<h1>'.&mt('Metadata').'</h1>'
+        );
         &present_uneditable_metadata($r,$uri);
     }
     $r->print(&Apache::loncommon::end_page());
@@ -882,9 +939,8 @@ sub present_uneditable_metadata {
 	    $versiondisplay='Version: '.$currentversion;
 	}
     }
-    # crumbify displayed URL               uri     target prefix form  size
-    $disuri=&Apache::lonhtmlcommon::crumbs($disuri,undef, undef, undef,'+1');
-    $disuri =~ s:<br />::g;
+    # crumbify displayed URL               uri     target prefix form 
+    $disuri=&Apache::lonhtmlcommon::crumbs($disuri,undef, undef, undef);
     # obsolete
     my $obsolete=$content{'obsolete'};
     my $obsoletewarning='';
