@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # handler for DC-only modifiable course settings
 #
-# $Id: lonmodifycourse.pm,v 1.51 2010/03/15 19:10:59 raeburn Exp $
+# $Id: lonmodifycourse.pm,v 1.59 2011/01/15 18:24:16 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -149,7 +149,7 @@ sub print_course_search_page {
                       'instcodefilter','ownerfilter',
                       'coursefilter'];
     my $filter = {};
-    my ($numtitles,$cctitle,$dctitle);
+    my ($numtitles,$cctitle,$dctitle,@codetitles);
     my $ccrole = 'cc';
     if ($type eq 'Community') {
         $ccrole = 'co';
@@ -163,7 +163,8 @@ sub print_course_search_page {
         $r->print('<h3>'.&mt('Search for a course in the [_1] domain',$domdesc).'</h3>');
     }   
     $r->print(&Apache::lonpickcourse::build_filters($filterlist,$type,
-                             undef,undef,$filter,$action,\$numtitles,'modifycourse'));
+                             undef,undef,$filter,$action,\$numtitles,'modifycourse',
+                             undef,undef,undef,\@codetitles));
     if ($type eq 'Community') {
         $r->print(&mt('Actions available after searching for a community:').'<ul>'.
                   '<li>'.&mt('Enter the community with the role of [_1]',$cctitle).'</li>'."\n".
@@ -192,14 +193,16 @@ sub print_course_selection_page {
     my %filter;
     my $action = '/adm/modifycourse';
     my $dctitle = &Apache::lonnet::plaintext('dc');
-    my $numtitles;
+    my ($numtitles,@codetitles);
     $r->print(&Apache::lonpickcourse::js_changer());
     $r->print(&mt('Revise your search criteria for this domain').' ('.$domdesc.').<br />');
     $r->print(&Apache::lonpickcourse::build_filters($filterlist,$type,
-                                       undef,undef,\%filter,$action,\$numtitles));
+                                       undef,undef,\%filter,$action,\$numtitles,
+                                       undef,undef,undef,undef,\@codetitles));
     $filter{'domainfilter'} = $dom;
     my %courses = &Apache::lonpickcourse::search_courses($r,$type,0,
-                                                         \%filter,$numtitles);
+                                                         \%filter,$numtitles,undef,
+                                                         undef,undef,\@codetitles);
     &Apache::lonpickcourse::display_matched_courses($r,$type,0,$action,undef,undef,undef,
                                                     %courses);
     return;
@@ -208,87 +211,122 @@ sub print_course_selection_page {
 sub print_modification_menu {
     my ($r,$cdesc,$domdesc,$dom,$type) = @_;
     &print_header($r,$type);
-    my ($ccrole,$setquota_text,$setparams_text,$cat_text);
+    my ($ccrole,$categorytitle,$setquota_text,$setparams_text,$cat_text);
     if ($type eq 'Community') {
         $ccrole = 'co';
     } else {
         $ccrole = 'cc';
     } 
-    my $action = '/adm/modifycourse';
     if ($type eq 'Community') {
+        $categorytitle = 'View/Modify Community Settings';
         $setquota_text = &mt('Total disk space allocated for storage of portfolio files in all groups in a community.');
         $setparams_text = 'View/Modify community owner';
         $cat_text = 'View/Modify catalog settings for community';
     } else {
+        $categorytitle = 'View/Modify Course Settings';
         $setquota_text = &mt('Total disk space allocated for storage of portfolio files in all groups in a course.');
         $setparams_text = 'View/Modify course owner, institutional code, and default authentication';
-        $cat_text = 'View/Modify catalog settings for course'; 
+        $cat_text = 'View/Modify catalog settings for course';
     }
-    my @menu =
-        (
-          { text => $setparams_text,
-             phase => 'setparms',
-          },
-          { text  => 'View/Modify quota for group portfolio files',
-            phase => 'setquota',
-          }
-    );
+    my $anon_text = 'Responder threshold required to display anonymous survey submissions';
+
     my %domconf = &Apache::lonnet::get_dom('configuration',['coursecategories'],$dom);
     my @additional_params = &catalog_settable($domconf{'coursecategories'},$type);
-    if (@additional_params > 0) {
-        push (@menu, { text => $cat_text,
-                       phase => 'catsettings',
-                     });
+
+    sub phaseurl {
+        my $phase = shift;
+        return "javascript:changePage(document.menu,'$phase')"
     }
-    unless ($type eq 'Community') {
-        push(@menu,
-           { text  => 'Display current settings for automated enrollment',
-            phase => 'viewparms',
-           }
+    my @menu =
+        ({  categorytitle => $categorytitle,
+        items => [
+            {
+                linktext => $setparams_text,
+                url => &phaseurl('setparms'),
+                permission => 1,
+                #help => '',
+                icon => 'crsconf.png',
+                linktitle => ''
+            },
+            {
+                linktext => 'View/Modify quota for group portfolio files',
+                url => &phaseurl('setquota'),
+                permission => 1,
+                #help => '',
+                icon => 'groupportfolioquota.png',
+                linktitle => ''
+            },
+            {
+                linktext => 'View/Modify responders threshold for anonymous survey submissions display',
+                url => &phaseurl('setanon'),
+                permission => 1,
+                #help => '',
+                icon => 'anonsurveythreshold.png',
+                linktitle => ''
+            },
+            {
+                linktext => $cat_text,
+                url => &phaseurl('catsettings'),
+                permission => (@additional_params > 0),
+                #help => '',
+                icon => 'ccatconf.png',
+                linktitle => ''
+            },
+            {
+                linktext => 'Display current settings for automated enrollment',
+                url => &phaseurl('viewparms'),
+                permission => ($type ne 'Community'),
+                #help => '',
+                icon => 'roles.png',
+                linktitle => ''
+            },
+        ]
+        },
         );
-    }
-    my $menu_html = '<h3>'.&mt('View/Modify settings for: ').
-                    ' <span class="LC_nobreak">'.$cdesc.'</span></h3>'."\n";
+
+    my $menu_html =
+        '<h3>'
+       .&mt('View/Modify settings for: [_1]',
+                '<span class="LC_nobreak">'.$cdesc.'</span>')
+       .'</h3>'."\n".'<p>';
     if ($type eq 'Community') {
         $menu_html .= &mt('Although almost all community settings can be modified by a Coordinator, the following may only be set or modified by a Domain Coordinator:');
     } else {
         $menu_html .= &mt('Although almost all course settings can be modified by a Course Coordinator, the following may only be set or modified by a Domain Coordinator:');
     }
-    $menu_html .= '<ul>';
+    $menu_html .= '</p>'."\n".'<ul>';
     if ($type eq 'Community') {
         $menu_html .= '<li>'.&mt('Community owner (permitted to assign Coordinator roles in the community).').'</li>';
     } else {
         $menu_html .=  '<li>'.&mt('Course owner (permitted to assign Course Coordinator roles in the course).').'</li>'.
                        '<li>'.&mt("Institutional code and default authentication (both required for auto-enrollment of students from institutional datafeeds).").'</li>';
     }
-    $menu_html .= '<li>'.$setquota_text.'</li>'."\n";
+    $menu_html .= '<li>'.$setquota_text.'</li>'.
+                  '<li>'.$anon_text.'</li>'."\n";
     foreach my $item (@additional_params) {
         if ($type eq 'Community') {
             if ($item eq 'togglecats') {
-                $menu_html .= '  <li>'.&mt('Hiding/unhiding a community from the catalog (although can be [_1]configured[_2] to be modifiable by a Coordinator in community context).','<a href="/adm/domainprefs?actions=coursecategories&phase=display">','</a>').'</li>'."\n";
+                $menu_html .= '  <li>'.&mt('Hiding/unhiding a community from the catalog (although can be [_1]configured[_2] to be modifiable by a Coordinator in community context).','<a href="/adm/domainprefs?actions=coursecategories&amp;phase=display">','</a>').'</li>'."\n";
             } elsif ($item eq 'categorize') {
-                $menu_html .= '  <li>'.&mt('Manual cataloging of a community (although can be [_1]configured[_2] to be modifiable by a Coordinator in community context).','<a href="/adm/domainprefs?actions=coursecategories&phase=display">','</a>').'</li>'."\n";
+                $menu_html .= '  <li>'.&mt('Manual cataloging of a community (although can be [_1]configured[_2] to be modifiable by a Coordinator in community context).','<a href="/adm/domainprefs?actions=coursecategories&amp;phase=display">','</a>').'</li>'."\n";
             }
         } else {
             if ($item eq 'togglecats') {
-                $menu_html .= '  <li>'.&mt('Hiding/unhiding a course from the course catalog (although can be [_1]configured[_2] to be modifiable by a Course Coordinator in course context).','<a href="/adm/domainprefs?actions=coursecategories&phase=display">','</a>').'</li>'."\n";
+                $menu_html .= '  <li>'.&mt('Hiding/unhiding a course from the course catalog (although can be [_1]configured[_2] to be modifiable by a Course Coordinator in course context).','<a href="/adm/domainprefs?actions=coursecategories&amp;phase=display">','</a>').'</li>'."\n";
             } elsif ($item eq 'categorize') {
-                $menu_html .= '  <li>'.&mt('Manual cataloging of a course (although can be [_1]configured[_2] to be modifiable by a Course Coordinator in course context).','<a href="/adm/domainprefs?actions=coursecategories&phase=display">','</a>').'</li>'."\n";
+                $menu_html .= '  <li>'.&mt('Manual cataloging of a course (although can be [_1]configured[_2] to be modifiable by a Course Coordinator in course context).','<a href="/adm/domainprefs?actions=coursecategories&amp;phase=display">','</a>').'</li>'."\n";
             }
         }
     }
-    $menu_html .= ' </ul>
-<form name="menu" method="post" action="'.$action.'" />'."\n".
-    &hidden_form_elements();
-    foreach my $menu_item (@menu) {
-        $menu_html.='<h3>';
-        $menu_html.=
-                qq|<a href="javascript:changePage(document.menu,'$menu_item->{'phase'}')">|;
-        $menu_html.= &mt($menu_item->{'text'}).'</a>';
-        $menu_html.='</h3>';
-    }
+    $menu_html .=
+        ' </ul>'
+       .'<form name="menu" method="post" action="/adm/modifycourse">'
+       ."\n"
+       .&hidden_form_elements();
     
     $r->print($menu_html);
+    $r->print(&Apache::lonhtmlcommon::generate_menu(@menu));
+    $r->print('</form>');
     return;
 }
 
@@ -381,11 +419,11 @@ sub print_setquota {
     my $hidden_elements = &hidden_form_elements();
     my $helpitem = &Apache::loncommon::help_open_topic('Modify_Course_Quota');
     $r->print(<<ENDDOCUMENT);
-<form action="/adm/modifycourse" method="post" name="setquota">
+<form action="/adm/modifycourse" method="post" name="setquota" onsubmit="return verify_quota();">
 <h3>$lt{'cquo'} <span class="LC_nobreak">$cdesc</span></h3>
 <p>
 $helpitem $lt{'gpqu'}: <input type="text" size="4" name="coursequota" value="$coursequota" /> Mb &nbsp;&nbsp;&nbsp;&nbsp;
-<input type="button" onClick="javascript:verify_quota(this.form)" value="$lt{'modi'}" />
+<input type="submit" value="$lt{'modi'}" />
 </p>
 $hidden_elements
 <a href="javascript:changePage(document.setquota,'menu')">$lt{'back'}</a>
@@ -394,6 +432,45 @@ ENDDOCUMENT
     return;
 }
 
+sub print_set_anonsurvey_threshold {
+    my ($r,$cdom,$cnum,$cdesc,$type) = @_;
+    my %lt = &Apache::lonlocal::texthash(
+                'resp' => 'Responder threshold for anonymous survey submissions display:',
+                'sufa' => 'Anonymous survey submissions displayed when responders exceeds',
+                'modi' => 'Save',
+                'back' => 'Pick another action',
+    );
+    my %settings = &Apache::lonnet::get('environment',['internal.anonsurvey_threshold'],$cdom,$cnum);
+    my $threshold = $settings{'internal.anonsurvey_threshold'};
+    if ($threshold eq '') {
+        my %domconfig = 
+            &Apache::lonnet::get_dom('configuration',['coursedefaults'],$cdom);
+        if (ref($domconfig{'coursedefaults'}) eq 'HASH') {
+            $threshold = $domconfig{'coursedefaults'}{'anonsurvey_threshold'};
+            if ($threshold eq '') {
+                $threshold = 10;
+            }
+        } else {
+            $threshold = 10;
+        }
+    }
+    &print_header($r,$type);
+    my $hidden_elements = &hidden_form_elements();
+    my $helpitem = &Apache::loncommon::help_open_topic('Modify_Anonsurvey_Threshold');
+    $r->print(<<ENDDOCUMENT);
+<form action="/adm/modifycourse" method="post" name="setanon" onsubmit="return verify_anon_threshold();">
+<h3>$lt{'resp'} <span class="LC_nobreak">$cdesc</span></h3>
+<p>
+$helpitem $lt{'sufa'}: <input type="text" size="4" name="threshold" value="$threshold" /> &nbsp;&nbsp;&nbsp;&nbsp;
+<input type="submit" value="$lt{'modi'}" />
+</p>
+$hidden_elements
+<a href="javascript:changePage(document.setanon,'menu')">$lt{'back'}</a>
+</form>
+ENDDOCUMENT
+    return;
+}
+
 sub print_catsettings {
     my ($r,$cdom,$cnum,$cdesc,$type) = @_;
     &print_header($r,$type);
@@ -768,6 +845,8 @@ sub modify_course {
 	            push(@warnings,&mt('There is no owner associated with this LON-CAPA course.').
                                    '<br />'.&mt('If automated enrollment at your institution requires validation of course owners, automated enrollment will fail.'));
                 } else {
+                    my %crsenv = &Apache::lonnet::get('environment',['internal.co-owners'],$cdom,$cnum);
+                    my $coowners = $crsenv{'internal.co-owners'};
 	            if (@sections > 0) {
                         if ($changed{'code'}) {
 	                    foreach my $sec (@sections) {
@@ -776,13 +855,13 @@ sub modify_course {
 		                    my $inst_course_id = $newattr{'coursecode'}.$1;
                                     my $course_check = &Apache::lonnet::auto_validate_courseID($cnum,$cdom,$inst_course_id);
 			            if ($course_check eq 'ok') {
-                                        my $outcome = &Apache::lonnet::auto_new_course($cnum,$cdom,$inst_course_id,$newattr{'courseowner'});
+                                        my $outcome = &Apache::lonnet::auto_new_course($cnum,$cdom,$inst_course_id,$newattr{'courseowner'},$coowners);
 			                unless ($outcome eq 'ok') {
                                
-				            push(@warnings,&mt('If automatic enrollment is enabled for "[_1]" automated enrollment may fail for "[_2]" - section: [_3], for the following reason: "[_4]"',$description,$newattr{'coursecode'},$instsec,$outcome).'<br/>');
+				            push(@warnings,&mt('If automatic enrollment is enabled for "[_1]", automated enrollment may fail for "[_2]" - section: [_3] for the following reason: "[_4]".',$description,$newattr{'coursecode'},$instsec,$outcome).'<br/>');
 			                }
 			            } else {
-                                        push(@warnings,&mt('If automatic enrollment is enabled for "[_1]" automated enrollment may fail for "[_2]" - section: [_3], for the following reason: "[_4]"',$description,$newattr{'coursecode'},$instsec,$course_check));
+                                        push(@warnings,&mt('If automatic enrollment is enabled for "[_1]", automated enrollment may fail for "[_2]" - section: [_3] for the following reason: "[_4]".',$description,$newattr{'coursecode'},$instsec,$course_check));
 			            }
 		                } else {
 			            push(@warnings,&mt('If automatic enrollment is enabled for "[_1]", automated enrollment may fail for "[_2]" - section: [_3], because this is not a valid section entry.',$description,$newattr{'coursecode'},$sec));
@@ -793,23 +872,23 @@ sub modify_course {
                                 if ($sec =~ m/^(.+):/) {
                                     my $instsec = $1;
                                     my $inst_course_id = $newattr{'coursecode'}.$instsec;
-                                    my $outcome = &Apache::lonnet::auto_new_course($cnum,$cdom,$inst_course_id,$newattr{'courseowner'});
+                                    my $outcome = &Apache::lonnet::auto_new_course($cnum,$cdom,$inst_course_id,$newattr{'courseowner'},$coowners);
                                     unless ($outcome eq 'ok') {
-                                        push(@warnings,&mt('If automatic enrollment is enabled for "[_1]", automated enrollment may fail for "[_2]" - section [_3] for the following reason: "[_4]".',$description,$newattr{'coursecode'},$instsec,$outcome));
+                                        push(@warnings,&mt('If automatic enrollment is enabled for "[_1]", automated enrollment may fail for "[_2]" - section: [_3] for the following reason: "[_4]".',$description,$newattr{'coursecode'},$instsec,$outcome));
                                     }
                                 } else {
-                                    push(@warnings,&mt('If automatic enrollment is enabled for "[_1]", automated enrollment may fail for "[_2]" - section [_3] because this is not a valid section entry.',$description,$newattr{'coursecode'},$sec));
+                                    push(@warnings,&mt('If automatic enrollment is enabled for "[_1]", automated enrollment may fail for "[_2]" - section: [_3], because this is not a valid section entry.',$description,$newattr{'coursecode'},$sec));
                                 }
                             }
                         }
 	            } else {
-	                push(@warnings,&mt('As no section numbers are currently listed for "[_1]" automated enrollment will not occur for any sections of institutional course code: "[_2]".',$description,$newattr{'coursecode'}));
+	                push(@warnings,&mt('As no section numbers are currently listed for "[_1]", automated enrollment will not occur for any sections of institutional course code: "[_2]".',$description,$newattr{'coursecode'}));
 	            }
 	            if ( (@xlists > 0) && ($changed{'owner'}) ) {
 	                foreach my $xlist (@xlists) {
 		            if ($xlist =~ m/^(.+):/) {
                                 my $instxlist = $1;
-                                my $outcome = &Apache::lonnet::auto_new_course($cnum,$cdom,$instxlist,$newattr{'courseowner'});
+                                my $outcome = &Apache::lonnet::auto_new_course($cnum,$cdom,$instxlist,$newattr{'courseowner'},$coowners);
 		                unless ($outcome eq 'ok') {
 			            push(@warnings,&mt('If automatic enrollment is enabled for "[_1]", automated enrollment may fail for crosslisted class "[_2]" for the following reason: "[_3]".',$description,$instxlist,$outcome));
 		                }
@@ -931,10 +1010,10 @@ sub update_coowners {
                             my %pendinghash = (
                                 'internal.pendingco-owners' => $pendingcoowners,
                             );
-                            my $putresult = &put('environment',\%pendinghash,$cdom,$cnum);
+                            my $putresult = &Apache::lonnet::put('environment',\%pendinghash,$cdom,$cnum);
                             if ($putresult eq 'ok') {
                                 if ($env{'course.'.$cid.'.num'} eq $cnum) {
-                                    &appenv({'course.'.$cid.'.internal.pendingco-owners' => $pendingcoowners});
+                                    &Apache::lonnet::appenv({'course.'.$cid.'.internal.pendingco-owners' => $pendingcoowners});
                                 }
                             }
                         } else {
@@ -963,7 +1042,7 @@ sub update_coowners {
             if ($designhash{$cdom.'.autoassign.co-owners'}) {
                 my @newcoowners = ();
                 if ($settings->{'internal.co-owners'}) {
-                    my @currcoown = split(',',$settings->{'internal.coowners'});
+                    my @currcoown = split(',',$settings->{'internal.co-owners'});
                     my ($updatecoowners,$delcoowners);
                     foreach my $person (@currcoown) {
                         my ($result,$desc) = &Apache::lonnet::auto_validate_instcode($cnum,$cdom,$newattr->{'coursecode'},$person);
@@ -1039,7 +1118,7 @@ sub modify_quota {
                 } else {
                     if ($putreply eq 'ok') {
                         my %updatedsettings = &Apache::lonnet::get('environment',['internal.coursequota'],$cdom,$cnum);
-                        $r->print(&mt('The disk space allocated for group portfolio files is now: [_1] Mb.',$updatedsettings{'internal.coursequota'}));
+                        $r->print(&mt('The disk space allocated for group portfolio files is now: [_1] Mb.','<b>'.$updatedsettings{'internal.coursequota'}.'</b>'));
                         my $usage = &Apache::longroup::sum_quotas($cdom.'_'.$cnum);
                         if ($usage >= $updatedsettings{'internal.coursequota'}) {
                             my $newoverquota;
@@ -1073,6 +1152,62 @@ sub modify_quota {
     return;
 }
 
+sub modify_anonsurvey_threshold {
+    my ($r,$cdom,$cnum,$cdesc,$domdesc,$type) = @_;
+    &print_header($r,$type);
+    $r->print('<form action="/adm/modifycourse" method="post" name="processthreshold">'."\n".
+              '<h3>'.&mt('Responder threshold required for display of anonymous survey submissions:').
+              ' <span class="LC_nobreak">'.$cdesc.'</span></h3><br />');
+    my %oldsettings = &Apache::lonnet::get('environment',['internal.anonsurvey_threshold'],$cdom,$cnum);
+    my %domconfig =
+        &Apache::lonnet::get_dom('configuration',['coursedefaults'],$cdom);
+    my $defaultthreshold; 
+    if (ref($domconfig{'coursedefaults'}) eq 'HASH') {
+        $defaultthreshold = $domconfig{'coursedefaults'}{'anonsurvey_threshold'};
+        if ($defaultthreshold eq '') {
+            $defaultthreshold = 10;
+        }
+    } else {
+        $defaultthreshold = 10;
+    }
+    if ($env{'form.threshold'} eq '') {
+        $r->print(&mt('The proposed responder threshold for display of anonymous survey submissions was blank, so the threshold is unchanged.'));
+    } else {
+        my $newthreshold = $env{'form.threshold'};
+        if ($newthreshold =~ /^\s*(\d+)\s*$/) {
+            $newthreshold = $1;
+            if ($oldsettings{'internal.anonsurvey_threshold'} eq $env{'form.threshold'}) {
+                $r->print(&mt('Responder threshold for anonymous survey submissions display remains unchanged: [_1].',$env{'form.threshold'}));
+            } else {
+                my %cenv = (
+                           'internal.anonsurvey_threshold' => $env{'form.threshold'},
+                           );
+                my $putreply = &Apache::lonnet::put('environment',\%cenv,$cdom,
+                                                    $cnum);
+                if (($oldsettings{'internal.anonsurvey_threshold'} eq '') &&
+                    ($env{'form.threshold'} == $defaultthreshold)) {
+                    $r->print(&mt('The responder threshold for display of anonymous survey submissions is the default for this domain: [_1].',$defaultthreshold));
+                } else {
+                    if ($putreply eq 'ok') {
+                        my %updatedsettings = &Apache::lonnet::get('environment',['internal.anonsurvey_threshold'],$cdom,$cnum);
+                        $r->print(&mt('The responder threshold for display of anonymous survey submissions is now: [_1].','<b>'.$updatedsettings{'internal.anonsurvey_threshold'}.'</b>'));
+                    } else {
+                        $r->print(&mt('An error occurred storing the responder threshold for anonymous submissions display: ').
+                                  $putreply);
+                    }
+                }
+            }
+        } else {
+            $r->print(&mt('The proposed responder threshold for display of anonymous submissions contained invalid characters, so the threshold is unchanged.'));
+        }
+    }
+    $r->print('<p>'.
+              '<a href="javascript:changePage(document.processthreshold,'."'menu'".')">'.
+              &mt('Pick another action').'</a>');
+    $r->print(&hidden_form_elements().'</form>');
+    return;
+}
+
 sub modify_catsettings {
     my ($r,$cdom,$cnum,$cdesc,$domdesc,$type) = @_;
     &print_header($r,$type);
@@ -1236,17 +1371,45 @@ function gochoose(cname,cdom,cdesc) {
 </script>
 |;
     } elsif ($phase eq 'setquota') {
-        $js .= <<'ENDSCRIPT';
+        my $invalid = &mt('The quota you entered contained invalid characters.');
+        my $alert = &mt('You must enter a number');
+        my $regexp = '/^\s*(\d+\.?\d*|\.\d+)\s*$/';
+        $js .= <<"ENDSCRIPT";
 <script type="text/javascript">
-function verify_quota(formname) {
-    var newquota = formname.coursequota.value; 
-    var num_reg = /^\s*(\d+\.?\d*|\.\d+)\s*$/;
+function verify_quota() {
+    var newquota = document.setquota.coursequota.value; 
+    var num_reg = $regexp;
     if (num_reg.test(newquota)) {
-        changePage(formname,'processquota');
+        changePage(document.setquota,'processquota');
     } else {
-        alert("The quota you entered contained invalid characters.\nYou must enter a number");
+        alert("$invalid\\n$alert");
+        return false;
     }
-    return;
+    return true;
+}
+</script>
+ENDSCRIPT
+    } elsif ($phase eq 'setanon') {
+        my $invalid = &mt('The responder threshold you entered is invalid.');
+        my $alert = &mt('You must enter a positive integer.');
+        my $regexp = ' /^\s*\d+\s*$/';
+        $js .= <<"ENDSCRIPT";
+<script type="text/javascript">
+function verify_anon_threshold() {
+    var newthreshold = document.setanon.threshold.value;
+    var num_reg = $regexp;
+    if (num_reg.test(newthreshold)) {
+        if (newthreshold > 0) {
+            changePage(document.setanon,'processthreshold');
+        } else {
+            alert("$invalid\\n$alert");
+            return false;
+        }
+    } else {
+        alert("$invalid\\n$alert");
+        return false;
+    }
+    return true;
 }
 </script>
 ENDSCRIPT
@@ -1343,7 +1506,8 @@ sub hidden_form_elements {
     my $hidden_elements = 
       &Apache::lonhtmlcommon::echo_form_input(['gosearch','updater','coursecode',
           'prevphase','numlocalcc','courseowner','login','coursequota','intarg',
-          'locarg','krbarg','krbver','counter','hidefromcat','usecategory'])."\n".
+          'locarg','krbarg','krbver','counter','hidefromcat','usecategory',
+          'threshold'])."\n".
           '<input type="hidden" name="prevphase" value="'.$env{'form.phase'}.'" />';
     return $hidden_elements;
 }
@@ -1431,7 +1595,21 @@ sub handler {
                             ({href=>"javascript:changePage(document.$phase,'$phase')",
                               text=>"Result"});
                             &modify_quota($r,$cdom,$cnum,$cdesc,$domdesc,$type);
-                        } elsif ($phase eq 'viewparms') {  
+                        } elsif ($phase eq 'setanon') {
+                            &Apache::lonhtmlcommon::add_breadcrumb
+                            ({href=>"javascript:changePage(document.$phase,'$phase')",
+                              text=>"Threshold for anonymous submissions display"});
+                            &print_set_anonsurvey_threshold($r,$cdom,$cnum,$cdesc,$type);
+
+                        } elsif ($phase eq 'processthreshold') {
+                            &Apache::lonhtmlcommon::add_breadcrumb
+                            ({href=>"javascript:changePage(document.$phase,'setanon')",
+                              text=>"Threshold for anonymous submissions display"});
+                            &Apache::lonhtmlcommon::add_breadcrumb
+                            ({href=>"javascript:changePage(document.$phase,'$phase')",
+                              text=>"Result"});
+                            &modify_anonsurvey_threshold($r,$cdom,$cnum,$cdesc,$domdesc,$type);
+                        } elsif ($phase eq 'viewparms') {
                             &Apache::lonhtmlcommon::add_breadcrumb
                             ({href=>"javascript:changePage(document.$phase,'viewparms')",
                               text=>"Display settings"});
