@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Routines for messaging
 #
-# $Id: lonmsg.pm,v 1.231 2011/02/13 17:44:51 raeburn Exp $
+# $Id: lonmsg.pm,v 1.232 2011/03/05 21:32:02 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -527,6 +527,9 @@ sub sendnotification {
 to access the full message.',$url);
     my %userenv = &Apache::lonnet::get('environment',['notifywithhtml'],$toudom,$touname);
     my $subject = &mt_user($user_lh,"'New' $critical message from ").$sender;
+    unless ($subj eq '') {
+        $subject = $subj;
+    }
  
     my ($blocked,$blocktext);
     if (!$crit) {
