@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Pick a course
 #
-# $Id: lonpickcourse.pm,v 1.101 2011/01/25 02:49:42 raeburn Exp $
+# $Id: lonpickcourse.pm,v 1.103 2011/09/01 02:32:50 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1061,8 +1061,13 @@ ENDSCRIPT
     } else {
         my ($name_code,$type_code);
         if ($env{'form.cnameelement'} ne '') {
-            $name_code = 'opener.document.'.$env{'form.form'}.'.'.
-                          $env{'form.cnameelement'}.'.value=cdesc;';
+            $name_code = <<ENDNAMECODE;  
+var showcdesc = cdesc;
+if (cdesc.length > 25) {
+    showcdesc = cdesc.substr(0,25)+' ...'; 
+}
+opener.document.$env{'form.form'}.$env{'form.cnameelement'}.value=showcdesc;
+ENDNAMECODE
         }
         if ($env{'form.typeelement'} ne '') {
             $type_code = 'opener.document.'.$env{'form.form'}.'.'.
@@ -1289,7 +1294,7 @@ javascript functions used when user selects a course(s). Different behavior depe
 
 =item
 
-(g) Scantron Operator uploading a scantron file to a course - course number is written to visible form element in opener window. Child window closes.
+(g) Bubblesheet Scanning Operator uploading a bubblesheet file to a course - course number is written to visible form element in opener window. Child window closes.
 
 =item
 
