@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Pick a student from the classlist
 #
-# $Id: lonpickstudent.pm,v 1.28 2009/11/05 14:24:01 raeburn Exp $
+# $Id: lonpickstudent.pm,v 1.30 2011/06/07 20:18:59 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -50,7 +50,7 @@ sub handler {
 
     &Apache::loncommon::get_unprocessed_cgi
         ($ENV{'QUERY_STRING'},['filter','form','unameelement','udomelement',
-			       'roles','courseadvonly']);
+			       'roles','courseadvonly','clicker']);
 # Allowed?
     my $allowed;
     my $scope = $env{'request.course.id'};
@@ -133,9 +133,31 @@ ENDSCRIPT
 
 	$r->print('</p>');
 
+        $r->rflush();
+
         unless ($env{'form.courseadvonly'}) {
 
 # ------------------------------------------------------------------ Students
+
+# Do we have a clicker?
+
+            my $clicker=$env{'form.clicker'};
+            my @fragments=();
+            if ($clicker) {
+               $r->print('<h1>'.&mt('Clicker: [_1]',$clicker).'</h1>');
+               my $clicklength=length($clicker);
+               my $maxlength=$clicklength-1;
+               if ($maxlength>2) {
+                  my $minlength=$maxlength-2;
+                  if ($minlength<2) { $minlength=2; }
+                  for (my $length=$maxlength;$length>=$minlength;$length--) {
+                      for (my $startidx=0; $startidx<=$clicklength-$length; $startidx++) {
+                          push(@fragments,substr($clicker,$startidx,$length));
+                      }
+                  }
+               }
+            }
+
 	    my $result;
             my $cdom = $env{'course.'.$env{'request.course.id'}.'.domain'};
             my $cnum = $env{'course.'.$env{'request.course.id'}.'.num'};
@@ -164,6 +186,20 @@ ENDSCRIPT
 			    }
 		        }
 		        $grouplist =~ s/,$//;
+                        my $markedupclicker;
+                        if ($clicker) {
+                           $markedupclicker=(&Apache::lonnet::userenvironment($udom,$uname,'clickers'))[1];
+                           if ($markedupclicker!~/\w/) { 
+                              $markedupclicker='-'; 
+                           } else {
+                               foreach my $frag (@fragments) {
+                                  if ($markedupclicker=~/\Q$frag\E/is) {
+                                     $markedupclicker=~s/(\Q$frag\E)/<font color=\"green\" size=\"\+1\"><b>$1<\/b><\/font>/gis;
+                                     last;
+                                  }
+                               }
+                           }
+                        }
 		        $result .=&Apache::loncommon::start_data_table_row().
 		    	          '<td>'.
 			          '<input type="button" value="'.&mt('Select').'" onClick="gochoose('.
@@ -174,6 +210,7 @@ ENDSCRIPT
 				    				     $uname,$udom).
 			          '</td><td>'.$id.'</td><td>'.$section.
 			          '</td><td>'.$grouplist.'</td>'.
+                                  ($clicker?'<td>'.$markedupclicker.'</td>':'').
 			          &Apache::loncommon::end_data_table_row();
 		    }
 	        }
@@ -191,6 +228,7 @@ ENDSCRIPT
 		          '<th>'.&mt('ID').'</th>'.
 		          '<th>'.&mt('section').'</th>'.
 		          '<th>'.&mt('active group(s)').'</th>'.
+                          ($clicker?'<th>'.&mt('clicker').'</th>':'').
 		          &Apache::loncommon::end_data_table_header_row().
 		          $result.
 		          &Apache::loncommon::end_data_table());
@@ -201,6 +239,7 @@ ENDSCRIPT
 		  &Apache::loncommon::plainname($env{'user.name'},
 						$env{'user.domain'}).'</h3>');
 	$r->print($filtermsg);
+        $r->rflush();
 
 	$r->print('<p>'.&Apache::loncommon::start_data_table());
 	my %user_role=&Apache::lonnet::get_my_roles();
