@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # RSS Feeder
 #
-# $Id: lonrss.pm,v 1.47.8.1 2010/01/03 21:21:25 raeburn Exp $
+# $Id: lonrss.pm,v 1.49 2009/11/04 15:38:27 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -60,10 +60,10 @@ sub displayfeedname {
 # no, construct a name
     my $name=$filterfilename; 
     if ($name=~/^CourseBlog/) {
+        $name=&mt('Course Blog');
         if ($env{'course.'.$env{'request.course.id'}.'.type'} eq 'Community') {
             $name = &mt('Community Blog'); 
         }
-        $name=&mt('Course Blog');
 	if ($env{'course.'.$env{'request.course.id'}.'.description'}) {
 	    $name.=' '.$env{'course.'.$env{'request.course.id'}.'.description'};
 	}
@@ -261,9 +261,11 @@ sub blocking_blogdisplay {
         if ($blockcause eq 'user') {
             $output .= &mt('This is because you are a student in one or more courses in which communication is being blocked.');
             if ($html) {
-                $output .= '<br />'.
-                       &Apache::loncommon::build_block_table($startblock,
-                                                        $endblock,\%setters);
+                #$output .= '<br />'.
+                       #&Apache::loncommon::build_block_table($startblock,
+                       #                                 $endblock,\%setters);
+                 my ($blocked, $blocktext) = Apache::loncommon::blocking_status('blogs');
+                 $output .= '<br /><br />'.$blocktext;
             }
         } else {
             $output .= &mt('This is because the blog owner is a student in one or more courses in which communication is being blocked.');
