@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Simple Page Editor
 #
-# $Id: lonsimplepage.pm,v 1.59.2.2 2010/02/13 00:51:06 raeburn Exp $
+# $Id: lonsimplepage.pm,v 1.98 2011/05/03 21:38:40 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -31,6 +31,7 @@ package Apache::lonsimplepage;
 use strict;
 use Apache::Constants qw(:common);
 use Apache::loncommon;
+use Apache::lontemplate;
 use Apache::lonnet;
 use Apache::lontexconvert;
 use Apache::lonfeedback;
@@ -38,6 +39,7 @@ use Apache::lonlocal;
 use Apache::lonprintout;
 use Apache::lonxml;
 use Apache::longroup;
+use Apache::lonnavmaps();
 use HTML::Entities();
 use LONCAPA;
 
@@ -50,10 +52,10 @@ sub get_db_name {
     my $db_name;
 
     if ($dom && $crs && ($udom eq $dom) && ($uname eq $crs)) {
-	$marker =~ s/\W//g;
-	$db_name = 'grppage_'.$marker;
+        $marker =~ s/\W//g;
+        $db_name = 'grppage_'.$marker;
     } else {
-	$marker=~s/\D//g;
+        $marker=~s/\D//g;
         $db_name = 'smppage_'.$marker;
     }
     return if (!defined($marker));
@@ -69,17 +71,17 @@ sub handler {
     my $target=$env{'form.grade_target'};
 # ------------------------------------------------------------ Print the screen
     if ($target eq 'tex') {
-	$r->print(&Apache::lonprintout::print_latex_header($env{'form.latex_type'}));
-    } 
+        $r->print(&Apache::lonprintout::print_latex_header($env{'form.latex_type'}));
+    }
 
 # Is this even in a course?
     unless ($env{'request.course.id'}) {
-	if ($target ne 'tex') {
-	    &Apache::loncommon::simple_error_page($r,'','Not in a course');
-	} else {
-	    $r->print('\textbf{Not in a course}\end{document}');
-	}
-	return OK;
+        if ($target ne 'tex') {
+            &Apache::loncommon::simple_error_page($r,'','Not in a course');
+        } else {
+            $r->print('\textbf{Not in a course}\end{document}');
+        }
+        return OK;
     }
 
     my $db_name = &get_db_name($r->uri);
@@ -92,26 +94,26 @@ sub handler {
     my %groupinfo = ();
     if ($db_name =~ /^grppage_/) {
         $group = (split(m{/},$r->uri))[4];
-	$group =~ s/\W//g;
+        $group =~ s/\W//g;
         my %curr_groups = &Apache::longroup::coursegroups($dom,$crs,$group);
         if (!%curr_groups) {
-	    &Apache::loncommon::simple_error_page($r,'','Invalid group name');
-	    return OK;
+            &Apache::loncommon::simple_error_page($r,'','Invalid group name');
+            return OK;
         }
-        %groupinfo = 
-	    &Apache::longroup::get_group_settings($curr_groups{$group});
+        %groupinfo =
+        &Apache::longroup::get_group_settings($curr_groups{$group});
         $group_desc = &unescape($groupinfo{'description'});
     }
 
     if (!$db_name) {
-	&Apache::loncommon::simple_error_page($r,'','Invalid call');
-	return OK;
+        &Apache::loncommon::simple_error_page($r,'','Invalid call');
+        return OK;
     }
 
 # --------------------------------------------------------- The syllabus fields
     my %syllabusfields=&Apache::lonlocal::texthash(
        'aaa_title'         => 'Page Title',
-       'bbb_content'       => 'Content',
+       'bbb_content'       => ($target eq 'tex'?'':'Content'),
        'ccc_webreferences' => 'Web References');
     if ($group ne '') {
         $syllabusfields{'abb_links'} = &mt('Available Group Tools');
@@ -132,23 +134,23 @@ sub handler {
     if ($env{'form.ref'}) {
         $refarg = '&amp;ref='.$env{'form.ref'};
     }
-   
+
     my %syllabus=&Apache::lonnet::dump($db_name,$dom,$crs);
-       
+
 # --------------------------------------- There is such a user, get environment
 
     if ($target ne 'tex') {
         my $title = 'Simple Course Page';
         if ($group ne '') {
-            $title = 'Group Page';
+            $title = 'Simple Group Page';
         }
-	my $start_page = 
-	    &Apache::loncommon::start_page($title,undef,
-					   {'function'       => $forcestudent,
-					    'domain'         => $dom,
-					    'force_register' =>
-						$env{'form.register'},});
-	$r->print($start_page);
+        my $start_page =
+        &Apache::loncommon::start_page($title,undef,
+                       {'function'       => $forcestudent,
+                        'domain'         => $dom,
+                        'force_register' =>
+                        $env{'form.register'},});
+        $r->print($start_page);
     }
 
     if ($group ne '') {
@@ -162,12 +164,13 @@ sub handler {
                                          $env{'request.course.id'}.'/'.$group);
         $group_home_edit = &Apache::lonnet::allowed('mgh',
                                          $env{'request.course.id'}.'/'.$group);
-        if ($group_view_perm || $group_edit_perm || $group_home_view || 
+        if ($group_view_perm || $group_edit_perm || $group_home_view ||
             $group_home_edit || &Apache::longroup::check_group_access($group)) {
-            if (($env{'form.ref'} eq 'grouplist') && ($target ne 'tex')) {
+            if (($env{'form.ref'} eq 'grouplist') && ($target ne 'tex') &&
+                (!$env{'form.register'})) {
                 $r->print(&grouppage_breadcrumbs($dom,$crs,$group,$group_desc));
             }
-            if ((!$group_home_edit) && (!$group_home_view) && 
+            if ((!$group_home_edit) && (!$group_home_view) &&
                 (!$group_view_perm) && (!$group_edit_perm)) {
                 &display_group_links($r,$target,$group,'view',$refarg,%groupinfo);
                 if ($env{'form.grade_target'} ne 'tex') {
@@ -178,17 +181,17 @@ sub handler {
                 return OK;
             }
         } else {
-	    my $msg = 
-		&mt('You do not currently have rights to view this group.');
+            my $msg =
+            &mt('You do not currently have rights to view this group.');
             if ($target ne 'tex') {
-                $r->print("<p>$msg</p>".
-			  &Apache::loncommon::end_page());
+                $r->print('<p class="LC_warning">'.$msg.'</p>'.
+                &Apache::loncommon::end_page());
             } else {
                 $r->print('\textbf{'.$msg.'}\end{document}');
             }
-	    return OK;
+            return OK;
         }
-        my ($blocked,$blocktext) = 
+        my ($blocked,$blocktext) =
              &Apache::loncommon::blocking_status('groups');
         if ($blocked) {
             $r->print($blocktext);
@@ -198,183 +201,218 @@ sub handler {
     }
 
     my $allowed;
-    
+
     if ($group ne '') {
         $allowed  = $group_edit_perm;
         if (!$allowed) {
-            $allowed = $group_home_edit; 
+            $allowed = $group_home_edit;
         }
-    } else { 
+    } else {
         $allowed=&Apache::lonnet::allowed('mdc',$env{'request.course.id'});
     }
     my $privileged=$allowed;
     if (($syllabus{'uploaded.lastmodified'}) && (!$forceedit)) {
-	$forcestudent='student';
+        $forcestudent='student';
     }
 
     if ($forcestudent or $target eq 'tex') { $allowed=0; }
 
-    if ($allowed) {
-	$r->print('<p>'.
-		  &Apache::loncommon::help_open_topic('Uploaded_Templates_TextBoxes',&mt('Help with filling in text boxes'))
-                 .'<br /><a href="'.$r->uri.'?forcestudent=1'.$refarg.'">'
-                 .'<font size="+1">'.&mt('Show Student View').'</font></a>'.
-		  &Apache::loncommon::help_open_topic('Uploaded_Templates_PublicView').'</p>');
-    } elsif ($privileged and $target ne 'tex') {
-        my $edittext = &mt('Edit');
-        if ($group ne '') {
-            $edittext = &mt('Edit Group Homepage');
-        }
-	$r->print('<a href="'.$r->uri.'?forceedit=edit'.$refarg.'"><font size="+1">'.$edittext.'</font></a>');
-        if ($group ne '') {
-            if ($group_edit_perm) {
-                $r->print('&nbsp;&nbsp;&nbsp;<font size="+1">'.
-               '<a href="/adm/coursegroups?action=modify&amp;refpage=grouplist'.
-               '&amp;state=pick_task&amp;groupname='.$group.'">'.
-               &mt('Edit Group Settings').'</a></font>');
-            }
-        }    
-    } 
     if (($env{'form.uploaddoc.filename'} and $target ne 'tex') &&
-	($env{'form.storeupl'}) && ($allowed)) {
-	if ($env{'form.uploaddoc.filename'}=~/\.(gif|jpg|png|jpeg)$/i) {
-	    if ($syllabus{'uploaded.photourl'}) {
-		&Apache::lonnet::removeuploadedurl($syllabus{'uploaded.photourl'});
-	    }
+    ($env{'form.storeupl'}) && ($allowed)) {
+        if ($env{'form.uploaddoc.filename'}=~/\.(gif|jpg|png|jpeg)$/i) {
+            if ($syllabus{'uploaded.photourl'}) {
+                &Apache::lonnet::removeuploadedurl($syllabus{'uploaded.photourl'});
+            }
             if ($group ne '') {
                 $syllabus{'uploaded.photourl'}=&Apache::lonnet::userfileupload(
-                                              'uploaddoc',1,"grouppage/$group");
+                                              'uploaddoc','coursedoc',"grouppage/$group");
             } else {
-	        $syllabus{'uploaded.photourl'}=
-		     &Apache::lonnet::userfileupload('uploaddoc',1,'simplepage');
+                $syllabus{'uploaded.photourl'}=
+                &Apache::lonnet::userfileupload('uploaddoc','coursedoc','simplepage');
             }
-	}
-	$syllabus{'uploaded.lastmodified'}=time;
-	&Apache::lonnet::put($db_name,\%syllabus,$dom,$crs);
+        }
+        $syllabus{'uploaded.lastmodified'}=time;
+        &Apache::lonnet::put($db_name,\%syllabus,$dom,$crs);
     }
+#    if ($allowed && $env{'form.delupl'}) {
+#        if ($syllabus{'uploaded.photourl'}) {
+#            &Apache::lonnet::removeuploadedurl($syllabus{'uploaded.photourl'});
+#            delete($syllabus{'uploaded.photourl'});
+#            &Apache::lonnet::del('simplepage',['uploaded.photourl']);
+#        }
+#    }
     if (($allowed) && ($env{'form.storesyl'})) {
-	foreach my $syl_field (keys(%syllabusfields)) {
-	    my $field=$env{'form.'.$syl_field};
-	    chomp($field);
-	    $field=~s/\s+$//s;
-	    $field=~s/^\s+//s;
-	    $field=~s/\<br\s*\/*\>$//s;
-	    $field=&Apache::lonfeedback::clear_out_html($field,1);
-	    $syllabus{$syl_field}=$field;
-	}
-	$syllabus{'uploaded.lastmodified'}=time;
-	&Apache::lonnet::put($db_name,\%syllabus,$dom,$crs);
+        foreach my $syl_field (keys(%syllabusfields)) {
+            my $field=$env{'form.'.$syl_field};
+            chomp($field);
+            $field=~s/\s+$//s;
+            $field=~s/^\s+//s;
+            $field=~s/\<br\s*\/*\>$//s;
+            $field=&Apache::lonfeedback::clear_out_html($field,1);
+            $syllabus{$syl_field}=$field;
+        }
+        $syllabus{'uploaded.lastmodified'}=time;
+        &Apache::lonnet::put($db_name,\%syllabus,$dom,$crs);
+    }
+
+#---Print Function
+    if ($target ne 'tex') {
+        if ($allowed || $privileged) {
+            my $functions=&Apache::lonhtmlcommon::start_funclist();
+            my $url = $r->uri;
+            if ($group ne '') {
+                my $navmap=Apache::lonnavmaps::navmap->new();
+                if (ref($navmap)) {
+                    $url = &Apache::longroup::get_group_link($dom,$crs,$group,$navmap);
+                }
+            }
+            if ($allowed) {
+                $url .= (($url=~/\?/)?'&amp;':'?').'forcestudent=1';
+                $functions.=&Apache::lonhtmlcommon::add_item_funclist(
+                                '<a href="'.$url.'">'
+                               .&mt('Show Student View').'</a>'
+                               .&Apache::loncommon::help_open_topic(
+                                    'Uploaded_Templates_PublicView'));
+            } elsif ($privileged) {
+                my $edittext = &mt('Edit');
+                $url .= (($url=~/\?/)?'&amp;':'?').'forceedit=edit'.$refarg;
+                if ($group ne '') {
+                    $edittext = &mt('Edit Group Homepage');
+                }
+                $functions.=&Apache::lonhtmlcommon::add_item_funclist(
+                                '<a href="'.$url.'">'
+                               .$edittext.'</a>');
+                if ($group ne '') {
+                    if ($group_edit_perm) {
+                        $functions.=&Apache::lonhtmlcommon::add_item_funclist(
+                                        '<a href="/adm/coursegroups'
+                                       .'?action=modify&amp;refpage=grouplist'
+                                       .'&amp;state=pick_task&amp;groupname='
+                                       .$group.'">'
+                                       .&mt('Edit Group Settings')
+                                       .'</a>');
+                       }
+                    }
+            }
+            $functions.=&Apache::lonhtmlcommon::end_funclist();
+            $r->print(&Apache::loncommon::head_subbox($functions));
+        }
+    }
+
+#---Print help Text
+    if($target ne 'tex'){
+        if ($allowed) {
+            $r->print(&Apache::loncommon::help_open_topic('Uploaded_Templates_TextBoxes',&mt('Help with filling in text boxes')));
+        }
     }
 
 # ---------------------------------------------------------------- Get syllabus
-    if ((($syllabus{'uploaded.lastmodified'}) && 
-         (($group ne '' && ($group_home_view || $group_edit_perm ||  
+    if ((($syllabus{'uploaded.lastmodified'}) &&
+         (($group ne '' && ($group_home_view || $group_edit_perm ||
            $group_view_perm)) || ($group eq ''))) || ($allowed)) {
-	if ($syllabus{'uploaded.photourl'}) {
-	    &Apache::lonnet::allowuploaded('/adm/smppg',
-					   $syllabus{'uploaded.photourl'});
-	    
-	    my $image='<img src="'.$syllabus{'uploaded.photourl'}.'"
-                            align="right" />';
-	    if ($target eq 'tex') {
-		$image=&Apache::lonxml::xmlparse($r,'tex',$image);
-	    }
-	    $r->print($image);
-	}
-	if ($allowed) {
-	    $r->print(
-		      '<form method="post" enctype="multipart/form-data">'.
-		      '<input type="hidden" name="forceedit" value="edit" />'.
-		      '<h3>'.&mt('Upload a Photo').'</h3>'.
-		      '<input type="file" name="uploaddoc" size="50" />'.
-		      '<input type="submit" name="storeupl" value="'.&mt('Upload').'" />'.
-		      '</form><form method="post">'.
-                      '<input type="hidden" name="forceedit" value="edit" />');
-	}
-	foreach my $field (sort(keys(%syllabusfields))) {
-	    if (($syllabus{$field}) || ($allowed) || 
-                ($field eq 'abb_links' && $group ne '')) {
-		my $message=$syllabus{$field};
-                if (!&Apache::lonfeedback::contains_block_html($message)) {
-                    &Apache::lonfeedback::newline_to_br(\$message);
-                }
-		$message
-		    =~s/(https*\:\/\/[^\s]+)/\<a href=\"$1\"\>\<tt\>$1\<\/tt\>\<\/a\>/g;
-		if ($allowed) {
-		    $message=&Apache::lonspeller::markeduptext($message);
-		}
-		if ($target ne 'tex') {
-		    $message=&Apache::lontexconvert::msgtexconverted($message);
-		}
-                if ($field eq 'abb_links' && $group ne '') {
-                    $r->print('<br /><input type="hidden" name="'.$field.
-                                          '" value="'.$syllabus{$field}.'" />');
-                    &display_group_links($r,$target,$group,'edit',$refarg,
-                                         %groupinfo);
-                    $r->print('<br />');
-                } elsif ($field eq 'aaa_title') {
-                    if ($target ne 'tex') {
-                        $r->print('<h1>'.$message.'</h1>');
-                    } else {
-                        my $safeinit;
-                        $r->print(&Apache::lonxml::xmlparse($r,'tex','<h1>'.$message.'</h1>'));
-                    }
-                    if ($allowed) {
-                        if ($env{'form.grade_target'} ne 'tex') {
-                            $r->print(
-                                      '<br /><h3>'.&mt('Title').'</h3><textarea cols="80" rows="2" name="'.$field.'">'.
-                                      &HTML::Entities::encode($syllabus{$field},'"&<>').
-                                      '</textarea><input type="submit" name="storesyl" value="'.&mt('Save').'" />');
-                        } else {
-                            my $safeinit;
-                            $r->print(&Apache::lonxml::xmlparse($r,'tex',$syllabus{$field},$safeinit));
-                        }
-                    }
-                } else {
-		    if (($field ne 'bbb_content') || ($allowed)) {
-			if ($target ne 'tex') {
-			    $r->print('<h3>'.$syllabusfields{$field}.'</h3>');
-			} else {
-			    my $safeinit;
-			    $r->print(&Apache::lonxml::xmlparse($r,'tex','<h3>'.$syllabusfields{$field}.'</h3>'));
+        #Print the title
+        my $titletext=&HTML::Entities::encode($syllabus{'aaa_title'},'<>&"');
+        if ($target ne 'tex') {
+            if ($allowed) {
+            }
+            $r->print('<h2>'.$titletext.'</h2>');
+        } else {
+            my $safeinit;
+            $r->print(&Apache::lonxml::xmlparse($r,'tex','<h1>'.$titletext.'</h1>'));
+        }
+        if ($allowed) {
+            if ($env{'form.grade_target'} ne 'tex') {
+                #editbox for title
+                $r->print('<form method="post" action="" enctype="multipart/form-data">');
+				&Apache::lontemplate::print_start_template($r,&mt('Title'),'LC_Box');
+				$r->print($titletext);
+				$r->print("<br /><div>");
+				&Apache::lontemplate::print_textarea_template($r, $syllabus{'aaa_title'},
+					'aaa_title', Apache::lontemplate->RICH_TEXT_ALWAYS_OFF);
+				&Apache::lontemplate::print_saveall_template($r);
+				$r->print("</div>");
+				&Apache::lontemplate::print_end_template($r);
+            } else {
+                my $safeinit;
+                $r->print(&Apache::lonxml::xmlparse($r,'tex',$syllabus{'aaa_title'},$safeinit));
+            }
+        }
+
+        #print the image
+        my $image='';
+        if ($syllabus{'uploaded.photourl'}) {
+            &Apache::lonnet::allowuploaded('/adm/smppg',
+                    $syllabus{'uploaded.photourl'});
+
+            $image='<img src="'.$syllabus{'uploaded.photourl'}
+                  .'" alt="'.&mt('Image').'" />';
+            if ($target eq 'tex') {
+                $image=&Apache::lonxml::xmlparse($r,'tex',$image);
+            }
+        }
+
+        if ($allowed) {
+            &Apache::lontemplate::print_start_template($r, &mt('Upload a Photo'),'LC_Box');
+            $r->print($image);
+            $r->print("<br /><br />");
+            $r->print(
+                '<input type="hidden" name="forceedit" value="edit" />'.
+                '<input type="file" name="uploaddoc" size="50" />'.
+                '<input type="submit" name="storeupl" value="'.&mt('Upload').'" />'.
+                '<input type="hidden" name="forceedit" value="edit" />');
+            &Apache::lontemplate::print_end_template($r);
+    
+
+#            if ($syllabus{'uploaded.photourl'}) {
+#                $r->print('<input type="submit" name="delupl"'
+#                         .' value="'.&mt('Delete Photo').'" />');
+#            }
+        }
+        #Image in Student view and printout.
+        else {
+            $r->print($image);
+        }
+       	
+        my $links_handler = sub { 
+        	my ($r, $field, $message, $group, $data_ref, $fields_ref, $target, $allowed) = @_;
+			if ($group ne '') {
+				my %data = %{$data_ref};
+				my %fields = %{$fields_ref};
+				$r->print('<br /><input type="hidden" name="'.$field.
+					'" value="'.$data{$field}.'" />');
+				&display_group_links($r, $target, $group, 'edit', $refarg, %groupinfo);
+				$r->print('<br />');
 			}
-		    }
-		    if ($target ne 'tex') {
-			$r->print('<blockquote>'.
-				  $message.'</blockquote>');
-		    } else {
-			my $safeinit;
-			$r->print(&Apache::lonxml::xmlparse($r,'tex',$message));
-		    }
-		    if ($allowed) {
-			if ($target ne 'tex') {
-			    $r->print('<br /><textarea cols="80" rows="24" name="'.$field.'" id="'.$field.'">'.
-                                      &HTML::Entities::encode($syllabus{$field},'"&<>').
-				      '</textarea><input type="submit" name="storesyl" value="'.&mt('Save').'" />');
-			} else {
-			    my $safeinit;
-			    $r->print(&Apache::lonxml::xmlparse($r,'tex',$syllabus{$field},$safeinit));
-			}
-		    }
-		}
-	    }
-	}
-	if ($allowed && ($env{'form.grade_target'} ne 'tex')) {
-	    $r->print(&Apache::lonhtmlcommon::htmlareaselectactive
-		      ('bbb_content').'</form>');
-	}
-	if ($env{'form.grade_target'} ne 'tex') {$r->print('</p>');}
+        };
+        my $title_handler = sub {};
+		my %custom_handlers = (
+			'abb_links' => $links_handler,
+			'aaa_title' => $title_handler
+		);
+		&Apache::lontemplate::print_template_fields($r, \%syllabus, \%syllabusfields, 
+			$target, $allowed, Apache::lontemplate->RICH_TEXT_DETECT_HTML, \%custom_handlers, $group);
+		
+        if ($allowed && ($env{'form.grade_target'} ne 'tex')) {
+            $r->print(&Apache::lonhtmlcommon::htmlareaselectactive().
+                      '</form>');
+        }
+
     } else {
         if ($group ne '') {
             &display_group_links($r,$target,$group,'view',$refarg,%groupinfo);
         } else {
-	    $r->print(&mt('<p>No page information provided.</p>'));
+            my $text=&mt('No page information provided.');
+            if ($target ne 'tex') {
+                $r->print('<p class="LC_info">'.$text.'</p>');
+            } else {
+            $r->print($text)
+            }
         }
     }
     if ($env{'form.grade_target'} ne 'tex') {
-	$r->print(&Apache::loncommon::end_page());
+        $r->print(&Apache::loncommon::end_page());
     } else {
-	$r->print('\end{document}');
+        $r->print('\end{document}');
     }
     return OK;
 }
@@ -441,7 +479,7 @@ sub display_group_links {
         my $output;
         if ($context eq 'edit') {
             $output = &mt('No group functionality.');
-        } else {  
+        } else {
             $output = &mt('No group functionality (e.g., e-mail, discussion, chat room or file upload) is currently available to you in this group: [_1].','<b>'.&unescape($groupinfo{'description'}).'</b>');
         }
         if ($target eq 'tex') {
@@ -461,11 +499,10 @@ sub grouppage_breadcrumbs {
           title=>"Display Groups"},
         {href=>"/adm/$cdom/$cnum/$group/smppg?ref=grouplist",
           text=>&mt('Group:')." $description",
-          title=>&mt("Go to group's home page"),
-          no_mt=>1,},
+          title=>"Go to group's home page"},
         );
     my $output .= &Apache::lonhtmlcommon::breadcrumbs(&mt('Group page - [_1]',
-                      $description),undef,undef,undef,undef,1);
+                                                           $description));
     return $output;
 }
 
