@@ -1,5 +1,5 @@
 #
-# $Id: lonsupportreq.pm,v 1.55.4.3 2010/04/14 07:31:21 raeburn Exp $
+# $Id: lonsupportreq.pm,v 1.66 2011/03/03 17:29:29 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -37,7 +37,7 @@ use Apache::lonnet;
 use Apache::lonlocal;
 use Apache::lonacc();
 use Apache::courseclassifier;
-use LONCAPA;
+use LONCAPA qw(:DEFAULT :match);
  
 
 sub handler {
@@ -57,7 +57,7 @@ sub handler {
         &Apache::lonacc::get_posted_cgi($r);
     }
     my $function = $env{'form.function'};
-    my $origurl = &unescape($env{'form.origurl'});
+    my $origurl = $env{'form.origurl'};
     my $command = $env{'form.command'};
 
     if ($command eq 'process') {
@@ -70,15 +70,18 @@ sub handler {
     
 sub print_request_form {
     my ($r,$origurl,$function) = @_;
-    my ($os,$browser,$bversion,$uhost,$uname,$udom,$uhome,$urole,$usec,$email,$cid,$cdom,$cnum,$ctitle,$ccode,$sectionlist,$lastname,$firstname,$server,$formname);
+    my ($os,$browser,$bversion,$uhost,$uname,$udom,$uhome,$urole,$usec,$email,$cid,
+        $cdom,$cnum,$ctitle,$ccode,$sectionlist,$lastname,$firstname,$server,
+        $formname,$public);
     $function = &Apache::loncommon::get_users_function() if (!$function);
     $ccode = '';
     $os = $env{'browser.os'};
     $browser = $env{'browser.type'};
     $bversion = $env{'browser.version'};
     $uhost = $env{'request.host'};
-    my ($uname,$udom);
-    if (($env{'user.name'} ne 'public') && ($env{'user.domain'} ne 'public')) {
+    if (($env{'user.name'} eq 'public') && ($env{'user.domain'} eq 'public')) {
+        $public = 1;
+    } else {
         $uname = $env{'user.name'};
         $udom = $env{'user.domain'};
     }
@@ -175,7 +178,20 @@ END
         my ($sec,$grp) = split(/:/,$section);
         $groupid{$sec} = $grp;
     }
-    &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},['codedom']);
+    &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},['codedom',
+                                                 'useremail','useraccount']);
+    if ($env{'form.origurl'} eq '/adm/createaccount') {
+        if ($email eq '') {
+            if ($env{'form.useremail'} =~ /^[^\@]+\@[^\@]+$/) {
+                $email = &HTML::Entities::encode($env{'form.useremail'},'"<>&');
+            }
+        }
+        if ($uname eq '') {
+            if ($env{'form.useraccount'} =~ /^$match_username$/) {
+                $uname = &HTML::Entities::encode($env{'form.useraccount'},'"<>&');
+            }
+        }
+    }
     my $codedom = &get_domain();
     my $details_title;
     if ($codedom) {
@@ -228,7 +244,7 @@ function initialize_codes() {
     }
 	
     my $js = '<script type="text/javascript">'."\n$scripttag\n$jscript\n".
-	'</script>';
+	     $loaditems.'</script>';
     my %add_entries = (topmargin    => "0",
 		       marginheight => "0",
 		       onLoad       =>"initialize_codes()",);
@@ -269,7 +285,7 @@ function initialize_codes() {
                &Apache::lonhtmlcommon::row_closure();
     $num ++;
     $i = $num%2;
-    if (defined($uname)) {
+    if (($env{'user.name'} =~ /^$match_username$/) && (!$public)) {
         $output .= &Apache::lonhtmlcommon::row_title($lt{'emac'},undef,$css[$i]).
                    '<input type="text" size="50" name="cc" value="" /><br />'."\n".
                    &Apache::lonhtmlcommon::row_closure();
@@ -281,30 +297,33 @@ function initialize_codes() {
                      &HTML::Entities::encode($udom,'"<>&').'" />';
     my $uname_input = '<input type="hidden" name="uname" value="'.
                       &HTML::Entities::encode($uname,'"<>&').'" />'; 
-    if (defined($uname) && defined($udom)) {
+    if (($env{'user.name'} =~ /^$match_username$/) && 
+        ($env{'user.domain'} =~ /^$match_domain$/) && (!$public)) {
         $output .= '<i>'.$lt{'unme'}.'</i>:&nbsp;'.$uname.'&nbsp;&nbsp;<i>'.$lt{'doma'}.'</i>:&nbsp;'.$udom.$udom_input.$uname_input;
     } else {
         my $udomform = '';
         my $unameform = '';
-        if (defined($udom)) {
+        if (($env{'user.domain'} =~ /^$match_domain$/) && (!$public)) {
             $output .= $lt{'entu'};
-        } elsif (defined($uname)) {
+        } elsif (($env{'user.name'} =~ /^$match_username$/) && (!$public)) { 
             $output .= $lt{'chdo'};
         } else {
             $output .= $lt{'entr'};
         }
         $output .= '<br />';
-        if (defined($udom)) {
-            $udomform = '<i>'.$lt{'doma'}.'</i>:&nbsp;'.$udom.$udom_input;
-        } elsif (defined($uname)) {
-            $unameform = '<i>'.$lt{'unme'}.'</i>:&nbsp;'.$uname.'&nbsp;&nbsp;'.$uname_input;
+        if (!$public) {
+            if ($env{'user.domain'} =~ /^$match_domain$/) {
+                $udomform = '<i>'.$lt{'doma'}.'</i>:&nbsp;'.$udom.$udom_input;
+            } elsif ($env{'user.name'} =~ /^$match_username$/) {
+                $unameform = '<i>'.$lt{'unme'}.'</i>:&nbsp;'.$uname.'&nbsp;&nbsp;'.$uname_input;
+            }
         }
         if ($udomform eq '') {
             $udomform = '<i>'.$lt{'doma'}.'</i>:&nbsp;';
             $udomform .= &Apache::loncommon::select_dom_form($codedom,'udom');
         }
         if ($unameform eq '') {
-            $unameform= '<i>'.$lt{'unme'}.'</i>:&nbsp;<input type="text" size="12" name="uname" value="'.$uname.'" />&nbsp;&nbsp;';
+            $unameform= '<i>'.$lt{'unme'}.'</i>:&nbsp;<input type="text" size="20" name="uname" value="'.$uname.'" />&nbsp;&nbsp;';
         }
         $output .= $unameform.$udomform;
     }
@@ -338,12 +357,13 @@ function initialize_codes() {
                 $output .= $lt{'enin'}.':&nbsp;
                   <input type="text" name="coursecode" size="15" value="" />';
             } else {
+                my @standardnames = &Apache::loncommon::get_standard_codeitems();
                 my $lasttitle = $numtitles;
                 if ($numtitles > 4) {
                     $lasttitle = 4;
                 } 
                 $output .= '<table><tr><td>'.$codetitles[0].'<br />'."\n".
-                      '<select name="'.$codetitles[0].'" onchange="courseSet('."'$codetitles[0]'".')">'."\n".
+                      '<select name="'.$standardnames[0].'" onchange="courseSet('."'$codetitles[0]'".')">'."\n".
                       ' <option value="-1" />'.$lt{'sele'}."\n";
                 my @items = ();
                 my @longitems = ();
@@ -372,7 +392,7 @@ function initialize_codes() {
                 $output .= '</select></td>';
                 for (my $i=1; $i<$numtitles; $i++) {
                     $output .= '<td>'.$codetitles[$i].'<br />'."\n".
-                     '<select name="'.$codetitles[$i].'" onchange="courseSet('."'$codetitles[$i]'".')">'."\n".
+                     '<select name="'.$standardnames[$i].'" onchange="courseSet('."'$codetitles[$i]'".')">'."\n".
                      '<option value="-1">&lt;-'.$lt{'pick'}.' '.$codetitles[$i-1].'</option>'."\n".
                      '</select>'."\n".
                      '</td>'."\n";
@@ -380,7 +400,7 @@ function initialize_codes() {
                 $output .= '</tr></table>';
                 if ($numtitles > 4) {
                     $output .= '<br /><br />'.$codetitles[$numtitles].'<br />'."\n".
-                          '<select name="'.$codetitles[$numtitles].'" onchange="courseSet('."'$codetitles[$numtitles]'".')">'."\n".
+                          '<select name="'.$standardnames[$numtitles].'" onchange="courseSet('."'$codetitles[$numtitles]'".')">'."\n".
                           '<option value="-1">&lt;-'.$lt{'pick'}.' '.$codetitles[$numtitles-1].'</option>'."\n".
                           '</select>'."\n";
                 }
@@ -431,7 +451,7 @@ function initialize_codes() {
                &Apache::lonhtmlcommon::row_closure();
     $num ++;
     $i = $num%2; 
-    if (defined($uname)) {
+    if (($env{'user.name'} =~ /^$match_username$/) && (!$public)) {
         $output .= &Apache::lonhtmlcommon::row_title($lt{'opfi'},undef,$css[$i]).
                    ' <input type="file" name="screenshot" size="20" /><br />'.$lt{'uplf'}."\n".
         &Apache::lonhtmlcommon::row_closure();
@@ -509,17 +529,21 @@ sub print_request_receipt {
     &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},\@formvars);
     my $coursecode = $env{'form.coursecode'};
     if ($coursecode eq '') {
-        if (defined($env{'form.Year'})) {
-            $coursecode .= $env{'form.Year'};
-        }
-        if (defined($env{'form.Semester'})) {
-            $coursecode .= $env{'form.Semester'};
-        }
-        if (defined($env{'form.Department'})) {
-            $coursecode .= $env{'form.Department'};
-        }
-        if (defined($env{'form.Number'})) {
-            $coursecode .= $env{'form.Number'};
+        my $totcodes = 0;
+        my %coursecodes;
+        $totcodes = &Apache::courseclassifier::retrieve_instcodes(\%coursecodes,$defdom,$totcodes);
+        my @standardnames = &Apache::loncommon::get_standard_codeitems();
+        if ($totcodes > 0) {
+            my $noregexps = 1;
+            $coursecode = 
+                &Apache::courseclassifier::instcode_from_selectors($defdom,$noregexps);
+        } 
+        if ($coursecode eq '') {
+            foreach my $item (@standardnames) {
+                if ((defined($env{'form.'.$item})) && ($env{'form.'.$item} ne '-1')) {
+                    $coursecode .= $env{'form.'.$item};
+                }
+            }
         }
     }
     my %lt = &Apache::lonlocal::texthash (
@@ -534,7 +558,6 @@ sub print_request_receipt {
                  sourceurl   => 'URL',
                  date        => 'Date/Time',
                  secn        => 'Section',
-                 asup        => 'A support request has been sent to',
                  warn        => 'Warning: Problem with support e-mail address',
                  your        => 'Your support request contained the following information',
                  sect        => 'section',
@@ -559,7 +582,7 @@ sub print_request_receipt {
                 if (!(grep(/^\Q$cc\E$/,@ok_ccs))) {
                     push(@ok_ccs,$cc);
                 }
-            } else {
+            } elsif ($cc ne '') {
                 if (!(grep(/^\Q$cc\E$/,@bad_ccs))) {
                     push(@bad_ccs,$cc);
                 }
@@ -576,14 +599,14 @@ sub print_request_receipt {
         }
     }
     $env{'form.user'} = "'".$env{'form.uname'}.':'.$env{'form.udom'}."'";
-    $env{'form.csri'} = $env{'form.title'}.' - '.$coursecode.' - '.$lt{'sect'}.': '.$env{'form.section'};
+    $env{'form.crsi'} = $env{'form.title'}.' - '.$coursecode.' - '.$lt{'sect'}.': '.$env{'form.section'};
     my $supportmsg = <<END;
 $lt{'username'}: $env{'form.username'}
 $lt{'email'}: $env{'form.email'}
 $lt{'cc'}: $okcclist
 $lt{'user'}: $env{'form.user'}
 $lt{'phone'}: $env{'form.phone'}
-$lt{'crsi'}: $env{'form.csri'}
+$lt{'crsi'}: $env{'form.crsi'}
 $lt{'subject'}: $env{'form.subject'}
 $lt{'description'}: $env{'form.description'}
 $lt{'sourceurl'}: $env{'form.sourceurl'}
@@ -665,14 +688,20 @@ END
             $bad_email = 1;
         }
     }
-    if ($bad_email) {
-        $r->print('
- <h3>'.$lt{'warn'}.'</h3>'.
-&mt('As the e-mail address provided for this LON-CAPA server ([_1]) does not appear to be a valid e-mail address, your support request has <b>not</b> been sent to the LON-CAPA support staff or administrator at your institution.',$to).' '.&mt('Instead a copy has been sent to the LON-CAPA support team at Michigan State University.')); 
-            $to = 'helpdesk@lon-capa.org';
+
+    my $message;
+    if (!$bad_email) {
+        $message = &Apache::lonhtmlcommon::confirm_success(
+            &mt('A support request has been sent to [_1]','<tt>'.$to.'</tt>'));
     } else {
-        $r->print('<h3>'.$lt{'asup'}.' '.$to.'</h3>');
+        $message = &Apache::lonhtmlcommon::confirm_success(
+            $lt{'warn'}.'<br />'
+           .&mt('As the e-mail address provided for this LON-CAPA server ([_1]) does not appear to be a valid e-mail address, your support request has [_2]not[_3] been sent to the LON-CAPA support staff or administrator at your institution.','<tt>'.$to.'</tt>','<b>','</b>')
+           .' '.&mt('Instead a copy has been sent to the LON-CAPA support team at Michigan State University.'),1); 
+        $to = 'helpdesk@lon-capa.org';
     }
+    $r->print(&Apache::loncommon::confirmwrapper($message));
+
     if (defined($env{'form.email'})) {
         $env{'form.email'} =~ s/^\s+//;
         $env{'form.email'} =~ s/\s+$//;
@@ -720,7 +749,7 @@ END
         $fname = $1;
         $displaymsg .= '<br />'
                       .&mt('An uploaded screenshot file [_1] ([_2] bytes) was included in the request sent by [_3].'
-                          ,'<span class="LC_filename">'.$fname.'<span>'
+                          ,'<span class="LC_filename">'.$fname.'</span>'
                           ,$attachmentsize
                           ,$env{'user.name'}.':'.$env{'user.domain'}
                        );
@@ -750,6 +779,8 @@ END
     if ($bcc ne '') {
         $msg->add("Bcc" => $bcc);
     }
+    $msg->attr("content-type"         => "text/plain");
+    $msg->attr("content-type.charset" => "UTF-8");
 
     if ($attachmentpath) {
         my ($type, $encoding) = MIME::Types::by_suffix($attachmentpath);
@@ -837,13 +868,16 @@ sub print_header {
     } else {
         $reviewtext = &mt('Please review the information in "Log-in help" if you are unable to log-in.');
     }
+    if ($origurl eq '') {
+        $origurl = 'javascript:history.go(-1)';
+    }
     $r->print(<<END);
 <table width="620" border="0" cellspacing="0" cellpadding="0" height="55">   <tr height="50">    <td width='5'>&nbsp;</td>
    <td>
     <fieldset>
       <legend>
-        <img src="$location/lonIcons/minilogo.gif" height="20" width="29" valign="bottom" />&nbsp;&nbsp;
-       <b>LON-CAPA $lt{'headline'}</b>
+        <img src="$location/lonIcons/minilogo.gif" height="20" width="29" valign="bottom" />
+        LON-CAPA $lt{'headline'}
       </legend>
  <table id="LC_helpmenu_links">
    <tr>
