@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Syllabus
 #
-# $Id: lonsyllabus.pm,v 1.110 2010/08/07 19:23:51 raeburn Exp $
+# $Id: lonsyllabus.pm,v 1.111 2011/06/16 10:00:57 christianto Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -333,22 +333,24 @@ ENDSCRIPT
         } else {
             $r->print(' '.&Apache::lonxml::xmlparse($r,'tex',$element).' & ');
         }
+        my @coursepersonlist;
         foreach (split(/\,/,$coursepersonnel{$element})) {
             my ($puname,$pudom)=split(/\:/,$_);
             if ($target ne 'tex') {
                 my $courseperson = &Apache::loncommon::plainname($puname,$pudom);
                 if (($env{'user.name'} eq '') || ($env{'user.name'} eq 'public') ||
                     ($env{'user.domain'} eq '') || ($env{'user.domain'} eq 'public')) {
-                    $r->print(' '.$courseperson);
+                    push(@coursepersonlist,$courseperson);
                 } else {
-                    $r->print(' '.&Apache::loncommon::aboutmewrapper($courseperson,
+                    push(@coursepersonlist,&Apache::loncommon::aboutmewrapper($courseperson,
                               $puname,$pudom));
                 }
             } else {
-                $r->print(' '.&Apache::loncommon::plainname($puname,
+                push(@coursepersonlist,&Apache::loncommon::plainname($puname,
                               $pudom).' ');
             }
         }
+        $r->print(join(", ",@coursepersonlist));
         if ($target ne 'tex') {
             my $lastclose=$element eq $lastpers?1:0;
             $r->print(&Apache::lonhtmlcommon::row_closure($lastclose));
