@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lontrackstudent.pm,v 1.30 2009/08/28 22:47:07 raeburn Exp $
+# $Id: lontrackstudent.pm,v 1.32 2010/06/06 21:34:23 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -433,14 +433,25 @@ sub display_values {
     my ($action,$values)=@_;
     my $result='<table>';
     if ($action eq 'CSTORE') {
+        my $is_anon;
 	my %values=map {split('=',$_,-1)} split(/\&/,$values);
 	foreach my $key (sort(keys(%values))) {
+            my $unesc_key = &unescape($key);
+            if ($values{$key} eq 'anonsurvey' || $values{$key} eq 'anonsurveycred') {
+                if ($unesc_key =~ /^resource\..+\.type$/) {
+                    $is_anon = 1;
+                    last;
+                }
+            }
 	    $result.='<tr><td align="right">'.
-		&unescape($key).
+		$unesc_key.
 		'</td><td>=</td><td align="left">'.
 		&unescape($values{$key}).'</td></tr>';
 	}
 	$result.='</table>';
+        if ($is_anon) {
+            $result = '<span class="LC_warning">'.&mt('Anonymous Survey Submission: details not shown').'</span>';
+        }
     } elsif ($action eq 'POST') {
 	my %values;
         foreach my $pair (split(/\&/,$values)) {
@@ -525,15 +536,6 @@ sub handler {
     my $r=shift;
     my $c = $r->connection();
     #
-    # Check for overloading here and on the course home server
-    my $loaderror=&Apache::lonnet::overloaderror($r);
-    if ($loaderror) { return $loaderror; }
-    $loaderror=
-        &Apache::lonnet::overloaderror
-        ($r,
-         $env{'course.'.$env{'request.course.id'}.'.home'});
-    if ($loaderror) { return $loaderror; }
-    #
     # Check for access
     if (! &Apache::lonnet::allowed('vsa',$env{'request.course.id'})) {
         $env{'user.error.msg'}=
