@@ -1,5 +1,5 @@
 #
-# $Id: lonwhatsnew.pm,v 1.99.2.2 2010/01/28 22:37:18 raeburn Exp $
+# $Id: lonwhatsnew.pm,v 1.101.2.1 2011/05/12 16:53:02 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -88,7 +88,7 @@ sub handler {
 
     if ( ! $env{'request.course.fn'} || ! $checkallowed{'whatsnew'}) {
         # Not in a course, or no whn priv in course
-        $env{'user.error.msg'}="/adm/whatsnew::whn:0:0:Cannot display what's new page";
+        $env{'user.error.msg'}="/adm/whatsnew:whn:0:0:Cannot display what's new page";
         return HTTP_NOT_ACCEPTABLE;
     }
 
@@ -348,11 +348,11 @@ sub display_actions_box {
             &GDBM_READER(),0640)) {
             my $furl=&HTML::Entities::encode($bighash{'first_url'},'"<>&');
             untie(%bighash);
-            $r->print('<span style="font-size: larger;"><a href="'.$furl.'">'.$lt{'gtfr'}.
-                  '</a></span><br />');
+            $header .= '<b><a href="'.$furl.'">'.$lt{'gtfr'}.
+                  '</a></b><br />';
         }
     }
-    $r->print(&mt('Page set to be displayed after you have selected a role in this '.$lctype).'.'
+    $header .= &mt('Page set to be displayed after you have selected a role in this '.$lctype).'.'
               .' <span class="LC_nobreak">'
               .&mt('Currently: [_1].','<i>'.$currinit.'</i>')
               .'&nbsp;&nbsp;'
@@ -363,9 +363,9 @@ sub display_actions_box {
                   ,'</a>'
                   ,'<a href="/adm/preferences?action=changecourseinit&amp;refpage='.$refpage.'">'
                   ,'</a>')
-              .' </span><br /><hr />');
+              .' </span>';
 
-    $r->print($header);
+    $r->print(&Apache::loncommon::head_subbox($header));
 
     if ($command eq 'reset') {
         $result = &process_reset($cdom,$crs);
@@ -974,6 +974,9 @@ sub check_thresholds {
         if ($resource->handgrade($part) eq 'yes') {
             next;
         }
+        if ($resource->is_anonsurvey($part)) {
+            next;
+        }
         if ($resource->is_survey($part)) {
             next;
         }
@@ -1166,7 +1169,6 @@ sub getnormalmail {
             &Apache::lonmsg::unpackmsgid($msgid);
         if (($fromcid) && ($fromcid eq $env{'request.course.id'})) {
             if (defined($sendtime) && $sendtime!~/error/) {
-                my $numsendtime = $sendtime;
                 if ($status eq 'new') {
                 $sendtime = &Apache::lonlocal::locallocaltime($sendtime);
 		    $msgcount ++;
@@ -1198,7 +1200,6 @@ sub getcritmail {
             &Apache::lonmsg::unpackmsgid($msgid);
         if (($fromcid) && ($fromcid eq  $env{'request.course.id'})) {
             if (defined($sendtime) && $sendtime!~/error/) {
-                my $numsendtime = $sendtime;
                 $sendtime = &Apache::lonlocal::locallocaltime($sendtime);
                 $critmsgcount ++;
                 if ($shortsubj eq '') {
@@ -1433,7 +1434,7 @@ sub checkversions {
                                                      'lastrevisiondate');
                     $revdate =  &Apache::lonlocal::locallocaltime($revdate);
                     my $linkurl=&Apache::lonnet::clutter($key);
-                    my $usedversion=$navmap->usedVersion('version_'.$linkurl);
+                    my $usedversion=$navmap->usedVersion($linkurl);
                     my @resources = $navmap->getResourceByUrl($linkurl,1);
                     if (($usedversion) && ($usedversion ne 'mostrecent')) {
                         $version = $usedversion;     
