@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler for requesting to have slots added to a students record
 #
-# $Id: slotrequest.pm,v 1.107 2010/05/27 04:44:33 raeburn Exp $
+# $Id: slotrequest.pm,v 1.110 2011/01/03 18:04:56 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -562,7 +562,11 @@ sub release_reservation {
     if ($mgr eq 'F') {
 	$msg = &mt('Released Reservation for user: [_1]',"$uname:$udom");
     } else {
-	$msg = &mt('Released Reservation: [_1]',$description);
+	$msg = '<span style="font-weight: bold;">'.&mt('Released reservation: [_1]',$description).'</span><br /><br />';
+        my $person = &Apache::loncommon::plainname($env{'user.name'},$env{'user.domain'});
+        my $subject = &mt('Reservation change: [_1]',$description);
+        my $msgbody = &mt('Reservation released by [_1] for [_2].',$person,$description);
+        $msg .= &slot_change_messaging($slot{'reservationmsg'},$subject,$msgbody,'release');
     }
     return (1,$msg);
 }
@@ -629,7 +633,6 @@ sub get_slot {
 	my $description1=&get_description($slot_name,\%slot);
 	%slot=&Apache::lonnet::get_slot($env{'form.slotname'});
 	my $description2=&get_description($env{'form.slotname'},\%slot);
-	$r->print('<p>'.&mt('Already have a reservation: [_1].',$description1).'</p>');
 	if ($slot_name ne $env{'form.slotname'}) {
 	    $r->print(<<STUFF);
 <form method="post" action="/adm/slotrequest">
@@ -638,19 +641,24 @@ sub get_slot {
    <input type="hidden" name="releaseslot" value="$slot_name" />
    <input type="hidden" name="command" value="change" />
 STUFF
-            $r->print('<p>'
-                     .&mt('You can either [_1]Change[_2] your reservation from [_3] to [_4] or'
-                         ,'<input type="submit" name="change" value="'
-                         ,'" />'
-                         ,'<b>'.$description1.'</b>'
-                         ,'<b>'.$description2.'</b>')
-                     .'<br /></p>'
-            );
-	    &return_link($r);
+            $r->print('<p class="LC_error">'.&mt('Reservation currently unchanged').'</p>');
+            if ($slot_name ne '') {
+                $r->print('<p>'.&mt('To complete the transaction you [_1]must confirm[_2] you want to [_3]process the change[_4] to [_5].'
+                         ,'<b>','</b>','<i>','</i>','<b>'.$description2.'</b>')
+                         .'<br />'
+                         .&mt('Or you can choose to [_1]make no change[_2] and continue[_2] with the reservation you already had: [_3].'
+                         ,'<i>','</i>','<b>'.$description1.'</b>')
+                         .'</p><p><span class="LC_nobreak">'
+                         .'<input type="submit" name="change" value="'.&mt('Process the change').'" />' 
+                         .('&nbsp;'x3)
+                         .'<input type="submit" name="nochange" value="'.&mt('Make no change').'" />'
+                         .'</span></p>');
+            }
 	    $r->print(<<STUFF);
 </form>
 STUFF
         } else {
+            $r->print('<p>'.&mt('Already have a reservation: [_1].',$description1).'</p>');
 	    &return_link($r);
 	}
 	return 0;
@@ -667,8 +675,15 @@ STUFF
                      .&mt('An error occurred while attempting to make a reservation. ([_1])',$1)
                      .'</span></p>');
 	} elsif ($reserved > -1) {
-	    $r->print('<p>'.&mt('Success: [_1]',$description).'</p>');
+	    $r->print('<p style="font-weight: bold;">'.&mt('Successfully signed up:  [_1]',$description).'</p>');
 	    $retvalue = 1;
+            my $person = &Apache::loncommon::plainname($env{'user.name'},$env{'user.domain'});
+            my $subject = &mt('Reservation change: [_1]',$description);
+            my $msgbody = &mt('Successful reservation by [_1] for [_2].',$person,$description);
+            my $msg = &slot_change_messaging($slot{'reservationmsg'},$subject,$msgbody,'reserve');
+            if ($msg) {
+                $r->print($msg);
+            }
 	} elsif ($reserved < 0) {
 	    $r->print('<p>'.&mt('Already reserved: [_1]',$description).'</p>');
 	}
@@ -1081,6 +1096,7 @@ sub show_table {
 	     'starttime'       => 'Start time',
 	     'endtime'         => 'End Time',
              'startreserve'    => 'Time students can start reserving',
+             'reservationmsg'  => 'Message triggered by reservation',
 	     'secret'          => 'Secret Word',
 	     'space'           => '# of students/max',
 	     'ip'              => 'IP or DNS restrictions',
@@ -1095,7 +1111,7 @@ sub show_table {
         $show_fields{'scheduled'} = &mt('Scheduled Members');
     }
     my @show_order=('name','description','type','starttime','endtime',
-		    'startreserve','secret','space','ip','symb',
+		    'startreserve','reservationmsg','secret','space','ip','symb',
 		    'allowedsections','allowedusers','uniqueperiod',
 		    'scheduled','proctor');
     my @show = 
@@ -1169,11 +1185,11 @@ sub show_table {
 						    6,\%stu_display_fields,
 						    \@stu_display_order).'
            </td>
-           <td valign="top">'.&Apache::loncommon::select_form($when,'when',%when_fields).
+           <td valign="top">'.&Apache::loncommon::select_form($when,'when',\%when_fields).
           '</td>
            <td valign="top">'.&Apache::loncommon::select_form($name_filter_type,
 						 'name_filter_type',
-						 %name_filter_type_fields).
+						 \%name_filter_type_fields).
 	      '<br />'.
 	      &Apache::lonhtmlcommon::textbox('name_filter_value',
 					      $env{'form.name_filter_value'},
@@ -1207,7 +1223,7 @@ sub show_table {
 
     my %name_cache;
     my $slotsort = sub {
-	if ($env{'form.order'}=~/^(type|description|endtime|startreserve|ip|symb|allowedsections|allowedusers)$/) {
+	if ($env{'form.order'}=~/^(type|description|endtime|startreserve|ip|symb|allowedsections|allowedusers|reservationmsg)$/) {
 	    if (lc($slots{$a}->{$env{'form.order'}})
 		ne lc($slots{$b}->{$env{'form.order'}})) {
 		return (lc($slots{$a}->{$env{'form.order'}}) 
@@ -1244,12 +1260,15 @@ sub show_table {
 	if ($tmp =~ /^error: /) { undef(%consumed); }
     }
 
+    my %msgops = &slot_reservationmsg_options();
+
     foreach my $slot (sort $slotsort (keys(%slots)))  {
 	if (!&to_show($slot,$slots{$slot},$when,
 		      $env{'form.deleted'},$name_filter)) { next; }
+        my $reservemsg;
 	if (defined($slots{$slot}->{'type'})
-	    && $slots{$slot}->{'type'} ne 'schedulable_student') {
-	    #next;
+	    && $slots{$slot}->{'type'} eq 'schedulable_student') {
+	    $reservemsg = $msgops{$slots{$slot}->{'reservationmsg'}};
 	}
 	my $description=&get_description($slot,$slots{$slot});
 	my ($id_count,$ids);
@@ -1393,6 +1412,9 @@ LOGLINK
 	if (exists($show{'startreserve'})) {
 	    $colspan++;$r->print("<td>$start_reserve</td>\n");
 	}
+        if (exists($show{'reservationmsg'})) {
+            $colspan++;$r->print("<td>$reservemsg</td>\n");
+        }
 	if (exists($show{'secret'})) {
 	    $colspan++;$r->print("<td>$slots{$slot}{'secret'}</td>\n");
 	}
@@ -2119,6 +2141,42 @@ sub display_filter {
     return $output;
 }
 
+sub slot_change_messaging {
+    my ($setting,$subject,$msg,$action) = @_;
+    my $user = $env{'user.name'};
+    my $domain = $env{'user.domain'};
+    my ($message_status,$comment_status);
+    if ($setting eq 'only_student'
+        || $setting eq 'student_and_user_notes_screen') {
+        $message_status =
+            &Apache::lonmsg::user_normal_msg($user,$domain,$subject,$msg);
+        $message_status = '<li>'.&mt('Sent to you: [_1]',
+                                    $message_status).' </li>';
+    }
+    if ($setting eq 'student_and_user_notes_screen') {
+        $comment_status =
+            &Apache::lonmsg::store_instructor_comment($subject.'<br />'.
+                                                      $msg,$user,$domain);
+        $comment_status = '<li>'.&mt('Entry added to course record (viewable by instructor): [_1]',
+                                    $comment_status).'</li>';
+    }
+    if ($message_status || $comment_status) {
+        my $msgtitle;
+        if ($action eq 'reserve') {
+            $msgtitle = &mt('Status of messages about saved reservation');
+        } elsif ($action eq 'release') {
+            $msgtitle = &mt('Status of messages about dropped reservation');
+        } elsif ($action eq 'nochange') {
+            $msgtitle = &mt('Status of messages about unchanged existing reservation');
+        }
+        return '<span class="LC_info">'.$msgtitle.'</span>'
+               .'<ul>'
+               .$message_status
+               .$comment_status
+               .'</ul><hr />';
+    }
+}
+
 sub upload_start {
     my ($r)=@_;    
     $r->print(
@@ -2289,6 +2347,7 @@ sub csvupload_fields {
 	    ['starttime','Start Time of slot'],
 	    ['endtime','End Time of slot'],
 	    ['startreserve','Reservation Start Time'],
+            ['reservationmsg','Message when reservation changed'],
 	    ['ip','IP or DNS restriction'],
 	    ['proctor','List of proctor ids'],
 	    ['description','Slot Description'],
@@ -2370,6 +2429,20 @@ sub csv_upload_assign {
 	    next;
 	}
 
+        if ($slot{'type'} eq 'schedulable_student') {
+            if ($entries{$fields{'reservationmsg'}}) {
+                 if (($entries{$fields{'reservationmsg'}} eq 'only_student') ||
+                     ($entries{$fields{'reservationmsg'}} eq 'student_and_user_notes_screen')) {
+                      $slot{'reservationmsg'}=$entries{$fields{'reservationmsg'}};
+                 } else {
+                      unless (($entries{$fields{'reservationmsg'}} eq 'none') ||
+                              ($entries{$fields{'reservationmsg'}} eq '')) {
+                          push(@errors,"$name -- Slot's reservationmsg setting ignored - not one of: 'only_student', 'student_and_user_notes_screen', 'none' or ''");
+                      }
+                 }
+            }
+        }
+
 	foreach my $key ('ip','proctor','description','maxspace',
 			 'secret','symb') {
 	    if ($entries{$fields{$key}}) {
@@ -2419,6 +2492,15 @@ sub slot_command_titles {
     return %titles;
 }
 
+sub slot_reservationmsg_options {
+    my %options = &Apache::lonlocal::texthash (
+                        only_student  => 'Sent to student',
+        student_and_user_notes_screen => 'Sent to student and added to user notes',
+                                 none => 'None sent and no record in user notes',
+    );
+    return %options;
+}
+
 sub handler {
     my $r=shift;
 
@@ -2548,7 +2630,26 @@ sub handler {
 	} elsif ($env{'form.command'} eq 'get') {
 	    &get_slot($r,$symb);
 	} elsif ($env{'form.command'} eq 'change') {
-	    if (&get_slot($r,$symb,$env{'form.releaseslot'},1)) {
+            if ($env{'form.nochange'}) {
+                my $slot_name = $env{'form.releaseslot'};
+                my @slots = &check_for_reservation($symb,'allslots');
+                my $msg;
+                if (($slot_name ne '') && (grep(/^\Q$slot_name\E/,@slots))) { 
+                     my %slot=&Apache::lonnet::get_slot($env{'form.releaseslot'});
+                     my $description=&get_description($slot_name,\%slot);
+                     $msg = '<span style="font-weight: bold;">'.
+                            &mt('Unchanged reservation: [_1]',$description).'</span><br /><br />';
+                     my $person = 
+                         &Apache::loncommon::plainname($env{'user.name'},$env{'user.domain'});
+                     my $subject = &mt('Reservation unchanged: [_1]',$description);
+                     my $msgbody = &mt('No change to existing registration by [_1] for [_2].',$person,$description);
+                     $msg .= &slot_change_messaging($slot{'reservationmsg'},$subject,$msgbody,'nochange');
+                } else {
+                    $msg = '<span class="LC_warning">'.&mt('Reservation no longer reported as available.').'</span>';
+                }
+                $r->print($msg);
+                &return_link($r);
+	    } elsif (&get_slot($r,$symb,$env{'form.releaseslot'},1)) {
 		&release_slot($r,$symb,$env{'form.releaseslot'});
 	    }
 	} else {
