@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonsurveyreports.pm,v 1.22 2008/12/12 05:03:39 raeburn Exp $
+# $Id: lonsurveyreports.pm,v 1.24 2010/02/28 23:58:55 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -63,7 +63,7 @@ sub BuildSurveyReportsPage {
                                );
     &Apache::loncommon::store_course_settings('survey_reports',
                                               \%Saveable_Parameters);
-    &Apache::loncommon::restore_course_settings('survey_resports',
+    &Apache::loncommon::restore_course_settings('survey_reports',
                                                 \%Saveable_Parameters);
     #
     &Apache::lonstatistics::PrepareClasslist();
@@ -98,7 +98,7 @@ sub BuildSurveyReportsPage {
         #
         $r->print('<hr />');
         $r->print('<h4>'.
-                  &Apache::lonlocal::locallocaltime(time).','.
+                  &Apache::lonlocal::locallocaltime(time).', '.
                   &Apache::lonstatistics::section_and_enrollment_description().
                   '</h4>');
         $r->rflush();
@@ -177,7 +177,7 @@ sub SurveyProblemSelector {
         my @resources = &Apache::lonstathelpers::get_resources($navmap,$seq);
         foreach my $res (@resources) {
             foreach my $part (@{$res->parts}) {
-                if ($res->is_survey($part)) {
+                if (($res->is_survey($part)) || ($res->is_anonsurvey($part))) {
                     push(@SurveyProblems,{res=>$res,seq=>$seq,part=>$part});
                     last;
                 }
@@ -658,11 +658,12 @@ sub CreateInterface {
         $prob_checkbox .= 'checked="checked" ';
     }
     $prob_checkbox .= 'value="true" />';
-    $Str .= '<td align="right" valign="top">'.
-        '<label><b>'.
-        &mt('Show problem [_1]',$prob_checkbox).'</b></label><br />'.
-        '<label><b>'.
-        '</td>';
+    $Str .=
+        '<td valign="top">'
+       .'<label>'
+       .$prob_checkbox.&mt('Show problem')
+       .'</label>'
+       .'</td>';
     #
     $Str .= &Apache::loncommon::end_data_table_row();
     $Str .= &Apache::loncommon::end_data_table();
