@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Arabic Localization Lexicon
 #
-# $Id: ar.pm,v 1.19 2010/05/03 10:53:20 bisitz Exp $
+# $Id: ar.pm,v 1.21 2011/05/27 14:39:55 bisitz Exp $
 #
 # Copyright i-Learning Limited Partnership Company
 #
@@ -1981,8 +1981,8 @@ use base qw(Apache::localize);
    'Grant/revoke role of Librarian'
 => 'منح أو إلغاء دور أمين المكتبة',
 
-   'Grant/revoke role of Scantron Operator'
-=> 'Scantron منح أو إلغاء دور مشغِّل',
+   'Grant/revoke role of Bubblesheet Scanning Operator'
+=> 'Grant/revoke role of Bubblesheet Scanning Operator', # 'Scantron منح أو إلغاء دور مشغِّل',
 
    'Grant/revoke role of Teaching Assistant'
 => 'منح أو إلغاء دور الأستاذ المساعد',
@@ -2425,8 +2425,8 @@ use base qw(Apache::localize);
    'Save as ...'
 => 'حفظ باسم',
 
-   'Scantron Operator'
-=> 'Scantron مشغِّل',
+   'Bubblesheet Scanning Operator'
+=> 'Bubblesheet Scanning Operator', # 'Scantron مشغِّل',
 
    'Search Complete'
 => 'البحث كامل',
@@ -2470,8 +2470,8 @@ use base qw(Apache::localize);
    'Send Reply'
 => 'إرسال جواب',
 
-   'Send Scantron data to a course'
-=> 'إرسال بيانات اسکنترون إلى دورة',
+   'Send bubblesheet data to a course'
+=> 'Send bubblesheet data to a course', # 'إرسال بيانات اسکنترون إلى دورة',
 
    'Send as critical message'
 => 'إرسال رسالة مهمة',
@@ -2764,8 +2764,8 @@ use base qw(Apache::localize);
    'Updating discussion time'
 => 'يطور زمن البحث',
 
-   'Upload Scantron data'
-=> 'تحميل بيانات اسکنترون إلى الشبكة',
+   'Upload bubblesheet data'
+=> 'Upload bubblesheet data', # 'تحميل بيانات اسکنترون إلى الشبكة',
 
    'Upload a Photo'
 => 'تحميل صورة إلى الشبكة',
@@ -2833,7 +2833,7 @@ use base qw(Apache::localize);
    'Welcome to the Assignment Parameter Helper'
 => 'نرحب بك في مساعد تسليم الوسيط',
 
-   'Welcome to the Learning<i>Online</i> Network with CAPA. Please wait while your session is being set up'
+   'Welcome to the Learning[_1]Online[_2] Network with CAPA. Please wait while your session is being set up'
 => 'نرحب بك في شبكة تحميل التعليم بواسطة لون کابا انتظر رجاءً ليتم تنظيم جلستك',
 
    'What parameter do you want to set for all problems in the course?'
