@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Farsi Localization Lexicon
 #
-# $Id: fa.pm,v 1.14 2009/05/07 12:42:17 bisitz Exp $
+# $Id: fa.pm,v 1.18 2011/05/27 14:39:56 bisitz Exp $
 #
 # Copyright i-Learning Limited Partnership Company
 #
@@ -34,7 +34,7 @@ use base qw(Apache::localize);
 %Lexicon=('_AUTO' => 1,
 'language_code' => 'fa',
 'char_encoding' => 'UTF-8',
-'date_locale'  => 
+'date_locale'  =>
       '$weekday, $day.$month.$year, $twentyfour:$minutes:$seconds',
 'date_months'  => ' ژانويه,فوريه,مارس,آوريل,مى,ژوئن,جولاى,آگوست,سپتامبر,اكتبر,نوامبر,دسامبر',
 'date_days'    => 'يكشنبه,دوشنبه,سه شنبه,چهارشنبه,پنجشنبه,جمعه,شنبه',
@@ -889,7 +889,7 @@ use base qw(Apache::localize);
    'Create a new course'
 => 'ايجاد يك درس جديد',
 
-   'Customized right of use ...	'
+   'Customized right of use ...'
 => 'حق سفارشى استفاده',
 
    'Delete messages from bulletin boards'
@@ -1402,81 +1402,87 @@ use base qw(Apache::localize);
    '. . . for an individual student'
 => '. . . براى يك دانشجو',
 
-   '1 am'
-=> ' 1 بامداد',
-
    '1 out of N multiple choice (radio button)'
 => 'يكى از  تعداد انتخاب چند گزينه‏اى',
 
-   '1 pm'
-=> '1 بعد از ظهر',
-
-   '10 am'
-=> '10 بامداد',
-
-   '10 pm'
-=> '10 شب',
-
-   '11 am'
-=> '11 بامداد',
-
-   '11 pm'
-=> 'شب  11',
-
-   '12 am'
+   '12 am' # midnight
 => '12 پيش از ظهر',
 
-   '12 noon'
-=> '12 ظهر',
+   'midnight'
+=> 'نيمه شب',
+
+   '1 am'
+=> '1 بامداد',
 
    '2 am'
 => '2 بامداد',
 
-   '2 pm'
-=> '2 بعد از ظهر',
-
    '3 am'
 => '3 بامداد',
 
-   '3 pm'
-=> '3 بعد از ظهر',
-
    '4 am'
 => '4 بامداد',
 
-   '4 pm'
-=> '4 بعد از ظهر',
-
    '5 am'
 => '5 بامداد',
 
-   '5 pm'
-=> '5 بعد از ظهر',
-
    '6 am'
 => '6 بامداد ',
 
-   '6 pm'
-=> '6 بعد از ظهر',
-
    '7 am'
 => '7 بامداد',
 
-   '7 pm'
-=> '7 بعد از ظهر',
-
    '8 am'
 => '8 بامداد',
 
-   '8 pm'
-=> '8 بعد از ظهر',
-
    '9 am'
 => '9 بامداد',
 
+   '10 am'
+=> '10 بامداد',
+
+   '11 am'
+=> '11 بامداد',
+
+   '12 noon'
+=> '12 ظهر',
+
+   'noon'
+=> 'ظهر',
+
+   '1 pm'
+=> '1 بعد از ظهر',
+
+   '2 pm'
+=> '2 بعد از ظهر',
+
+   '3 pm'
+=> '3 بعد از ظهر',
+
+   '4 pm'
+=> '4 بعد از ظهر',
+
+   '5 pm'
+=> '5 بعد از ظهر',
+
+   '6 pm'
+=> '6 بعد از ظهر',
+
+   '7 pm'
+=> '7 بعد از ظهر',
+
+   '8 pm'
+=> '8 بعد از ظهر',
+
    '9 pm'
 => '9 بعد از ظهر',
 
+   '10 pm'
+=> '10 شب',
+
+   '11 pm'
+=> 'شب  11',
+
    '<- Previous'
 => '<- قبلى',
 
@@ -1975,8 +1981,8 @@ use base qw(Apache::localize);
    'Grant/revoke role of Librarian'
 => 'اعطا يا لغو نقش كتابدار',
 
-   'Grant/revoke role of Scantron Operator'
-=> 'اعطا يا لغو نقش اپراتور اسكانترون',
+   'Grant/revoke role of Bubblesheet Scanning Operator'
+=> 'Grant/revoke role of Bubblesheet Scanning Operator', # 'اعطا يا لغو نقش اپراتور اسكانترون',
 
    'Grant/revoke role of Teaching Assistant'
 => 'اعطا يا لغو نقش دستيار مدرس',
@@ -2419,8 +2425,8 @@ use base qw(Apache::localize);
    'Save as ...'
 => '... ذخيره با نام',
 
-   'Scantron Operator'
-=> 'اپراتور اسكانترون',
+   'Bubblesheet Scanning Operator'
+=> 'Bubblesheet Scanning Operator', # 'اپراتور اسكانترون',
 
    'Search Complete'
 => 'جستجو كامل است',
@@ -2464,8 +2470,8 @@ use base qw(Apache::localize);
    'Send Reply'
 => 'ارسال پاسخ',
 
-   'Send Scantron data to a course'
-=> 'ارسال داده‏هاى اسكانترون به يك دوره',
+   'Send bubblesheet data to a course'
+=> 'Send bubblesheet data to a course', # 'ارسال داده‏هاى اسكانترون به يك دوره',
 
    'Send as critical message'
 => 'ارسال به عنوان پيام نقادانه',
@@ -2755,8 +2761,8 @@ use base qw(Apache::localize);
    'Updating discussion time'
 => 'در حال روزآمدسازى زمان بحث',
 
-   'Upload Scantron data'
-=> 'آپ‏لود كردن داده‏هاى اسكانترون',
+   'Upload bubblesheet data'
+=> 'Upload bubblesheet data', # 'آپ‏لود كردن داده‏هاى اسكانترون',
 
    'Upload a Photo'
 => 'آپ‏لود كردن يك عكس',
@@ -2824,7 +2830,7 @@ use base qw(Apache::localize);
    'Welcome to the Assignment Parameter Helper'
 => 'به كمك رسان واگذارى پارامتر خوش آمديد',
 
-   'Welcome to the Learning<i>Online</i> Network with CAPA. Please wait while your session is being set up'
+   'Welcome to the Learning[_1]Online[_2] Network with CAPA. Please wait while your session is being set up'
 => 'به شبكه آن لايْنِ يادگيرى به وسيله كاپا خوش آمديد! لطفاً صبر كنيد تا جلسه شما تنظيم شود',
 
    'What parameter do you want to set for all problems in the course?'
@@ -3016,9 +3022,6 @@ use base qw(Apache::localize);
    'manage'
 => 'مديريت كردن',
 
-   'midnight'
-=> 'نيمه شب',
-
    'minutes'
 => 'دقيقه',
 
@@ -3034,9 +3037,6 @@ use base qw(Apache::localize);
    'name only visible to course faculty'
 => 'نام تنها براى هيئت علمى دوره قابل رؤيت است',
 
-   'noon'
-=> 'ظهر',
-
    'notes'
 => 'يادداشتها',
 
