@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Localization routines
 #
-# $Id: lonlocal.pm,v 1.62 2011/03/28 21:10:41 raeburn Exp $
+# $Id: lonlocal.pm,v 1.63 2011/08/03 18:25:16 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -264,7 +264,7 @@ sub preferred_languages {
 
     my $defdom = &Apache::lonnet::default_login_domain();
     foreach my $domtype ($Apache::lonnet::env{'user.domain'},$Apache::lonnet::env{'request.role.domain'},$defdom) {
-        if ($domtype ne '') {
+        if (($domtype ne '') && ($domtype ne 'public')) {
             my %domdefs = &Apache::lonnet::get_domain_defaults($domtype);
             if ($domdefs{'lang_def'} ne '') {
                 push(@languages,$domdefs{'lang_def'});
@@ -382,7 +382,8 @@ sub gettimezone {
         if ($uroledomdefs{'timezone_def'} ne '') {
             $timezone = $uroledomdefs{'timezone_def'};
         }
-    } elsif ($Apache::lonnet::env{'user.domain'} ne '') {
+    } elsif (($Apache::lonnet::env{'user.domain'} ne '') && 
+             ($Apache::lonnet::env{'user.domain'} ne 'public')) {
         my %udomdefaults = 
             &Apache::lonnet::get_domain_defaults($Apache::lonnet::env{'user.domain'});
         if ($udomdefaults{'timezone_def'} ne '') {
