@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonmetadata.pm,v 1.28 2010/01/31 03:12:03 raeburn Exp $
+# $Id: lonmetadata.pm,v 1.33 2011/05/31 14:45:53 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -93,7 +93,7 @@ FULLTEXT idx_language (language),
 FULLTEXT idx_owner (owner), 
 FULLTEXT idx_copyright (copyright)) 
 
-TYPE=MYISAM;
+ENGINE=MYISAM;
 
 =cut
 
@@ -356,6 +356,9 @@ sub create_metadata_storage {
                 $col_des.="(".$coldata->{'size'}.")";
             }
         }
+        if (($tablename =~ /allusers/) && ($column eq 'username')) {  
+            $col_des .= ' CHARACTER SET latin1 COLLATE latin1_general_cs';
+        }
         # Modifiers
         if (exists($coldata->{'restrictions'})){
             $col_des.=" ".$coldata->{'restrictions'};
@@ -381,7 +384,7 @@ sub create_metadata_storage {
         $text .= 'idx_'.$colname.' ('.$colname.')';
         push (@Columns,$text);
     }
-    $request .= "(".join(", ",@Columns).") TYPE=MyISAM";
+    $request .= "(".join(", ",@Columns).") ENGINE=MyISAM";
     return $request;
 }
 
