@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 # The LearningOnline Network
 #
-# $Id: refresh_courseids_db.pl,v 1.3 2010/03/17 18:16:56 raeburn Exp $
+# $Id: refresh_courseids_db.pl,v 1.10 2010/12/24 07:58:09 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -54,10 +54,15 @@ use strict;
 use lib '/home/httpd/lib/perl/';
 use Apache::lonnet;
 use Apache::loncommon;
+use Apache::lonuserstate;
+use Apache::loncoursedata;
+use Apache::lonnavmaps;
 use LONCAPA qw(:DEFAULT :match);
 
 exit if ($Apache::lonnet::perlvar{'lonRole'} ne 'library');
 
+use vars qw( %checkparms %checkresponsetypes %checkcrstypes %anonsurvey %randomizetry );
+
 #  Make sure this process is running from user=www
 my $wwwid=getpwnam('www');
 if ($wwwid!=$<) {
@@ -73,14 +78,20 @@ open(my $fh,'>>'.$Apache::lonnet::perlvar{'lonDaemons'}.'/logs/refreshcourseids_
 print $fh "==== refresh_courseids_db.pl Run ".localtime()."====\n";
 
 my @domains = sort(&Apache::lonnet::current_machine_domains());
+my @ids=&Apache::lonnet::current_machine_ids();
+
+&Apache::loncommon::build_release_hashes(\%checkparms,\%checkresponsetypes,
+                                         \%checkcrstypes,\%anonsurvey,\%randomizetry);
+$env{'allowed.bre'} = 'F';
+
 foreach my $dom (@domains) {
     my %courseshash;
-    my @ids=&Apache::lonnet::current_machine_ids();
     my %currhash = &Apache::lonnet::courseiddump($dom,'.',1,'.','.','.',1,\@ids,'.');
+    my %lastaccess = &Apache::lonnet::courselastaccess($dom,undef,\@ids);
     my $dir = $Apache::lonnet::perlvar{lonUsersDir}.'/'.$dom;
     my %domdesign = &Apache::loncommon::get_domainconf($dom);
     my $autoassign = $domdesign{$dom.'.autoassign.co-owners'};
-    &recurse_courses($dom,$dir,0,\%courseshash,\%currhash,$autoassign,$fh);
+    &recurse_courses($dom,$dir,0,\%courseshash,\%currhash,\%lastaccess,$autoassign,$fh);
     foreach my $lonhost (keys(%courseshash)) {
         if (ref($courseshash{$lonhost}) eq 'HASH') {
             if (&Apache::lonnet::courseidput($dom,$courseshash{$lonhost},$lonhost,'notime') eq 'ok') {
@@ -92,12 +103,14 @@ foreach my $dom (@domains) {
     }
 }
 
+delete($env{'allowed.bre'});
+
 ## Finished!
 print $fh "==== refresh_courseids.db completed ".localtime()." ====\n";
 close($fh);
 
 sub recurse_courses {
-    my ($cdom,$dir,$depth,$courseshash,$currhash,$autoassign,$fh) = @_;
+    my ($cdom,$dir,$depth,$courseshash,$currhash,$lastaccess,$autoassign,$fh) = @_;
     next unless (ref($currhash) eq 'HASH');
     if (-d $dir) {
         opendir(DIR,$dir);
@@ -107,7 +120,7 @@ sub recurse_courses {
         foreach my $item (@contents) {
             if ($depth < 4) {
                 &recurse_courses($cdom,$dir.'/'.$item,$depth,$courseshash,
-                                 $currhash,$autoassign,$fh);
+                                 $currhash,$lastaccess,$autoassign,$fh);
             } elsif ($item =~ /^$match_courseid$/) {
                 my $cnum = $item;
                 my $cid = $cdom.'_'.$cnum;
@@ -140,7 +153,8 @@ sub recurse_courses {
                 }
                 my $chome = &Apache::lonnet::homeserver($cnum,$cdom);
                 my $owner = $courseinfo{'internal.courseowner'};
-                my (%roleshash,$gotcc);
+                my $twodaysago = time - 172800;
+                my (%roleshash,$gotcc,$reqdmajor,$reqdminor);
                 if ($owner eq '') {
                     %roleshash = &Apache::lonnet::get_my_roles($cnum,$cdom,undef,undef,['cc'],undef,undef,1);
                     $gotcc = 1;
@@ -165,6 +179,7 @@ sub recurse_courses {
                 my $creator = $courseinfo{'internal.creator'};
                 my $creationcontext = $courseinfo{'internal.creationcontext'};
                 my $inst_code = $courseinfo{'internal.coursecode'};
+                my $releaserequired = $courseinfo{'internal.releaserequired'};
                 $inst_code = '' if (!defined($inst_code));
                 $owner = '' if (!defined($owner));
                 if ($created eq '') {
@@ -187,13 +202,11 @@ sub recurse_courses {
                             my @stats = stat("$dir/$cnum/passwd");
                             $created = $stats[9];
                         }
-                        my %lastaccess = 
-                            &Apache::lonnet::courselastaccess($cdom,$cnum);
-                        if ($lastaccess{$cid}) {
+                        if ($lastaccess->{$cid}) {
                             if ($created eq '') {
-                                $created = $lastaccess{$cid};
-                            } elsif ($lastaccess{$cid} < $created) {
-                                $created = $lastaccess{$cid};
+                                $created = $lastaccess->{$cid};
+                            } elsif ($lastaccess->{$cid} < $created) {
+                                $created = $lastaccess->{$cid};
                             }
                         }
                         unless ($created eq '') {
@@ -201,6 +214,29 @@ sub recurse_courses {
                         }
                     }
                 }
+                 
+                if (($chome ne '')  && ($lastaccess->{$cid} > $twodaysago)) {
+                    $env{'request.course.id'} = $cdom.'_'.$cnum;
+                    $env{'request.role'} = 'cc./'.$cdom.'/'.$cnum;
+                    &Apache::lonuserstate::readmap($cdom.'/'.$cnum);
+
+                    # check all parameters
+                    ($reqdmajor,$reqdminor) = &parameter_constraints($cnum,$cdom);
+
+                    # check course type
+                    ($reqdmajor,$reqdminor) = &coursetype_constraints($cnum,$cdom,$crstype,
+                                                                      $reqdmajor,
+                                                                      $reqdminor);
+                    # check course contents
+                    ($reqdmajor,$reqdminor) = &coursecontent_constraints($cnum,$cdom,
+                                                                         $reqdmajor,
+                                                                         $reqdminor);
+                    delete($env{'request.course.id'});
+                    delete($env{'request.role'});
+                } elsif ($releaserequired) {
+                    ($reqdmajor,$reqdminor) = split(/\./,$releaserequired);
+                }
+
                 unless ($chome eq 'no_host') {
                     $courseshash->{$chome}{$cid} = {
                         description => $courseinfo{'description'},
@@ -274,6 +310,22 @@ sub recurse_courses {
                                 $courseinfo{'internal.'.$item};
                         }
                     }
+                    if ($reqdmajor eq '' && $reqdminor eq '') {
+                        if ($courseinfo{'internal.releaserequired'} ne '') {
+                            $changes{'internal.releaserequired'} = '';
+                        }
+                    } else {
+                        my $releasereq =  $reqdmajor.'.'.$reqdminor;
+                        $courseshash->{$chome}{$cid}{'releaserequired'} = $releasereq;
+                        if ($courseinfo{'internal.releaserequired'} eq '') {
+                            $changes{'internal.releaserequired'} = $releasereq;
+                        } else {
+                            if ($courseinfo{'internal.releaserequired'} ne $releasereq) {
+                        
+                                $changes{'internal.releaserequired'} = $releasereq;
+                            }
+                        }
+                    }
                     if (keys(%changes)) {
                         if (&Apache::lonnet::put('environment',\%changes,$cdom,$cnum) eq 'ok') {
                             print $fh "Course's environment.db for ".$cdom."_".$cnum." successfully updated with following entries: ";
@@ -292,5 +344,114 @@ sub recurse_courses {
     return;
 }
 
+sub parameter_constraints {
+    my ($cnum,$cdom) = @_;
+    my ($reqdmajor,$reqdminor);
+    my $resourcedata=&read_paramdata($cnum,$cdom);
+    if (ref($resourcedata) eq 'HASH') {
+        foreach my $key (keys(%{$resourcedata})) { 
+            foreach my $item (keys(%checkparms)) {
+                if ($key =~ /(\Q$item\E)$/) {
+                    if (ref($checkparms{$item}) eq 'ARRAY') {
+                        my $value = $resourcedata->{$key};
+                        if (grep(/^\Q$value\E$/,@{$checkparms{$item}})) {
+                            my ($major,$minor) = split(/\./,$Apache::lonnet::needsrelease{'parameter:'.$item.':'.$value});
+                            ($reqdmajor,$reqdminor) = 
+                                &update_reqd_loncaparev($major,$minor,$reqdmajor,$reqdminor);
+                        }
+                    }
+                }
+            }
+        }
+    }
+    return ($reqdmajor,$reqdminor);
+}
 
+sub coursetype_constraints {
+    my ($cnum,$cdom,$crstype,$reqdmajor,$reqdminor) = @_;
+    if (defined($checkcrstypes{$crstype})) {
+        my ($major,$minor) = split(/\./,$checkcrstypes{$crstype});
+        ($reqdmajor,$reqdminor) = 
+            &update_reqd_loncaparev($major,$minor,$reqdmajor,$reqdminor);
+    }
+    return ($reqdmajor,$reqdminor);
+}
+
+sub coursecontent_constraints {
+    my ($cnum,$cdom,$reqdmajor,$reqdminor) = @_;
+    my $navmap = Apache::lonnavmaps::navmap->new();
+    if (defined($navmap)) {
+        my %anonsubmissions =  &Apache::lonnet::dump('nohist_anonsurveys',
+                                                     $cdom,$cnum);
+        my %randomizetrysubm = &Apache::lonnet::dump('nohist_randomizetry',
+                                                     $cdom,$cnum);
+        my %allresponses;
+        my ($anonsurv_subm,$randbytry_subm);
+        foreach my $res ($navmap->retrieveResources(undef,sub { $_[0]->is_problem() },1,0)) {
+            my %responses = $res->responseTypes();
+            foreach my $key (keys(%responses)) {
+                next unless(exists($checkresponsetypes{$key}));
+                $allresponses{$key} += $responses{$key};
+            }
+            my @parts = @{$res->parts()};
+            my $symb = $res->symb();
+            foreach my $part (@parts) {
+                if (exists($anonsubmissions{$symb."\0".$part})) {
+                    $anonsurv_subm = 1;
+                }
+                if (exists($randomizetrysubm{$symb."\0".$part})) {
+                    $randbytry_subm = 1;
+                }
+            }
+        }
+        foreach my $key (keys(%allresponses)) {
+            my ($major,$minor) = split(/\./,$checkresponsetypes{$key});
+            ($reqdmajor,$reqdminor) = &update_reqd_loncaparev($major,$minor,$reqdmajor,$reqdminor);
+        }
+        if ($anonsurv_subm) {
+            ($reqdmajor,$reqdminor) = &update_reqd_loncaparev($anonsurvey{major},
+                                          $anonsurvey{minor},$reqdmajor,$reqdminor);
+        }
+        if ($randbytry_subm) {
+            ($reqdmajor,$reqdminor) = &update_reqd_loncaparev($randomizetry{major},
+                                          $randomizetry{minor},$reqdmajor,$reqdminor);
+        }
+    }
+    return ($reqdmajor,$reqdminor);
+}
+
+sub update_reqd_loncaparev {
+    my ($major,$minor,$reqdmajor,$reqdminor) = @_;
+    if (($major ne '' && $major !~ /\D/) & ($minor ne '' && $minor !~ /\D/)) {
+        if ($reqdmajor eq '' || $reqdminor eq '') {
+            $reqdmajor = $major;
+            $reqdminor = $minor;
+        } elsif (($major > $reqdmajor) ||
+            ($major == $reqdmajor && $minor > $reqdminor))  {
+            $reqdmajor = $major;
+            $reqdminor = $minor;
+        }
+    }
+    return ($reqdmajor,$reqdminor);
+}
+
+sub read_paramdata {
+    my ($cnum,$dom)=@_;
+    my $resourcedata=&Apache::lonnet::get_courseresdata($cnum,$dom);
+    my $classlist=&Apache::loncoursedata::get_classlist();
+    foreach my $student (keys(%{$classlist})) {
+        if ($student =~/^($LONCAPA::match_username)\:($LONCAPA::match_domain)$/) {
+            my ($tuname,$tudom)=($1,$2);
+            my $useropt=&Apache::lonnet::get_userresdata($tuname,$tudom);
+            foreach my $userkey (keys(%{$useropt})) {
+                if ($userkey=~/^$env{'request.course.id'}/) {
+                    my $newkey=$userkey;
+                    $newkey=~s/^($env{'request.course.id'}\.)/$1\[useropt\:$tuname\:$tudom\]\./;
+                    $$resourcedata{$newkey}=$$useropt{$userkey};
+                }
+            }
+         }
+    }
+    return $resourcedata;
+}
 
