@@ -9,7 +9,7 @@
 #  and displays a page showing the results of the action.
 #
 #
-# $Id: loncfile.pm,v 1.106 2011/03/01 01:36:55 raeburn Exp $
+# $Id: loncfile.pm,v 1.106.2.1 2011/11/07 13:38:45 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1475,7 +1475,7 @@ function writeDone() {
 |;
 	$loaditem{'onload'} = "writeDone()";
     }
-    
+
     # Breadcrumbs
     &Apache::lonhtmlcommon::clear_breadcrumbs();
     &Apache::lonhtmlcommon::add_breadcrumb({
@@ -1493,7 +1493,7 @@ function writeDone() {
 					     {'add_entries' => \%loaditem,})
              .&Apache::lonhtmlcommon::breadcrumbs()
              .&Apache::loncommon::head_subbox(
-                  &Apache::loncommon::CSTR_pageheader())
+                  &Apache::loncommon::CSTR_pageheader($fn))
     );
   
     $r->print('<h3>'.&mt('Location').': '.&display($fn).'</h3>');
