@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler to show differences between file versions
 #
-# $Id: londiff.pm,v 1.23 2007/01/15 18:34:32 albertel Exp $
+# $Id: londiff.pm,v 1.28.2.1 2011/11/07 15:18:13 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -27,6 +27,9 @@
 #
 ###
 
+
+
+
 package Apache::londiff;
 
 use strict;
@@ -74,26 +77,55 @@ sub handler {
     &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},
 					    ['filename','versiontwo',
 					     'versionone','filetwo']);
-# Get the files
 
+# Check permissions
+    my $allowed=0;
     my $cuname=$env{'user.name'};
     my $cudom=$env{'user.domain'};
 
-    if ($env{'form.filename'}=~/^\/res\//) {
-	($cudom,$cuname,$env{'form.filename'})=
-	    ($env{'form.filename'}=~m{^/res/($LONCAPA::domain_re)/($LONCAPA::username_re)/(.*)$});
+    if ($env{'form.filename'}=~ m{^/res/}) {
+        if (&Apache::lonnet::allowed('bre',$env{'form.filename'})) {
+            if ($env{'request.course.id'}) {
+                if (&Apache::lonnet::allowed('mdc',$env{'request.course.id'})) {
+                    $allowed = 1;
+                }
+            } else {
+                $allowed = 1;
+            }
+        } elsif (&Apache::lonnet::allowed('bro',$env{'form.filename'})) {
+            $allowed = 1;
+        }
+        if ($allowed) {
+            ($cudom,$cuname,$env{'form.filename'})=
+                ($env{'form.filename'}=~m{^/res/($LONCAPA::domain_re)/($LONCAPA::username_re)(/.*)$});
+
+            if (($env{'form.versionone'} eq 'priv') || ($env{'form.versiontwo'} eq 'priv')) {
+                my ($cstrname,$cstrdom) =
+                    &Apache::loncacc::constructaccess("/priv/$cuname".$env{'form.filename'},$cudom);
+                unless (($cstrname eq $cuname) && ($cstrdom eq $cudom)) {
+                    $allowed = 0;
+                }
+            }
+        }
     } else {
-	unless (($cuname,$cudom)=
-		&Apache::loncacc::constructaccess($env{'form.filename'},
-						  $r->dir_config('lonDefDomain'))) {
-	    $r->log_reason($cuname.':'.$cudom.
-			   ' trying to get diffs file '.$env{'form.filename'}.
-			   '  - not authorized', 
-			   $r->filename); 
-	    return HTTP_NOT_ACCEPTABLE;
-	}
+        ($cuname,$cudom)=
+            &Apache::loncacc::constructaccess($env{'form.filename'},
+                                              $r->dir_config('lonDefDomain'));
+        if ($cuname ne '' && $cudom ne '') {
+            $allowed = 1;
+        } else {
+            $r->log_reason($env{'user.name'}.':'.$env{'user.domain'}.
+                           ' trying to get diffs file '.$env{'form.filename'}.
+                           '  - not authorized',
+                           $r->filename);
+        }
     }
-  
+    unless ($allowed) {
+        return HTTP_NOT_ACCEPTABLE;
+    }
+
+# Get the files
+
     my $efn=$env{'form.filename'};
 
     $efn=~s{/\~($LONCAPA::username_re)}{}g;
@@ -104,15 +136,19 @@ sub handler {
     &Apache::loncommon::content_type($r,'text/html');
     $r->send_http_header;
 
-    $r->print(&Apache::loncommon::start_page('Resource Differences'));
-
+    $r->print(&Apache::loncommon::start_page('Resource Differences',undef,
+                                             {'no_nav_bar'  => 1, }));
   
-    $r->print('<h1>'.($env{'form.filetwo'}?'':&mt('Compare versions of')).
-	      ' <tt>'.$efn.'</tt></h1>');
+    $r->print(($env{'form.filetwo'}?'':&mt('Compare versions of')).
+	      ' <span class="LC_filename">'.$efn.'</span>');
    
     if (($cuname ne $env{'user.name'}) || ($cudom ne $env{'user.domain'})) {
-	$r->print('<h3><span class="LC_diff_coauthor">Co-Author: '.$cuname.' at '.$cudom.
-		  '</span></h3>');
+        $r->print('<p><span class="LC_info">'
+                 .&mt('Co-Author [_1]'
+                     ,&Apache::loncommon::plainname($cuname,$cudom)
+                     .' ('.$cuname.':'.$cudom.')')
+                .'</span></p>'
+        );
     }
 
 
@@ -173,28 +209,27 @@ sub handler {
 # Run diff
 
 	my $diffs = diff(\@f1, \@f2);
-	
-# Start page output
 
-	my $chunk;
-	my $line;
-
-	$r->print('<pre>');
-	
-	foreach $chunk (@$diffs) {
-	 
-	    foreach $line (@$chunk) {
-		my ($sign, $lineno, $text) = @$line;
-		$text=&HTML::Entities::encode($text,'<>&"');
-		$lineno=substr($lineno.'        ',0,7);
-		$r->print('<span class="'.(($sign eq '+')?'LC_diff_added'
-                                                         :'LC_diff_removed').'">'.
-			  $sign.' '.$lineno.' '.$text."</span>\n");
-	    }
-	    $r->print("</pre><hr /><pre>\n");
-	}
-	$r->print('</pre>');
-	
+        if (@$diffs) {
+            # Start page output
+            my $chunk;
+            my $line;
+            $r->print('<pre>');
+            foreach $chunk (@$diffs) {
+                foreach $line (@$chunk) {
+                    my ($sign, $lineno, $text) = @$line;
+                    $text=&HTML::Entities::encode($text,'<>&"');
+                    $lineno=substr($lineno.'        ',0,7);
+                    $r->print('<span class="'.(($sign eq '+')?'LC_diff_added'
+                                                             :'LC_diff_removed').'">'.
+                              $sign.' '.$lineno.' '.$text."</span>\n");
+                }
+                $r->print("</pre><hr /><pre>\n");
+            }
+            $r->print('</pre>');
+        } else {
+            $r->print('<p class="LC_info">'.&mt('No differences found').'</p>');
+        }
     } else {
 	$r->print('<h1><span class="LC_warning">'.&mt('Binary File').'</span></h1>');
     }
@@ -208,5 +243,27 @@ sub handler {
 __END__
 
 
+=pod
 
+=head1 NAME
 
+Apache::londiff
+
+=head1 SYNOPSIS
+
+Handler to show difference between two files.
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+=head1 Subroutines
+
+=over
+
+=item get_split_file()
+
+=item are_different_files()
+
+=item handler()
+
+=cut
