@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Publication Handler
 #
-# $Id: lonpublisher.pm,v 1.258.2.4 2010/01/27 03:44:48 raeburn Exp $
+# $Id: lonpublisher.pm,v 1.267.2.1 2011/11/07 13:38:45 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1121,7 +1121,7 @@ sub publish {
 # ------------------------------------------------------------- Save some stuff
         my %savemeta=();
         foreach ('title') {
-            $savemeta{$_}=$metadatafields{$_};
+            if ($metadatafields{$_}) { $savemeta{$_}=$metadatafields{$_}; }
 	}
 # ------------------------------------------ See if anything new in file itself
  
@@ -1223,12 +1223,14 @@ sub publish {
     my $intr_scrout.='<br />'
                     .'<form name="pubform" action="/adm/publish" method="post">';
     unless ($env{'form.makeobsolete'}) {
+       my $thissrc=$source;
+       $thissrc=~s{^/home/($match_username)/public_html}{/priv/$1};
        $intr_scrout.='<p class="LC_warning">'
                     .&mt('Searching for your resource will be based on the following metadata. Please provide as much data as possible.')
                     .'</p>'
                     .'<p><input type="submit" value="'
                     .&mt('Finalize Publication')
-                    .'" /></p>';
+                    .'" /> <a href="'.$thissrc.'">'.&mt('Cancel').'</a></p>';
     }
     $intr_scrout.=&Apache::lonhtmlcommon::start_pick_box();
     $intr_scrout.=
@@ -1687,7 +1689,6 @@ sub phasetwo {
             if (-e $target.'.meta') {
                 $r->print(&Apache::lonhtmlcommon::confirm_success(
                            &mt('Failed to write old metadata copy').", $!",1));
-
 		return 0;
 	    }
         }
@@ -1727,7 +1728,7 @@ sub phasetwo {
 	    &mt('Failed to copy source').", $!",1));
 	return 0;
     }
-
+    
 # ---------------------------------------------- Delete local tmp-preview files
     unlink($copyfile.'.tmp');
 # --------------------------------------------------------------- Copy Metadata
@@ -1771,15 +1772,23 @@ sub phasetwo {
         
         my $thissrcdir=$thissrc;
         $thissrcdir=~s/\/[^\/]+$/\//;
- 
-        $r->print(
-           '<hr /><a href="'.$thisdistarget.'"><font size="+2">'.
-           &mt('View Published Version').'</font></a>'.
-           '<p><a href="'.$thissrc.'"><font size="+2">'.
-		  &mt('Back to Source').'</font></a></p>'.
-           '<p><a href="'.$thissrcdir.
-                   '"><font size="+2">'.
-		  &mt('Back to Source Directory').'</font></a></p>');
+        
+        $r->print(&Apache::loncommon::head_subbox(
+            &Apache::lonhtmlcommon::start_funclist().
+            &Apache::lonhtmlcommon::add_item_funclist(
+                '<a href="'.$thisdistarget.'">'.
+                &mt('View Published Version').
+                '</a>').
+            &Apache::lonhtmlcommon::add_item_funclist(
+                '<a href="'.$thissrc.'">'.
+                &mt('Back to Source').
+                '</a>').
+            &Apache::lonhtmlcommon::add_item_funclist(
+                '<a href="'.$thissrcdir.'">'.
+                &mt('Back to Source Directory').
+                '</a>').
+            &Apache::lonhtmlcommon::end_funclist())
+        );
     }
     return 1;
 }
@@ -2165,10 +2174,25 @@ sub handler {
     &Apache::loncommon::content_type($r,'text/html');
     $r->send_http_header;
     
+    # Breadcrumbs
+    &Apache::lonhtmlcommon::clear_breadcrumbs();
+    &Apache::lonhtmlcommon::add_breadcrumb({
+        'text'  => 'Construction Space',
+        'href'  => &Apache::loncommon::authorspace(),
+    });
+    &Apache::lonhtmlcommon::add_breadcrumb({
+        'text'  => 'Resource Publication',
+        'href'  => '',
+    });
+
     my $js='<script type="text/javascript">'.
 	&Apache::loncommon::browser_and_searcher_javascript().
 	'</script>';
-    $r->print(&Apache::loncommon::start_page('Resource Publication',$js));
+    $r->print(&Apache::loncommon::start_page('Resource Publication',$js)
+             .&Apache::lonhtmlcommon::breadcrumbs()
+             .&Apache::loncommon::head_subbox(
+                  &Apache::loncommon::CSTR_pageheader($fn))
+    );
 
 
     my $thisfn=$fn;
@@ -2269,7 +2293,6 @@ ENDDIFF
 	    }
 	} else {
 	    &phasetwo($r,$thisfn,$thistarget,$thisembstyle,$thisdistarget); 
-	    $r->print('<hr />');
 	}
     }
     $r->print(&Apache::loncommon::end_page());
