@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler to retrieve an old version of a file
 #
-# $Id: lonretrieve.pm,v 1.41 2009/08/11 15:15:01 bisitz Exp $
+# $Id: lonretrieve.pm,v 1.42.2.1 2011/11/07 13:38:45 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -292,7 +292,7 @@ sub handler {
 
   my $r=shift;
 
-  my $fn;
+  my ($fn,$trailfile);
 
 
 # Get query string for limited number of parameters
@@ -330,6 +330,7 @@ sub handler {
   }
 
   $fn=~s{/~($LONCAPA::username_re)}{};
+  $trailfile = "/home/$uname/public_html".$fn;
 
   &Apache::loncommon::content_type($r,'text/html');
   $r->send_http_header;
@@ -348,7 +349,7 @@ sub handler {
   $r->print(&Apache::loncommon::start_page('Retrieve Published Resources')
            .&Apache::lonhtmlcommon::breadcrumbs()
            .&Apache::loncommon::head_subbox(
-                &Apache::loncommon::CSTR_pageheader()) # FIXME crumbs broken?
+                &Apache::loncommon::CSTR_pageheader($trailfile))
     );
 
   $r->print('<p>'
@@ -357,7 +358,7 @@ sub handler {
            .'</p>');
   
   if (($uname ne $env{'user.name'}) || ($udom ne $env{'user.domain'})) {
-          $r->print('<p><span class="LC_warning">'
+          $r->print('<p><span class="LC_info">'
                    .&mt('Co-Author [_1]'
                        ,&Apache::loncommon::plainname($uname,$udom)
                        .' ('.$uname.':'.$udom.')')
