@@ -1,5 +1,5 @@
 # Handler for parsing text upload problem descriptions into .problems
-# $Id: testbankimport.pm,v 1.29 2011/01/31 17:49:13 raeburn Exp $
+# $Id: testbankimport.pm,v 1.30 2011/03/05 22:25:09 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1330,7 +1330,11 @@ sub create_mcq {
     my $numfoils = scalar(@{$qstnref}) - 1; 
     my $datestamp = localtime;
     my $numansrs = scalar(@{$answerref});
-    my $output = '<problem>
+    my $output = '<problem>';
+    if ($qtype eq 'MC') {
+        $output .= "\n".'<parameter name="maxtries" type="int_pos" default="2" description="Maximum Number of Tries" />';
+    }
+    $output .= '
  <startouttext />';
     if ($res eq 'application/rtf' || $res eq 'text/html') {
         if ($header ne '') {
