@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# $Id: startup.pl,v 1.33 2008/07/13 17:38:55 raeburn Exp $
+# $Id: startup.pl,v 1.34.12.1 2011/02/07 21:29:37 raeburn Exp $
 
 BEGIN {
     eval "use Apache2::compat();";
@@ -148,6 +148,9 @@ use Apache::coursecatalog();
 use Apache::courseclassifier();
 use Apache::selfenroll();
 use Apache::createaccount();
+use Apache::lonconfigsettings();
+use Apache::courseprefs();
+use Apache::domainprefs();
 1;
 __END__
 
