@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # TeX Conversion Module
 #
-# $Id: lontexconvert.pm,v 1.107 2011/05/27 18:34:07 raeburn Exp $
+# $Id: lontexconvert.pm,v 1.108 2011/06/06 16:08:45 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -247,12 +247,10 @@ sub init_math_support {
 sub mimetex_valign {
     my ($esc_texstring)=@_;
     my $valign = 0;
-    my $lonhost = $Apache::lonnet::perlvar{'lonHostID'};
-    my $hostname = &Apache::lonnet::hostname($lonhost);
     my $path = '/cgi-bin/mimetex.cgi?'.$esc_texstring;
     my $socket;
     &Apache::lonxml::start_alarm();
-    $socket = IO::Socket::INET->new(PeerAddr => $hostname,
+    $socket = IO::Socket::INET->new(PeerAddr => 'localhost',
                                     PeerPort => 'http(80)',
                                     Proto    => 'tcp');
     if ($socket) {
