@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # XML Parser Module 
 #
-# $Id: lonxml.pm,v 1.505.2.4 2010/09/29 16:12:17 raeburn Exp $
+# $Id: lonxml.pm,v 1.505.2.7 2011/12/01 04:41:55 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -112,6 +112,7 @@ use Apache::lonmaxima();
 use Apache::lonr();
 use Apache::lonlocal;
 use Apache::lonhtmlcommon();
+use Apache::functionplotresponse();
 
 #====================================   Main subroutine: xmlparse  
 
@@ -881,6 +882,11 @@ sub init_safespace {
   $safehole->wrap(\&Apache::lonnet::logthis,$safeeval,'&LONCAPA_INTERNAL_LOGTHIS');
   $safehole->wrap(\&Apache::inputtags::finalizeawards,$safeeval,'&LONCAPA_INTERNAL_FINALIZEAWARDS');
   $safehole->wrap(\&Apache::caparesponse::get_sigrange,$safeeval,'&LONCAPA_INTERNAL_get_sigrange');
+  $safehole->wrap(\&Apache::functionplotresponse::fpr_val,$safeeval,'&fpr_val');
+  $safehole->wrap(\&Apache::functionplotresponse::fpr_f,$safeeval,'&fpr_f');
+  $safehole->wrap(\&Apache::functionplotresponse::fpr_dfdx,$safeeval,'&fpr_dfdx');
+  $safehole->wrap(\&Apache::functionplotresponse::fpr_d2fdx2,$safeeval,'&fpr_d2fdx2');
+
 #  use Data::Dumper;
 #  $safehole->wrap(\&Data::Dumper::Dumper,$safeeval,'&LONCAPA_INTERNAL_Dumper');
 #need to inspect this class of ops
@@ -2139,11 +2145,13 @@ sub register_insert_xml {
     while (my $token = $parser->get_token()) {
 	if ($token->[0] eq 'S') {
 	    my $key;
-	    if      ($token->[1] eq 'tag') {
+	    if ($token->[1] eq 'tag') {
 		$tag = $token->[2]{'name'};
-		$insertlist{"$tagnum.tag"} = $tag;
-		$insertlist{"$tag.num"}   = $tagnum;
-		push(@alltags,$tag);
+                if (defined($tag)) {
+		    $insertlist{$tagnum.'.tag'} = $tag;
+		    $insertlist{$tag.'.num'}   = $tagnum;
+		    push(@alltags,$tag);
+                }
 	    } elsif ($in_help && $token->[1] eq 'file') {
 		$key = $tag.'.helpfile';
 	    } elsif ($in_help && $token->[1] eq 'description') {
@@ -2175,12 +2183,12 @@ sub register_insert_xml {
     
     # parse the allows and ignore tags set to <show>no</show>
     foreach my $tag (@alltags) {	
-        next if (!exists($insertlist{"$tag.allow"}));
-	my $allow =  $insertlist{"$tag.allow"};
+        next if (!exists($insertlist{$tag.'.allow'}));
+	my $allow =  $insertlist{$tag.'.allow'};
        	foreach my $element (split(',',$allow)) {
 	    $element =~ s/(^\s*|\s*$ )//gx;
-	    if (!exists($insertlist{"$element.show"})
-                || $insertlist{"$element.show"} ne 'no') {
+	    if (!exists($insertlist{$element.'.show'})
+                || $insertlist{$element.'.show'} ne 'no') {
 		push(@{ $insertlist{$tag.'.which'} },$element);
 	    }
 	}
