@@ -1,7 +1,7 @@
 <!--
 The LearningOnline Network
 Resource Assembly Tool
-// $Id: ratcode.js,v 1.10 2009/04/23 13:09:44 bisitz Exp $
+// $Id: ratcode.js,v 1.13.2.1 2011/11/22 00:22:09 raeburn Exp $
 //
 // Copyright Michigan State University Board of Trustees
 //
@@ -1403,7 +1403,7 @@ function draw () {
 function infoclear() {
  if (notclear!=1) {
   infcheck();
-  inf.document.clear();
+  inf.document.open();
   inf.document.writeln
    ('<html><body bgcolor="#FFFFFF"><table><tr><td>'+
     '<img src="/adm/lonIcons/lonlogos.gif" /></td>');
@@ -1468,7 +1468,7 @@ function info(infostr) {
  if ((editmode!=1) && (infostr!=lastinfo)) {
   notclear=1;
   infcheck();
-  inf.document.clear();
+  inf.document.open();
   inf.document.writeln(
    '<html><body bgcolor="#FFFFFF">'+
    '<table><tr><td width="32"><img src="'+raticons+'info.gif" /></td><td bgcolor="#AAFFAA">');
@@ -1622,21 +1622,25 @@ function insertcondlink(cid,lnr) {
 
 // ------------------------------------------------------ Clears indexer window
 function idxclear() {
-  idx.document.clear();
+  idx.document.open();
+  idx.document.close();
 }
 
 // --------------------------------------------------------- Clears copy window
 function copydxclear() {
-  copydx.document.clear();
+  copydx.document.open();
+  copydx.document.close();
 }
 // ------------------------------------------------------- Clears search window
 function srchclear() {
-  srch.document.clear();
+  srch.document.open();
+  srch.document.close();
 }
 
 // --------------------------------------------------------- Clears parm window
 function parmclear() {
-  parm.document.clear();
+  parm.document.open();
+  parm.document.close();
 }
 
 // ------------------------------------------------------ Closes indexer window
@@ -1684,7 +1688,7 @@ function groupopen(url) {
    var options="scrollbars=1,resizable=1,menubar=0";
    idxmode=mode;
    idxflag=1;
-   idx=open("/adm/groupsort?mode=rat&recover=1&readfile="+url,"idxout",options);
+   idx=open("/adm/groupsort?inhibitmenu=yes&mode=rat&recover=1&readfile="+url,"idxout",options);
    idx.focus();
 }
 // ------------------------------------------------------- Open bookmark window
@@ -1692,7 +1696,7 @@ function bookmarkopen() {
    var options="scrollbars=1,resizable=1,menubar=0";
    idxmode=mode;
    idxflag=1;
-   idx=open("/adm/groupsort?mode=rat&bookmarks=1","idxout",options);
+   idx=open("/adm/groupsort?inhibitmenu=yes&mode=rat&bookmarks=1","idxout",options);
    idx.focus();
 }
 // ------------------------------------------------- Open browser to select map
@@ -1724,7 +1728,7 @@ function copydxopen(mode) {
    copydxmode=mode;
    copydxflag=1;
    copydx=open("",'copydxout',options);
-   copydx.document.clear('');
+   copydx.document.open('');
    copydx.document.writeln(
  '<html><body bgcolor="#FFFFFF"><h1>Copy from Map</h1>'+
  '<form name="mapload"><input type="text" size="40" name="importmap">'+
@@ -1782,7 +1786,7 @@ function handler(infostr) {
   editmode=1;
   notclear=1;
   infcheck();
-  inf.document.clear();
+  inf.document.open();
   inf.document.writeln(
    '<html><body bgcolor="#FFFFFF">'+
    '<table><tr><td width="32"><img src="'+raticons+'edit.gif" /></td><td bgcolor="#AAFFAA">');
@@ -1954,7 +1958,7 @@ function empty(rid,k) {
   notclear=1;
   linkmode=0;
   infcheck();
-  inf.document.clear();
+  inf.document.open();
   inf.document.writeln(
    '<html><body bgcolor="#FFFFFF">'+
    '<table><tr><td width="32"><img src="'+raticons+'edit.gif" /></td><td bgcolor="#AAFFAA">'+
