@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Server for RAT Maps
 #
-# $Id: lonratsrv.pm,v 1.39 2006/12/20 22:42:48 albertel Exp $
+# $Id: lonratsrv.pm,v 1.41 2008/11/20 15:19:05 jms Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -26,6 +26,7 @@
 # http://www.lon-capa.org/
 #
 
+
 package Apache::lonratsrv;
 
 use strict;
@@ -96,3 +97,22 @@ ENDSCRIPT
 
 1;
 __END__
+
+
+=head1 NAME
+
+Apache::lonratsrv
+
+=head1 SYNOPSIS
+
+Handler that takes output from RAT and stores
+it on disk. Handles the upper hidden frame of
+the added window that comes up in RAT. (3
+frames come up in RAT server, code, and
+output. This module handles server
+connection.)
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+=cut
\ No newline at end of file
