@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # routines for modyfing .sequence and .page files
 #
-# $Id: map.pm,v 1.12 2008/12/19 03:49:56 raeburn Exp $
+# $Id: map.pm,v 1.13 2009/02/12 11:35:10 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -357,7 +357,7 @@ sub storemap {
 	    $output.='<&>objcont<:>'.$i.'<:>'.$zombies[$i];
         }
     }
-    $output=~s/https?\&colon\;\/\///g;
+    $output=~s/http\&colon\;\/\///g;
     $env{'form.output'}=$output;
     return &loadmap($fn,&savemap($fn,''));
 }
@@ -616,8 +616,8 @@ sub savemap {
 			}
 			$comp[1].='" external="true';
 		    } else {
-			if ($comp[1]=~/^https?\:\/\//) {
-			    $comp[1]=~s/^https?\:\/\/[^\/]*\//\//;
+			if ($comp[1]=~/^http\:\/\//) {
+			    $comp[1]=~s/^http\:\/\/[^\/]*\//\//;
 			}
 		    }
 		    $outstr.='<resource id="'.$parts[1].'" src="'
